@@ -35,36 +35,43 @@
 
 #include "cdflib.h"
 #include "cdftools.h"
+#if defined(WIN32)
+#  include <Windows.h>
+#endif
 
 /******************************************************************************
 * Parameter/qualifier constants.
 ******************************************************************************/
 
-#define CDFPATHparm     0
+#define CDFPATHparm       0
 
-#define DUMPqual        0
-#define OUTPUTqual      1
-#define FORMATqual      2
-#define NOFORMATqual    3
-#define PRECISIONqual   4
-#define VARSqual        5
-#define ABOUTqual	6
-#define HEADERqual	7
-#define NOHEADERqual	8
-#define RECORDRANGEqual 9
-#define COL2ROWqual    10
-#define DETECTqual     11
+#define DUMPqual          0
+#define OUTPUTqual        1
+#define FORMATqual        2
+#define NOFORMATqual      3
+#define PRECISIONqual     4
+#define VARSqual          5
+#define ABOUTqual    	  6
+#define HEADERqual	  7
+#define NOHEADERqual	  8
+#define RECORDRANGEqual   9
+#define COL2ROWqual      10
+#define DETECTqual       11
+#define EPOCHVVqual      12
+#define ZISO8601qual     13
 
-#define ALLDUMP         0
-#define DATADUMP        1
-#define METADATADUMP    2
-#define GLOBALDUMP      3
-#define VARIABLEDUMP    4
+#define ALLDUMP           0
+#define DATADUMP          1
+#define NODATADUMP        2
+#define METADATADUMP      3
+#define GLOBALDUMP        4
+#define VARIABLEDUMP      5
 
 #define DEFAULToptionDUMP ALLDUMP
 /******************************************************************************
 * Global variables.
 ******************************************************************************/
+CDFid id;
 #if defined(CDFDUMP)
 int dump = DEFAULToptionDUMP;
 Logical useFormat = DEFAULTformatDUMP;
@@ -74,6 +81,8 @@ char varsOption[513];
 Logical header = DEFAULTheaderDUMP;
 Logical col2row = DEFAULTcol2rowDUMP;
 long startingRec, endingRec;
+Logical epochVV = DEFAULTepochVVDUMP;
+Logical ziso8601;
 #else
 extern char outputCDF[CDF_PATHNAME_LEN+1];
 extern int dump;
@@ -83,6 +92,8 @@ extern char varsOption[513];
 extern Logical header;
 extern Logical col2row;
 extern long startingRec, endingRec;
+extern Logical epochVV;
+extern Logical ziso8601;
 #endif
 /******************************************************************************
 * Function Prototypes.
