@@ -32,6 +32,9 @@
 
 #include "cdflib.h"
 #include "widgets.h"
+#if defined(WIN32)
+#  include <Windows.h>
+#endif
 
 #if defined(mac)
 #  include "cdfedit.rh"
