@@ -395,7 +395,7 @@ struct AEDRstruct64 {
   Int32 Num;            /* Entry number (rVariable/zVariable number or
 			   arbitrary global `entry' [gEntry] number) */
   Int32 NumElems;       /* Number of elements of DataType */
-  Int32 rfuA;           /* reserved for future use (value = 0) */
+  Int32 NumStrings;     /* Number of strings of string type */
   Int32 rfuB;           /* reserved for future use (value = 0) */
   Int32 rfuC;           /* reserved for future use (value = 0) */
   Int32 rfuD;           /* reserved for future use (value = -1) */
@@ -421,7 +421,7 @@ struct AEDRstructExt64 {
 #define AEDR_DATATYPE_OFFSET64  24
 #define AEDR_NUM_OFFSET64       28
 #define AEDR_NUMELEMS_OFFSET64  32
-#define AEDR_RFUa_OFFSET64      36
+#define AEDR_NUMSTRINGS_OFFSET64 36
 #define AEDR_RFUb_OFFSET64      40
 #define AEDR_RFUc_OFFSET64      44
 #define AEDR_RFUd_OFFSET64      48
@@ -516,7 +516,7 @@ struct UIRstruct64 {
 * Function prototypes.
 ******************************************************************************/
 
-STATICforIDL CDFstatus ValidateCompression64 PROTOARGs((
+VISIBLE_PREFIX CDFstatus ValidateCompression64 PROTOARGs((
   long cType, long *cParms
 ));
 STATICforIDL Logical Read32s_64 PROTOARGs((vFILE *fp, Int32 *buffer, int count));
@@ -537,6 +537,9 @@ STATICforIDL CDFstatus CloseVarFiles64 PROTOARGs((struct CDFstruct *CDF));
 STATICforIDL Logical WriteAccess64 PROTOARGs((
   struct CDFstruct *CDF, Logical forDelete, CDFstatus *pStatus
 ));
+STATICforIDL Logical UpdateTT2000header PROTOARGs((
+  struct CDFstruct *CDF, CDFstatus *pStatus
+));
 STATICforIDL CDFstatus WriteBuffer64 PROTOARGs((
   struct CDFstruct *CDF, vFILE *fp, Int32 dataType, Int32 numElems,
   void *buffer
