@@ -34,6 +34,9 @@
 
 #include "cdflib.h"
 #include "cdftools.h"
+#if defined(WIN32)
+#  include <Windows.h>
+#endif
 
 #if defined(mac)
 #  include "cdfstats.rh"
@@ -120,6 +123,7 @@ extern long formatAttrN;
 extern long majority;
 extern Logical ziso8601;
 #endif
+
 /******************************************************************************
 * VarStructST.
 ******************************************************************************/
@@ -151,7 +155,7 @@ struct VarStructST {
   Logical oneINrange;
   Logical minmaxInited;
   Logical monoInited;
-  Logical hyper;
+  Logical hyperx;
   enum monoStatesENUM monoState;
   long nValueBytes;
 };
