@@ -35,6 +35,9 @@
 
 #include "cdflib.h"
 #include "widgets.h"
+#if defined(WIN32)
+#  include <Windows.h>
+#endif
 
 #if defined(mac)
 #  include "cdfxp.rh"
@@ -171,9 +174,9 @@
 #define MAX_CHECKSUM            MD5_CHECKSUM
 #define MAX_SETTINGS_LEN        200
 
-#define PASSED                  1
-#define FAILED                  2
-#define FATAL                   3
+#define PASSEDx                 1
+#define FAILEDx                 2
+#define FATALx                  3
 
 #define SUCCESS                 1
 #define FATALin                 2
@@ -260,7 +263,7 @@
 
 #if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
     defined(__amd64) || defined(__x86_64__) || defined(__ia64__) || \
-    defined(__PPC64__) || defined(__ppc64__)
+    defined(__PPC64__) || defined(__ppc64__) || defined(__arm64__)
 #  define Int32FORMATstandard     "%11d"
 #  define Int32uFORMATstandard    "%10d"
 #  define Int64FORMATstandard     "%20lld"
