@@ -81,17 +81,18 @@ struct ItemWindowStruct {
   int ULcol;
   int nColsTotal;               /* Includes left and right borders. */
   char *label;
-  int NhLines;
-  char **hLines;
-  int NiLines;
-  char **iLines;
-  int nItems;
-  int *iLineNs;
-  int *iCols;
-  int *iLens;
-  int NiRows;
+  int NhLines;			/* Label at the top window. */
+  char **hLines;		/* Header lines */
+  int NiLines;			/* Number of lines. */
+  char **iLines;		/* Lines for attribute or variable value. */
+  int nItems;			/* Total number of items. */
+  int *iLineNs;			/* Each item's line number (0-based). */
+  int *iCols;			/* Each items's starting column position. */
+  int *iLens;			/* Each item's character length. */
+  int *ibLens;			/* Each item's byte length. */
+  int NiRows;			/* Number of rows in the windows. */
   int NtLines;
-  char **tLines;
+  char **tLines;		/* Tail lines. */
   int *exitChars;               /* The characters which cause an exit from
 				   the prompt window.  Terminated by NUL. */
   int refreshChar;              /* Causes entire screen to be refreshed. */
@@ -103,7 +104,8 @@ struct ItemWindowStruct {
   * These are initialized/calculated/returned by `ItemWindow'.
   ***************************************************************************/
   int itemN;                    /* Current item number. */
-  int key;                      /* Key entered causing exit from menu. */
+/*int key;*/                    /* Key entered causing exit from menu. */
+  wint_t key;                   /* Key entered causing exit from menu. */
   /***************************************************************************
   * These are for internal use by `ItemWindow'.
   ***************************************************************************/
@@ -183,7 +185,7 @@ struct PromptWindowStruct {
   char *label;
   int ULrow;
   int ULcol;
-  int nColsTotal;               /* Includes left and right borders. */
+  int nColsTotal;               /* Includes left and right borders. (= 78) */
   int NhLines;
   char **hLines;
   int maxChars;
@@ -200,7 +202,8 @@ struct PromptWindowStruct {
   /***************************************************************************
   * These are initialized/calculated/returned by `PromptWindow'.
   ***************************************************************************/
-  int key;                      /* Key entered causing exit from menu. */
+/*int key;*/                    /* Key entered causing exit from menu. */
+  wint_t key;                   /* Key entered causing exit from menu. */
   /***************************************************************************
   * These are for internal use by `PromptWindow'.
   ***************************************************************************/
@@ -210,18 +213,22 @@ struct PromptWindowStruct {
 				   bottom border rows). */
   int nColS;                    /* Doesn't include left and right borders. */
   int curCol;                   /* Current column cursor is on (numbered from
-				   zero (0). */
+				   zero (0). (== vLcol + total width till 
+				   curChar) */
   int curChar;                  /* Current character cursor is on (numbered
 				   from zero (0). */
-  int curLen;                   /* Current length of value. */
+  int curCharWidth;             /* Current character column cursor is on 
+				   (numbered from zero (0). */
+  int curLen;                   /* Current character length of value. */
+  int curWidthLen;              /* Current width length of value. */
   int NvCols;                   /* Number of columns in value section. */
   int vRow;                     /* Row number value is on. */
-  int vLcol;                    /* Left-most column of value. */
+  int vLcol;                    /* Left-most column of value. (= 3) */
   int vRcol;                    /* Right-most column of value. */
   int mLcol;                    /* Column left `more' indicator is in. */
   int mRcol;                    /* Column right `more' indicator is in. */
-  int hRowT, tRowT;             /* Top row for section. */
-  int hRowB, tRowB;             /* Bottom row for section.  */
+  int hRowT, tRowT;             /* Top row number for help/trailer section. */
+  int hRowB, tRowB;             /* Bottom row number for help/trailer section.*/
   WINDOWid wid;                 /* Window id. */
 };
 
@@ -292,7 +299,8 @@ struct EditWindowStruct {
   /***************************************************************************
   * These are initialized/calculated/returned by `EditWindow'.
   ***************************************************************************/
-  int key;                      /* Key entered causing exit from menu. */
+/*int key;*/                    /* Key entered causing exit from menu. */
+  wint_t key;                   /* Key entered causing exit from menu. */
   /***************************************************************************
   * These are for internal use by `EditWindow'.
   ***************************************************************************/
@@ -387,7 +395,8 @@ struct FieldWindowStruct {
   * These are initialized/calculated/returned by `FieldWindow'.
   ***************************************************************************/
   int fieldN;                   /* Current field number. */
-  int key;                      /* Key entered causing exit from menu. */
+/*int key;*/                    /* Key entered causing exit from menu. */
+  wint_t key;                   /* Key entered causing exit from menu. */
   /***************************************************************************
   * These are for internal use by `FieldWindow'.
   ***************************************************************************/
