@@ -18,7 +18,7 @@
 #include "cdflib64.h"
 #include "cdfmd5.h"
 
-#define BUFFSIZE 16384
+#define BLOCKSIZE 16384
 
 /******************************************************************************
 * Local function prototypes.
@@ -219,20 +219,25 @@ vFILE *vFp;
 long  size;
 uChar  signature[16];
 {
-  uChar buffer[BUFFSIZE];
+/*  uChar buffer[BLOCKSIZE]; */
+  uChar *buffer;
   struct MD5Context md5c;
   int jj = 0, readBytes;
 
   MD5Init(&md5c);
+  buffer = (uChar *) malloc (BLOCKSIZE + 72);
+  if (!buffer) return FALSE; 
   if (fseek(vFp->fp, 0, vSEEK_SET) == EOF) return FALSE;
   while (jj < size) {
-     if (jj+BUFFSIZE < size) readBytes = BUFFSIZE;
+     if (jj+BLOCKSIZE < size) readBytes = BLOCKSIZE;
      else readBytes = size - jj;
      if (fread(buffer,1,readBytes,vFp->fp) != (size_t) readBytes) return FALSE;
      MD5Update(&md5c, buffer, (unsigned) readBytes);
      jj = jj + readBytes;
   }
   MD5FinalZ(signature, &md5c);
+  free (buffer);
+  buffer = NULL;
   return TRUE;
 
 }
@@ -246,19 +251,22 @@ vFILE *vFp;
 OFF_T  size;
 uChar  signature[16];
 {
-  uChar buffer[BUFFSIZE];
+/*  uChar buffer[BLOCKSIZE]; */
+  uChar *buffer;
   struct MD5Context md5c;
   OFF_T jj = 0; 
   int readBytes;
 
   MD5Init(&md5c);
+  buffer = (uChar *) malloc (BLOCKSIZE + 72);
+  if (!buffer) return FALSE;
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
      if (FSEEK64(vFp->fh,(OFF_T) 0,vSEEK_SET) == EOF) return FALSE;
 #else
      if (FSEEK64(vFp->fp,(OFF_T) 0,vSEEK_SET) == EOF) return FALSE;
 #endif
   while (jj < size) {
-     if (jj+BUFFSIZE < size) readBytes = BUFFSIZE;
+     if (jj+BLOCKSIZE < size) readBytes = BLOCKSIZE;
      else readBytes = (int) (size - jj);
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
      if (FREAD64(vFp->fh,buffer,(unsigned int) readBytes) != (int) readBytes)
@@ -270,6 +278,8 @@ uChar  signature[16];
      jj = jj + readBytes;
   }
   MD5FinalZ(signature, &md5c);
+  free (buffer);
+  buffer = NULL;
   return TRUE;
 }
 
