@@ -129,13 +129,15 @@ switch (Va->item) {
     /**************************************************************************
     * Allocate/initialize CDF structure.
     **************************************************************************/
-    CDF = (struct CDFstruct *) cdf_AllocateMemory ((size_t)sizeof(struct CDFstruct), NULL);
+    CDF = (struct CDFstruct *) 
+		cdf_AllocateMemory ((size_t)sizeof(struct CDFstruct), NULL);
     if (CDF == NULL) {
       V_close (dotFp, NULL, NULL);
       CDFdeleteFile (CDFnameX);
       return BAD_MALLOC;
     }
-    CDF->CDFname = (char *) cdf_AllocateMemory ((size_t)strlen(CDFnameTx) + 1, NULL);
+    CDF->CDFname = (char *) cdf_AllocateMemory ((size_t)strlen(CDFnameTx) + 1,
+						 NULL);
     if (CDF->CDFname == NULL) {
       V_close (dotFp, NULL, NULL);
       CDFdeleteFile (CDFnameX);
@@ -196,6 +198,7 @@ switch (Va->item) {
     **************************************************************************/
     if (!CACHEv(CDF->fp,CDF->workingCacheSize)) {
       AbortAccess (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return BAD_CACHE_SIZE;
     }
@@ -204,11 +207,13 @@ switch (Va->item) {
     **************************************************************************/
     if (!Write32(CDF->fp,(Int32 *)&magicNumber1)) {
       AbortAccess (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
     if (!Write32(CDF->fp,(Int32 *)&magicNumber2u)) {
       AbortAccess (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
@@ -241,6 +246,7 @@ switch (Va->item) {
 		     CDR_RECORD,&CDR,copyRight,
 		     CDR_NULL),&pStatus)) {
       AbortAccess (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -248,7 +254,7 @@ switch (Va->item) {
     * Write GDR.
     **************************************************************************/
     CDF->GDRoffset = CDR.GDRoffset;
-    GDR.RecordSize = GDR_BASE_SIZE + (numDims * sizeof(Int32));
+    GDR.RecordSize = GDR_BASE_SIZE + (numDims * 4);
     GDR.RecordType = GDR_;
     GDR.rVDRhead = 0;
     GDR.zVDRhead = 0;
@@ -270,6 +276,7 @@ switch (Va->item) {
 		     GDR_RECORD,&GDR,
 		     GDR_NULL),&pStatus)) {
       AbortAccess (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -408,9 +415,8 @@ switch (Va->item) {
     * Write rVDR/zVDR.
     **************************************************************************/
     VDR.RecordSize = BOO(zOp,zVDR_BASE_SIZE,rVDR_BASE_SIZE) +
-		     BOO(zOp,zNumDims,0)*sizeof(Int32) +          /*DimSizes.*/
-		     BOO(zOp,zNumDims,
-			     CDF->rNumDims)*sizeof(Int32);	  /*DimVarys.*/
+		     BOO(zOp,zNumDims,0)*4 +          		  /*DimSizes.*/
+		     BOO(zOp,zNumDims, CDF->rNumDims)*4;	  /*DimVarys.*/
     VDR.RecordType = BOO(zOp,zVDR_,rVDR_);
     VDR.VDRnext = 0;
     VDR.DataType = dataType;
@@ -443,6 +449,7 @@ switch (Va->item) {
     if (!sX(AllocateIR(CDF,VDR.RecordSize+padSize,&offset),&pStatus)) {
       CDFdeleteFile (pathnameX);
       AbortAccess (CDF, UPDATE, noDELETE);
+      cdf_FreeMemory (pad, NULL);
       return pStatus;
     }
     DefaultPadValuePre350(dataType, numElements, pad);
@@ -453,6 +460,7 @@ switch (Va->item) {
 		     VDR_NULL),&pStatus)) {
       CDFdeleteFile (pathnameX);
       AbortAccess (CDF, UPDATE, noDELETE);
+      cdf_FreeMemory (pad, NULL);
       return pStatus;
     }
     cdf_FreeMemory (pad, NULL);
