@@ -132,13 +132,15 @@ switch (Va->item) {
     /**************************************************************************
     * Allocate/initialize CDF structure.
     **************************************************************************/
-    CDF = (struct CDFstruct *) cdf_AllocateMemory ((size_t)sizeof(struct CDFstruct), NULL);
+    CDF = (struct CDFstruct *) 
+		cdf_AllocateMemory ((size_t)sizeof(struct CDFstruct), NULL);
     if (CDF == NULL) {
       V_close64 (dotFp, NULL, NULL);
       CDFdeleteFile (CDFnameX);
       return BAD_MALLOC;
     }
-    CDF->CDFname = (char *) cdf_AllocateMemory ((size_t)strlen(CDFnameT) + 1, NULL);
+    CDF->CDFname = (char *) cdf_AllocateMemory ((size_t)strlen(CDFnameT) + 1,
+						 NULL);
     if (CDF->CDFname == NULL) {
       V_close64 (dotFp, NULL, NULL);
       CDFdeleteFile (CDFnameX);
@@ -150,7 +152,7 @@ switch (Va->item) {
     CDF->magic = VALIDid_MAGIC_NUMBER;
     CDF->largeFile = TRUE;
     CDF->CDRoffset64 = (OFF_T) V3_CDR_OFFSET64;
-    CDF->GDRoffset64 = (OFF_T) NO_OFFSET64; /* Reset below when GDR is written. */
+    CDF->GDRoffset64 = (OFF_T) NO_OFFSET64; /* Reset when GDR is written. */
     CDF->readOnly = FALSE;
     CDF->zMode = zMODEoff;
     CDF->decoding = HOST_DECODING;
@@ -200,6 +202,7 @@ switch (Va->item) {
     **************************************************************************/
     if (!CACHEv64(CDF->fp,CDF->workingCacheSize)) {
       AbortAccess64 (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return BAD_CACHE_SIZE;
     }
@@ -208,11 +211,13 @@ switch (Va->item) {
     **************************************************************************/
     if (!Write32_64(CDF->fp,(Int32 *)&magicNumber1)) {
       AbortAccess64 (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
     if (!Write32_64(CDF->fp,(Int32 *)&magicNumber2u)) {
       AbortAccess64 (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
@@ -239,6 +244,7 @@ switch (Va->item) {
 		       CDR_RECORD,&CDR,copyRight,
 		       CDR_NULL),&pStatus)) {
       AbortAccess64 (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -273,6 +279,7 @@ switch (Va->item) {
 		       GDR_RECORD,&GDR,
 		       GDR_NULL),&pStatus)) {
       AbortAccess64 (CDF, noUPDATE, CDFDELETE);
+      cdf_FreeMemory (CDF->CDFname, NULL);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -452,6 +459,7 @@ switch (Va->item) {
     if (!sX(AllocateIR64(CDF,VDR.RecordSize+padSize,&offset),&pStatus)) {
       CDFdeleteFile (pathnameX);
       AbortAccess64 (CDF, UPDATE, noDELETE);
+      cdf_FreeMemory (pad, NULL);
       return pStatus;
     }
     DefaultPadValue(dataType, numElements, pad);
@@ -462,6 +470,7 @@ switch (Va->item) {
 		       VDR_NULL),&pStatus)) {
       CDFdeleteFile (pathnameX);
       AbortAccess64 (CDF, UPDATE, noDELETE);
+      cdf_FreeMemory (pad, NULL);
       return pStatus;
     }
     cdf_FreeMemory (pad, NULL);
