@@ -115,7 +115,8 @@ switch (Va->item) {
       CDF->stage.fp = NULL;
     }
     if (CDF->compressFp != NULL) {
-      if (!DELETEv64(CDF->compressFp,NULL)) sX (SCRATCH_DELETE_ERROR, &pStatus);
+      if (!DELETEv64(CDF->compressFp,NULL)) sX (SCRATCH_DELETE_ERROR,
+                     &pStatus);
       CDF->compressFp = NULL;
     }
     if (!PriorTo ("3.5.0", (Int32)version, (Int32)release, (Int32)increment))
@@ -1067,7 +1068,8 @@ Int32 *deletedTo;
   * ...and start there.
   ****************************************************************************/
   if (!sX(DeleteRecords_r_64(CDF,Var,vxrOffset,firstRec,
-			     lastRec,deletedTo,&total),&pStatus)) return pStatus;
+			     lastRec,deletedTo,&total),&pStatus))
+    return pStatus;
   /****************************************************************************
   * If the top level of VXR(s) was totally deleted, set the VXR head/tail to
   * ZERO_OFFSET.
@@ -1086,8 +1088,8 @@ Int32 *deletedTo;
 * DeleteRecords_r_64.
 ******************************************************************************/
 
-static CDFstatus DeleteRecords_r_64 (CDF, Var, firstVXRoffset, firstRec, lastRec,
-				     deletedTo, total)
+static CDFstatus DeleteRecords_r_64 (CDF, Var, firstVXRoffset, firstRec,
+				     lastRec, deletedTo, total)
 struct CDFstruct *CDF;
 struct VarStruct *Var;
 OFF_T firstVXRoffset;
@@ -1713,8 +1715,8 @@ OFF_T irSize;
 * DeleteVXRentry64.
 ******************************************************************************/
 
-static CDFstatus DeleteVXRentry64 (CDF, firstVXRoffset, delVXRoffset, delEntryN,
-				   total)
+static CDFstatus DeleteVXRentry64 (CDF, firstVXRoffset, delVXRoffset,
+				   delEntryN, total)
 struct CDFstruct *CDF;
 OFF_T firstVXRoffset;
 OFF_T delVXRoffset;
@@ -1806,8 +1808,8 @@ Logical *total;
 * InsertIndexEntry64.
 ******************************************************************************/
 
-static CDFstatus InsertIndexEntry64 (CDF, vxrOffset, entryN, after, first, last,
-				     offset)
+static CDFstatus InsertIndexEntry64 (CDF, vxrOffset, entryN, after, first,
+				     last, offset)
 struct CDFstruct *CDF;
 OFF_T vxrOffset;
 int entryN;
@@ -1929,7 +1931,8 @@ OFF_T offset;
 * UpdateIndexEntries_r_64.
 ******************************************************************************/
 
-static CDFstatus UpdateIndexEntries_r_64 (fp, vxrOffset, aboveRecord, recordCount)
+static CDFstatus UpdateIndexEntries_r_64 (fp, vxrOffset, aboveRecord,
+					  recordCount)
 vFILE *fp;
 OFF_T vxrOffset;
 Int32 aboveRecord;
