@@ -707,8 +707,10 @@ Int32	  *status;		/* Out: CDF status code. */
   long scope;
   long entryT;
 
-  *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),                                                              ATTR_, (long) (*attr_num - 1),                                               GET_, ATTR_SCOPE_, &scope,                                                        NULL_);  
-
+  *status = (Int32) CDFlib (SELECT_, CDF_, Int32ToCDFid(*id),
+                                     ATTR_, (long) (*attr_num - 1),
+                            GET_, ATTR_SCOPE_, &scope,
+                            NULL_);  
   if (StatusBAD(*status)) return;
 
   if (GLOBALscope(scope)) {
@@ -2207,6 +2209,11 @@ Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
   struct STRINGstruct *ssh = NULL;
+  struct CDFstruct *CDF;
+  int LFS = FALSE;
+
+  CDF  = (struct CDFstruct *)Int32ToCDFid(*id);
+  if (isLFS(CDF)) LFS = TRUE;
   *status = (Int32) CDFgetVarAllRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
                                                   DESCRtoREFnul(var_name,
@@ -2254,6 +2261,11 @@ Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
   struct STRINGstruct *ssh = NULL;
+  struct CDFstruct *CDF;
+  int LFS = FALSE;
+
+  CDF  = (struct CDFstruct *)Int32ToCDFid(*id);
+  if (isLFS(CDF)) LFS = TRUE;
   *status = (Int32) CDFgetVarRangeRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
                                                     DESCRtoREFnul(var_name,
@@ -2358,6 +2370,11 @@ Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
   struct STRINGstruct *ssh = NULL;
+  struct CDFstruct *CDF;
+  int LFS = FALSE;
+
+  CDF  = (struct CDFstruct *)Int32ToCDFid(*id);
+  if (isLFS(CDF)) LFS = TRUE;
   *status = (Int32) CDFputVarAllRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
                                                   DESCRtoREFnul(var_name,
@@ -2406,6 +2423,11 @@ Fif_GHOSTDEF(len)               /* Invisible length of "var_name"
                                    (generated by FORTRAN compiler). */
 {
   struct STRINGstruct *ssh = NULL;
+  struct CDFstruct *CDF;
+  int LFS = FALSE;
+  
+  CDF  = (struct CDFstruct *)Int32ToCDFid(*id);
+  if (isLFS(CDF)) LFS = TRUE;
   *status = (Int32) CDFputVarRangeRecordsByVarName (Int32ToCDFid(*id),
 #if defined(Fif_DESCR)
                                                     DESCRtoREFnul(var_name,
