@@ -846,7 +846,8 @@ switch (Va->item) {
 	if (Var != NULL) {
 	  if (Var->stage.areaOffset != NO_OFFSET &&
 	      Var->stage.firstRec != NO_RECORD) {
-	    Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec : Var->stage.lastRec);
+	    Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec :
+                                                        Var->stage.lastRec);
 	    nRecords += (tmp - Var->stage.firstRec + 1);
 	  }
 	}
@@ -860,7 +861,8 @@ switch (Va->item) {
 	  if (Var->stage.areaOffset != NO_OFFSET &&
 	      Var->stage.firstRec != NO_RECORD &&
 	      Var->stage.dotOffset == NO_OFFSET) {
-            Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec : Var->stage.lastRec);
+            Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec :
+                                                        Var->stage.lastRec);
 	    nRecords += (tmp - Var->stage.firstRec + 1);
 	  }
 	}
@@ -1788,6 +1790,10 @@ switch (Va->item) {
       AbortAccess (CDF, UPDATE, noDELETE);
       return pStatus;
     }
+/*
+    if (STRINGdataType(dataType))
+      *((char *)value+(int)numElems) = '\0';
+*/
     if (!sX(ConvertBuffer(CDF->encoding,CDF->decoding,
 			  CDF->negToPosFp0,dataType,
 			  numElems,value,value),&pStatus)) {
@@ -1798,7 +1804,7 @@ switch (Va->item) {
   }
   /****************************************************************************
    * rENTRY_NUMSTRINGS_/zENTRY_NUMSTRINGS_
-   ****************************************************************************/
+   ***************************************************************************/
   case rENTRY_NUMSTRINGS_:
   case zENTRY_NUMSTRINGS_: {
     Logical dataOp = (Va->item == rENTRY_NUMSTRINGS_);
@@ -1825,7 +1831,7 @@ switch (Va->item) {
   }
   /****************************************************************************
    * rENTRY_STRINGSDATA_/zENTRY_STRINGSDATA_, 
-   ****************************************************************************/
+   ***************************************************************************/
   case rENTRY_STRINGSDATA_:
   case zENTRY_STRINGSDATA_: {
     Logical zOp = (Va->item == zENTRY_STRINGSDATA_);
@@ -1862,6 +1868,7 @@ switch (Va->item) {
     if (*numStrings < 1) *numStrings = 1;
     StringBreakIntoStrings (tmp, numElems, *numStrings, strings);
     free (tmp);
+    tmp = NULL;
     break;
   }
   /****************************************************************************
