@@ -944,7 +944,8 @@ switch (Va->item) {
 	if (Var != NULL) {
 	  if (Var->stage.areaOffset64 != (OFF_T) NO_OFFSET64 &&
 	      Var->stage.firstRec != NO_RECORD) {
-	    Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec : Var->stage.lastRec);
+	    Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec :
+                                                        Var->stage.lastRec);
 	    nRecords += (tmp - Var->stage.firstRec + 1);
 	  }
 	}
@@ -958,7 +959,8 @@ switch (Va->item) {
 	  if (Var->stage.areaOffset64 != (OFF_T) NO_OFFSET64 &&
 	      Var->stage.firstRec != NO_RECORD &&
 	      Var->stage.dotOffset64 == (OFF_T) NO_OFFSET64) {
-            Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec : Var->stage.lastRec);
+            Int32 tmp = (Var->stage.lastRec > tMaxRec ? tMaxRec :
+                                                        Var->stage.lastRec);
 	    nRecords += (tmp - Var->stage.firstRec + 1);
 	  }
 	}
@@ -1435,7 +1437,6 @@ switch (Va->item) {
     if (!sX(ReadVDR64(CDF,CDF->fp,offset,zVar,
 		      VDR_FLAGS,&flags,
 		      VDR_DATATYPE,&dataType,
-		      VDR_NUMELEMS,&numElems,
 		      VDR_NULL),&pStatus)) {
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return pStatus;
@@ -1447,7 +1448,7 @@ switch (Va->item) {
       of the pad value is greater than 16, it causes segmentation fault
       for the IDL CDF interface routine.
     ***********************************************************************/
-    if (STRINGdataType(dataType)) numElems = 1;
+    numElems = 1;
     if (PADvalueBITset(flags)) {
       if (!sX(ReadVDR64(CDF,CDF->fp,offset,zVar,
 	    	        VDR_PADVALUE,padValue,
@@ -1471,12 +1472,6 @@ switch (Va->item) {
         DefaultPadValuePre350 (dataType, numElems, padValue);
       else
         DefaultPadValue (dataType, numElems, padValue);
-      if (!sX(ConvertBuffer(HostEncoding(),CDF->decoding,
-			    CDF->negToPosFp0,dataType,
-			    numElems,padValue,padValue),&pStatus)) {
-	AbortAccess64 (CDF, UPDATE, noDELETE);
-	return pStatus;
-      }
       sX (NO_PADVALUE_SPECIFIED, &pStatus);
     }
     break;
@@ -1928,6 +1923,10 @@ switch (Va->item) {
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return pStatus;
     }
+/*
+    if (STRINGdataType(dataType))
+      *((char *)value+(int)numElems) = '\0';
+*/
     if (!sX(ConvertBuffer(CDF->encoding,CDF->decoding,
 			  CDF->negToPosFp0,dataType,
 			  numElems,value,value),&pStatus)) {
@@ -1975,6 +1974,7 @@ switch (Va->item) {
     if (*numStrings < 1) *numStrings = 1;
     StringBreakIntoStrings (tmp, numElems, *numStrings, strings);
     free (tmp);
+    tmp = NULL;
     break;
   }
   /****************************************************************************
@@ -1987,3 +1987,4 @@ switch (Va->item) {
 }
 return pStatus;
 }
+
