@@ -144,7 +144,8 @@ void *buffer;
        * and extract values from the buffer. Otherwise, get one value at a
        * time from the file
        *******************************************************************/
-       phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,NULL);
+       phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,
+						 NULL);
        if (phyBuffer != NULL) {
          if (!sX(ReadVarValues(CDF,Var,phyRecN,INT32_ZERO,Var->NphyRecValues,
                                phyBuffer),&pStatus)) {
@@ -498,7 +499,8 @@ void *buffer;
          * with values from the buffer. Otherwise, write one value at a
          * time to the file
          *********************************************************************/
-         phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,NULL);
+         phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,
+						  NULL);
 	 if (phyBuffer != NULL) {
 	    if (!sX(ReadVarValues(CDF,Var,phyRecN,INT32_ZERO,
                                  Var->NphyRecValues,
@@ -544,7 +546,7 @@ void *buffer;
     * been written but then overwritten by the last one).
     **************************************************************************/
     tBuffer = (Byte1 *) buffer + (size_t) (nHypRecBytes * (rd->recCount - 1));
-    phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,NULL);
+    phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes, NULL);
     if (phyBuffer != NULL) {
        if (!sX(ReadVarValues(CDF,Var,phyRecN,INT32_ZERO,
                              Var->NphyRecValues, 
@@ -714,7 +716,8 @@ struct VarStruct *Var;
 				        tBuffer),&pStatus)) return pStatus;
                } else {
                  memmove((size_t) tOffset + (Byte1 *) phyBuffer, tBuffer,
-                         (size_t) (Var->NvalueBytes * nPhyDimValues[firstDim]));
+                         (size_t) (Var->NvalueBytes *
+                                   nPhyDimValues[firstDim]));
                }
 	     }
 	     else {
