@@ -147,7 +147,8 @@ void *buffer;
        * and extract values from the buffer. Otherwise, get one value at a
        * time from the file
        *******************************************************************/
-       phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,NULL);
+       phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,
+						 NULL);
        if (phyBuffer != NULL) {
          if (!sX(ReadVarValues64(CDF,Var,phyRecN,INT32_ZERO,Var->NphyRecValues,
                                  phyBuffer),&pStatus)) {
@@ -502,7 +503,8 @@ void *buffer;
          * with values from the buffer. Otherwise, write one value at a
          * time to the file
          *********************************************************************/
-         phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,NULL);
+         phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,
+						  NULL);
 	 if (phyBuffer != NULL) {
 	    if (!sX(ReadVarValues64(CDF,Var,phyRecN,INT32_ZERO,
                                    Var->NphyRecValues,
@@ -529,7 +531,8 @@ void *buffer;
          }
          if (phyBuffer != NULL) {
            if (!sX(WriteVarValues64(CDF,Var,phyRecN,INT32_ZERO,
-                                    (OFF_T) Var->NphyRecValues,phyBuffer),&pStatus)) {
+                                    (OFF_T) Var->NphyRecValues,phyBuffer),
+                   &pStatus)) {
 	     cdf_FreeMemory(phyBuffer,NULL);
 	     return pStatus;
 	   }
@@ -548,7 +551,7 @@ void *buffer;
     * been written but then overwritten by the last one).
     **************************************************************************/
     tBuffer = (Byte1 *) buffer + (size_t) (nHypRecBytes * (rd->recCount - 1));
-    phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes,NULL);
+    phyBuffer = (Byte1 *) cdf_AllocateMemory((size_t) Var->NphyRecBytes, NULL);
     if (phyBuffer != NULL) {
        if (!sX(ReadVarValues64(CDF,Var,phyRecN,INT32_ZERO,
                                Var->NphyRecValues, 
@@ -718,7 +721,8 @@ struct VarStruct *Var;
 				          tBuffer),&pStatus)) return pStatus;
                } else {
                  memmove((size_t) tOffset + (Byte1 *) phyBuffer, tBuffer,
-                         (size_t) (Var->NvalueBytes * nPhyDimValues[firstDim]));
+                         (size_t) (Var->NvalueBytes *
+                                   nPhyDimValues[firstDim]));
                }
 	     }
 	     else {
