@@ -1740,10 +1740,10 @@ struct CDFstruct *CDF;
       for (i = 0; i < 4; i++) {
 	 char aName[8+1];
 	 switch (i) {
-	   case 0: strcpy (aName, "VALIDMIN"); break;
-	   case 1: strcpy (aName, "VALIDMAX"); break;
-	   case 2: strcpy (aName, "SCALEMIN"); break;
-	   case 3: strcpy (aName, "SCALEMAX"); break;
+	   case 0: strcpyX (aName, "VALIDMIN", 8); break;
+	   case 1: strcpyX (aName, "VALIDMAX", 8); break;
+	   case 2: strcpyX (aName, "SCALEMIN", 8); break;
+	   case 3: strcpyX (aName, "SCALEMAX", 8); break;
 	 }
 	 tStatus = FindAttrByName (CDF,aName,&aOffset);
 	 switch (tStatus) {
@@ -2207,6 +2207,57 @@ long b;
   return MAXIMUM(a,b);
 }
 
+/******************************************************************************
+* FindNumberOfItems
+* Find the number of items in a string. Each item is delimited by the given
+* delimiter string.
+******************************************************************************/
+
+VISIBLE_PREFIX long FindNumberOfItems (string, numElems, delimiter)
+char *string;
+long numElems;
+char *delimiter;
+{
+  long count;
+  char *tmp, *tmp2, *tmp3;
+  int dlen = (int) strlen(delimiter);
+  tmp = malloc ((size_t) numElems+1);
+  memcpy (tmp, string, (size_t) numElems);
+  *(tmp+numElems) = '\0';
+  count = 1;
+  tmp2 = tmp;
+  tmp3 = strstr(tmp2, delimiter);
+  while (tmp3 != NULL) {
+    tmp2 = tmp3 + dlen;
+    ++count;
+    tmp3 = strstr(tmp2, delimiter);
+  }
+  free (tmp);
+  tmp = NULL;
+  return count;
+}
+
+/******************************************************************************
+* CDF_Free_String
+* This is used to free the dynamic space allocated by the CDF library for
+* reading the string-based variable attribute entry.
+******************************************************************************/
+
+VISIBLE_PREFIX void CDF_Free_String (numStrings, strings)
+long numStrings;
+char **strings;
+{
+  int ix;
+  for (ix = 0; ix < (int) numStrings; ++ix) {
+    free (strings[ix]);
+    strings[ix] = NULL;
+  }
+  if (strings != NULL) {
+    free (strings);
+    strings = NULL;
+  }
+}
+
 /******************************************************************************
 * AddTOvStats.
 ******************************************************************************/
@@ -2253,11 +2304,8 @@ int   totalBytes;
 int   numElems;
 {
   int i, j, k, l;
-/*  if ((totalBytes == numElems) && ((int)strlen(buffer) == totalBytes))
-      return; */
   l = totalBytes / numElems;
   for (i = 0; i < l; ++i) {
-/*  if ((int)strlen(buffer+i*numElems) >= numElems) continue; */
     for (j = 0; j < numElems; ++j) {
       if (*(buffer+i*numElems+j) == '\0') {
         for (k = j; k < numElems; ++k)
@@ -2268,6 +2316,33 @@ int   numElems;
   }
   return;
 }
+
+/******************************************************************************
+* FillNulsToString.
+* This function scans for Nul in a string buffer. If found, it fills Nul(s)
+* until the end of the number of elements. This happens when a string is
+* entered with a length shorter than the defined number of elements. The
+* buffer's size is a number of numElms, which could contain multiple strings.
+******************************************************************************/
+STATICforIDL void FillNulsToString (buffer, totalBytes, numElems)
+char  *buffer;
+int   totalBytes;
+int   numElems;
+{
+  int i, j, k, l;
+  l = totalBytes / numElems;
+  for (i = 0; i < l; ++i) {
+    for (j = 0; j < numElems; ++j) {
+      if (*(buffer+i*numElems+j) == '\0') {
+        for (k = j+1; k < numElems; ++k)
+          *(buffer+i*numElems+k) = '\0';
+        break;
+      }
+    }
+  }
+  return;
+}
+
 /******************************************************************************
 * DisplayVs.
 ******************************************************************************/
