@@ -545,8 +545,9 @@ OFF_T *offsetP;
     case STANDARD_:
     case SPARSE_RECORDS_: {
       if (Var->firstRecInVVR <= phyRecN && phyRecN <= Var->lastRecInVVR) {
-        *offsetP = Var->offsetOfVVR64 + (OFF_T) (VVR_BASE_SIZE64 + ((OFF_T)
-                           Var->NphyRecBytes) * (phyRecN - Var->firstRecInVVR));
+        *offsetP = Var->offsetOfVVR64 + (OFF_T) (VVR_BASE_SIZE64 +
+                   ((OFF_T) Var->NphyRecBytes) * (phyRecN -
+                                                  Var->firstRecInVVR));
 	break;
       }
       else {
@@ -626,7 +627,7 @@ OFF_T *offset;                  /* Out: Offset of ADR that was found. */
   {
       /************************************************************************
       * Read number of attributes and the offset of the first ADR from the GDR.
-      *************************************************************************/
+      ************************************************************************/
       if (!sX(ReadGDR64(CDF->fp,CDF->GDRoffset64,
                         GDR_NUMATTR,&numAttrs,
                         GDR_ADRHEAD,&fstADR,
@@ -637,10 +638,10 @@ OFF_T *offset;                  /* Out: Offset of ADR that was found. */
       * offset of zero for the next ADR.  For that reason, we will loop
       * through the number of attributes read from the GDR (and then stop).
       ************************************************************************/
-      if (CDF->CURattrOffset64 != (OFF_T) (OFF_T) RESERVED_ATTROFFSET64)                   
-        tOffset = CDF->CURattrOffset64;                                  
-      else                                                             
-        tOffset = fstADR;                                              
+      if (CDF->CURattrOffset64 != (OFF_T) (OFF_T) RESERVED_ATTROFFSET64)
+        tOffset = CDF->CURattrOffset64;
+      else
+        tOffset = fstADR;
 
       for (attrN = 0; attrN < numAttrs; attrN++) {
          if (!sX(ReadADR64(CDF->fp,tOffset,
@@ -710,9 +711,9 @@ OFF_T *offset;                  /* Out: The offset of the located ADR. */
 */
   pStatus = CDFlib(CONFIRM_, CDF_READONLY_MODE_, &read_only_mode, NULL_);
   if (pStatus != CDF_OK) return pStatus;
-  /***************************************************************************
+  /****************************************************************************
   * If in read only mode, set CurADRIndex to the searched for atribute number.
-  ***************************************************************************/
+  ****************************************************************************/
   if (read_only_mode == READONLYon)
   {
       if (CDF->fp->GDR64->NumAttr <= searchNum) return NO_SUCH_ATTR;
@@ -738,12 +739,12 @@ OFF_T *offset;                  /* Out: The offset of the located ADR. */
         tOffset = CDF->CURattrOffset64;
       else
         tOffset = fstADR;
-      /*************************************************************************
+      /************************************************************************
       * Read from ADRs until a matching attribute number is found.
       *   Note that if this is a V2.0 CDF, the last ADR will not have an
       * offset of zero for the next ADR.  For that reason, we will loop
       * through the number of attributes read from the GDR (and then stop).
-      *************************************************************************/
+      ************************************************************************/
       for (attrN = 0; attrN < numAttrs; attrN++) {
          if (!sX(ReadADR64(CDF->fp,tOffset,
 	                   ADR_NUM,&attrNum,
@@ -758,9 +759,9 @@ OFF_T *offset;                  /* Out: The offset of the located ADR. */
          else
            tOffset = fstADR;
       }
-      /*************************************************************************
+      /************************************************************************
       * Attribute number not found, internal error or corrupted CDF.
-      *************************************************************************/
+      ************************************************************************/
       return CORRUPTED_V3_CDF;
   };
 }
@@ -794,7 +795,7 @@ OFF_T *offset;                  /* Out: The offset of the located AEDR. */
   if (pStatus != CDF_OK) return pStatus;
   if (read_only_mode == READONLYon)
   {
-      /***********************************************************************
+      /************************************************************************
       * If the requested entry exists, set CurAEDRIndex to the entry number and
       * set CURzEntrySel to reflect if the entry is in the z list or the gr 
       * list.
@@ -887,8 +888,8 @@ OFF_T *lastOffset;              /* Out: Offset of last attribute's ADR. */
   else
   {
       /************************************************************************
-      * Read number of attributes and the offset of the first ADR.  If there are
-      * no attributes, return an offset of zero.
+      * Read number of attributes and the offset of the first ADR.  If there
+      * are no attributes, return an offset of zero.
       ************************************************************************/
       if (!sX(ReadGDR64(CDF->fp,CDF->GDRoffset64,
                         GDR_NUMATTR,&nAttrs,
@@ -899,9 +900,9 @@ OFF_T *lastOffset;              /* Out: Offset of last attribute's ADR. */
       }
       /************************************************************************
       * There is at least one attribute.
-      * Note that if this is a V2.0 CDF, the last ADR will not have an offset of
-      * zero for the next ADR.  For that reason, we will loop through the number
-      * of attributes read from the GDR (and then stop).
+      * Note that if this is a V2.0 CDF, the last ADR will not have an offset
+      * of zero for the next ADR.  For that reason, we will loop through the
+      * number of attributes read from the GDR (and then stop).
       ************************************************************************/
       if (!sX(ReadGDR64(CDF->fp,CDF->GDRoffset64,
                         GDR_ADRHEAD,&offset,
@@ -945,19 +946,19 @@ OFF_T *lastOffset;              /* Out: The offset of the last AEDR. */
       if (zEntry == TRUE)
       {
           CDF->fp->CurAEDRIndex = 
-                           CDF->fp->ADRList64[CDF->fp->CurADRIndex]->MAXzEntry;
+                        CDF->fp->ADRList64[CDF->fp->CurADRIndex]->MAXzEntry;
       }
       else
       {
           CDF->fp->CurAEDRIndex = 
-                           CDF->fp->ADRList64[CDF->fp->CurADRIndex]->MAXgrEntry;
+                        CDF->fp->ADRList64[CDF->fp->CurADRIndex]->MAXgrEntry;
       };
   }
   else
   {
       /************************************************************************
-      * Read offset of first AEDR and determine if there are any entries (of the
-      * specified type).  If there are none, pass back an offset of zero.
+      * Read offset of first AEDR and determine if there are any entries (of 
+      * the specified type).  If there are none, pass back an offset of zero.
       ************************************************************************/
       if (!sX(ReadADR64(CDF->fp,ADRoffset,
                         BOO(zEntry,ADR_AzEDRHEAD,ADR_AgrEDRHEAD),
@@ -967,8 +968,8 @@ OFF_T *lastOffset;              /* Out: The offset of the last AEDR. */
         return pStatus;
       }
       /************************************************************************
-      * There is at least one entry.  Read the actual number of entries and then
-      * scan through to the last one.
+      * There is at least one entry.  Read the actual number of entries and 
+      * then scan through to the last one.
       *   Note that if this is a V2.0 CDF, the last AEDR will not have an
       * offset of zero for the next AEDR.  For that reason, we will loop
       * through the number of entries (minus one) read from the ADR (and then
@@ -1176,7 +1177,7 @@ OFF_T *offset;          /* Out: offset of the VDR. */
   * Search for the variable from the current selected variabale, instead of
   * the top of the variable list. It will speed up the search process if the 
   * variables are accessed in a orderly sequence.
-  ****************************************************************************/   
+  ****************************************************************************/
   for (varN = 0; varN < nVars; varN++) {
      if (!sX(ReadVDR64(CDF,CDF->fp,tOffset,zVar,
 		       VDR_NUM,&varNum,
@@ -1789,8 +1790,8 @@ CDFstatus oError;
 * Decompress64.
 ******************************************************************************/
 
-STATICforIDL CDFstatus Decompress64 (iFp, iOffset, iSize, iError, cType, cParms,
-				     oFp, oOffset, oError)
+STATICforIDL CDFstatus Decompress64 (iFp, iOffset, iSize, iError, cType,
+				     cParms, oFp, oOffset, oError)
 vFILE *iFp;
 OFF_T iOffset;
 OFF_T iSize;
@@ -1900,7 +1901,7 @@ struct CDFstruct *CDF;
                                CDF->fp->ADRList64[i]->grAEDRList64[j]->Value, 
                                NULL);
                             CDF->fp->ADRList64[i]->grAEDRList64[j]->Value = 
-                                                                           NULL;
+                                                                        NULL;
                         };
                         cdf_FreeMemory(
                            CDF->fp->ADRList64[i]->grAEDRList64[j], NULL);
@@ -1919,7 +1920,8 @@ struct CDFstruct *CDF;
                             cdf_FreeMemory(
                                CDF->fp->ADRList64[i]->zAEDRList64[j]->Value, 
                                NULL);
-                            CDF->fp->ADRList64[i]->zAEDRList64[j]->Value = NULL;
+                            CDF->fp->ADRList64[i]->zAEDRList64[j]->Value =
+                                                                       NULL;
                         };
                         cdf_FreeMemory(CDF->fp->ADRList64[i]->zAEDRList64[j],
                                        NULL);
