@@ -48,7 +48,7 @@ STATICforIDL CDFstatus CDFope (Va, Cur)
 struct VAstruct *Va;
 struct CurStruct *Cur;
 {
-CDFstatus pStatus = CDF_OK;
+CDFstatus pStatus = CDF_OK, status;
 
 switch (Va->item) {
   /****************************************************************************
@@ -264,6 +264,7 @@ switch (Va->item) {
     CDF->CURzVarOffset64 = (OFF_T) 0;
     CDF->CURrVarOffset = 0;
     CDF->CURrVarOffset64 = (OFF_T) 0;
+    CDF->leapSecondUpdated = 0;
     /**************************************************************************
     * Read necessary fields from the CDR and GDR.
     **************************************************************************/
@@ -375,7 +376,8 @@ switch (Va->item) {
           return pStatus;
         }   
       } else {
-        pStatus = ValidateCDF64(CDF,CDF->fp,CDF->CDRoffset64,CDF->eof64, debug);
+        pStatus = ValidateCDF64(CDF,CDF->fp,CDF->CDRoffset64,CDF->eof64,
+                                debug);
         if (pStatus != CDF_OK) {
           AbortAccess64 (CDF, noUPDATE, noDELETE);
           cdf_FreeMemory (CDF, NULL);
@@ -384,7 +386,6 @@ switch (Va->item) {
           if (pStatus == CORRUPTED_V3_CDF) {
             char vri[6];
             long libver, librel, libinc;
-            CDFstatus status;
             snprintf (vri, (size_t) 6, "%1.1d.%1.1d.%1.1d", (int) version,
                       (int) release, (int) increment);
             status = CDFlib (GET_, LIB_VERSION_, &libver,
@@ -598,11 +599,12 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
     count = (int) (maxRec + 1);
     if (numDims > 0)
       for (j = 0; j < (int) numDims; ++j) count *= (int) dimSizes[j];
-    buffer = (void *) malloc ((size_t) (count * sizeof(long long)));
+    buffer = (void *) malloc ((size_t) (count * 8));
     if (buffer == NULL) return BAD_MALLOC;
     status =  CDFgetVarAllRecordsByVarID (id, 1, (long) i, buffer);
     if (status < CDF_OK) {
       free (buffer);
+      buffer = NULL;
       return status;
     } 
     for (j = 0; j < count; ++j) {
@@ -610,6 +612,7 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
         tt2000 = *(((long long *)buffer)+j);
     }
     free (buffer);
+    buffer = NULL;
   }
   status = CDFlib(GET_, rVARs_NUMDIMS_, &numDims,
                         rVARs_DIMSIZES_, dimSizes,
@@ -631,11 +634,12 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
     count = (int) (maxRec + 1);
     if (numDims > 0) 
       for (j = 0; j < (int) numDims; ++j) count *= (int) dimSizes[j];
-    buffer = (void *) malloc ((size_t) (count * sizeof(long long)));
+    buffer = (void *) malloc ((size_t) (count * 8));
     if (buffer == NULL) return BAD_MALLOC;
     status =  CDFgetVarAllRecordsByVarID (id, 0, (long) i, buffer);
     if (status < CDF_OK) {
       free (buffer);
+      buffer = NULL;
       return status;
     }
     for (j = 0; j < count; ++j) {
@@ -643,6 +647,7 @@ static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
         tt2000 = *(((long long *)buffer)+j);
     }
     free (buffer);
+    buffer = NULL;
   }
   if (tt2000 != DEFAULT_TT2000_PADVALUE) {
     breakdownTT2000 (tt2000, &yy, &mm, &dd, &hh, &mn, &ss, &ml, &ms, &ns);
