@@ -841,7 +841,11 @@ switch (Va->item) {
 	   CDF->CURzEntryNum) == RESERVED_ENTRYNUM) return NO_ENTRY_SELECTED;
     if (!ValidDataType((Int32)dataType) || InValidDataType((Int32)dataType))
       return BAD_DATA_TYPE;
-    if (numElems < 1) return BAD_NUM_ELEMS;
+    if (!STRINGdataType(dataType) && numElems < 1) return BAD_NUM_ELEMS;
+    if (STRINGdataType(dataType) && numElems < 1) {
+      if ((*((unsigned char *)value)) == '\0') numElems = 1;
+      else return BAD_NUM_ELEMS;
+    }
     if (!sX(ReadADR(CDF->fp,CDF->CURattrOffset,
 		    ADR_RECORD,&ADR,
 		    ADR_NULL),&pStatus)) {
@@ -850,6 +854,13 @@ switch (Va->item) {
     }
     if (!sX(CheckEntryOp(CDF,entryType),&pStatus)) return pStatus;
     if (!WriteAccess(CDF,FALSE,&pStatus)) return pStatus;
+    if (STRINGdataType(dataType)) {
+      int cnt;
+/*
+      if (UTF8Check((unsigned char *)value, (int) numElems, &cnt) != NULL)
+	pStatus = STRING_NOT_UTF8_ENCODING;
+*/
+    }
     nBytesNew = (int) (CDFelemSize(dataType) * numElems);
     eOffset = E3(entryType,CDF->CURgrEntryOffset,
 			   CDF->CURgrEntryOffset,
@@ -1056,7 +1067,7 @@ switch (Va->item) {
   }
   /****************************************************************************
    * rENTRY_STRINGSDATA_/zENTRY_STRINGSDATA_, 
-   ****************************************************************************/
+   ***************************************************************************/
   case rENTRY_STRINGSDATA_:
   case zENTRY_STRINGSDATA_: {
     Logical zOp = (Va->item == zENTRY_STRINGSDATA_);
@@ -1101,7 +1112,7 @@ switch (Va->item) {
     if (eOffset != (Int32) RESERVED_ENTRYOFFSET) {
       /************************************************************************
        * The entry already exists.
-       ************************************************************************/
+       ***********************************************************************/
       struct AEDRstruct AEDR; int nBytesCur;
       if (!sX(ReadAEDR(CDF->fp,eOffset,
                        AEDR_RECORD,&AEDR,NULL,
@@ -1177,7 +1188,7 @@ switch (Va->item) {
     else {
       /************************************************************************
        * The entry does not exist.
-       ************************************************************************/
+       ***********************************************************************/
       struct AEDRstruct AEDR;
       Int32 lastOffset;
       zEntry = BOO(!zOp,FALSE, BOO(zModeON(CDF),
@@ -1268,6 +1279,7 @@ switch (Va->item) {
       }
     }
     free (tmpStr);
+    tmpStr = NULL;
     break;
   }
 }
