@@ -333,7 +333,7 @@ switch (Va->item) {
 	  return CDF_CREATE_ERROR;
 	}
 	pCount = CompressionParmsCount ((Int32) cType);
-	CPR.RecordSize = CPR_BASE_SIZE64 + (pCount * sizeof(Int32));
+	CPR.RecordSize = CPR_BASE_SIZE64 + (pCount * 4);
 	CPR.RecordType = CPR_;
 	CPR.rfuA = 0;
 	CPR.cType = (Int32) cType;
@@ -485,7 +485,7 @@ switch (Va->item) {
       case GZIP_COMPRESSION:
 	pCount = CompressionParmsCount ((Int32) cType);
 	SetBit32 (&VDR.Flags, VDR_COMPRESSION_BIT);
-	CPR.RecordSize = CPR_BASE_SIZE64 + (pCount * sizeof(Int32));
+	CPR.RecordSize = CPR_BASE_SIZE64 + (pCount * 4);
 	CPR.RecordType = CPR_;
 	CPR.cType = (Int32) cType;
 	CPR.rfuA = 0;
@@ -881,7 +881,11 @@ switch (Va->item) {
 	   CDF->CURgrEntryNum,
 	   CDF->CURzEntryNum) == RESERVED_ENTRYNUM) return NO_ENTRY_SELECTED;
     if (!ValidDataType((Int32)dataType)) return BAD_DATA_TYPE;
-    if (numElems < 1L) return BAD_NUM_ELEMS;
+    if (!STRINGdataType(dataType) && numElems < 1L) return BAD_NUM_ELEMS;
+    if (STRINGdataType(dataType) && numElems < 1L) {
+      if ((*((unsigned char *)value)) == '\0') numElems = 1L;
+      else return BAD_NUM_ELEMS;
+    }
     if (!sX(ReadADR64(CDF->fp,CDF->CURattrOffset64,
 		      ADR_RECORD,&ADR,
 		      ADR_NULL),&pStatus)) {
@@ -893,6 +897,13 @@ switch (Va->item) {
     if (dataType == CDF_TIME_TT2000) {
       if (!UpdateTT2000header(CDF,&pStatus)) return pStatus;
     }
+    if (STRINGdataType(dataType)) {
+      int cnt;
+/*
+      if (UTF8Check((unsigned char *)value, (int) numElems, &cnt) != NULL)
+	pStatus = STRING_NOT_UTF8_ENCODING;
+*/
+    }
     nBytesNew = (int) (CDFelemSize(dataType) * numElems);
     eOffset = E3(entryType,CDF->CURgrEntryOffset64,
 			   CDF->CURgrEntryOffset64,
@@ -930,6 +941,13 @@ switch (Va->item) {
 	AEDR.RecordSize = AEDR_BASE_SIZE64 + nBytesNew;
 	AEDR.DataType = dataType;
 	AEDR.NumElems = numElems;
+        if ((Va->item == rENTRY_DATA_ || Va->item == zENTRY_DATA_) &&
+            STRINGdataType(dataType)) {
+          long numStrings = FindNumberOfItems ((char *)value, numElems,
+                                               STRINGDELIMITER);
+          AEDR.NumStrings = numStrings;
+        } else
+          AEDR.NumStrings = 0;
 	if (!sX(WriteAEDR64(CDF,CDF->fp,newOffset,
 			    AEDR_RECORD,&AEDR,value,
 			    AEDR_NULL),&pStatus)) {
@@ -961,13 +979,19 @@ switch (Va->item) {
 	    return pStatus;
 	  }
 	}
-      }
-      else {
+      } else {
 	/********************************************************************
 	* The AEDR is not changing size.
 	********************************************************************/
 	AEDR.DataType = dataType;
 	AEDR.NumElems = numElems;
+        if ((Va->item == rENTRY_DATA_ || Va->item == zENTRY_DATA_) &&
+            STRINGdataType(dataType)) {
+          long numStrings = FindNumberOfItems ((char *)value, numElems,
+                                               STRINGDELIMITER);
+          AEDR.NumStrings = numStrings;
+        } else
+          AEDR.NumStrings = 0;
 	if (!sX(WriteAEDR64(CDF,CDF->fp,eOffset,
 			    AEDR_RECORD,&AEDR,value,
 			    AEDR_NULL),&pStatus)) {
@@ -975,8 +999,7 @@ switch (Va->item) {
 	  return pStatus;
 	}
       }
-    }
-    else {
+    } else {
       /************************************************************************
       * The entry does not exist.
       ************************************************************************/
@@ -997,7 +1020,13 @@ switch (Va->item) {
       AEDR.DataType = dataType;
       AEDR.Num = entryN;
       AEDR.NumElems = numElems;
-      AEDR.rfuA = 0;
+      if ((Va->item == rENTRY_DATA_ || Va->item == zENTRY_DATA_) &&
+          STRINGdataType(dataType)) {
+        long numStrings = FindNumberOfItems ((char *)value, numElems,
+                                             STRINGDELIMITER);
+        AEDR.NumStrings = numStrings;
+      } else
+        AEDR.NumStrings = 0;
       AEDR.rfuB = 0;
       AEDR.rfuC = 0;
       AEDR.rfuD = -1;
@@ -1077,6 +1106,223 @@ switch (Va->item) {
     }
     break;
   }
+  /****************************************************************************
+  * rENTRY_STRINGSDATA_/zENTRY_STRINGSDATA_, 
+  ****************************************************************************/
+  case rENTRY_STRINGSDATA_:
+  case zENTRY_STRINGSDATA_: {
+    Logical zOp = (Va->item == zENTRY_STRINGSDATA_);
+    struct CDFstruct *CDF;
+    struct ADRstruct64 ADR;
+    long entryN;                /* True entry number. */
+    Logical zEntry;             /* If true, a AzEDR.  If FALSE, a AgrEDR. */
+    long dataType, numElems;
+    OFF_T eOffset;              /* Offset of AEDR. */
+    int ix, length; char *tmpStr, *cstr;
+    long numStrings = va_arg (Va->ap, long);
+    char **values = va_arg (Va->ap, char **);
+    SelectCDF (Cur->cdf, CDF)
+    if (!CURRENTattrSELECTED64(CDF)) return NO_ATTR_SELECTED;
+    if ((!zOp?CDF->CURgrEntryNum:CDF->CURzEntryNum) == RESERVED_ENTRYNUM)
+      return NO_ENTRY_SELECTED;
+    if (numStrings < 1) return BAD_NUM_STRINGS;
+    length = 0;
+    for (ix = 0; ix < numStrings; ++ix) {
+      length += (int) strlen(values[ix]);
+    }
+    dataType = CDF_CHAR;
+    numElems = length + (long) strlen(STRINGDELIMITER) * (numStrings-1);
+    tmpStr = (char *) malloc (sizeof(char)*numElems);
+    cstr = tmpStr;
+    for (ix = 0; ix < numStrings; ++ix) {
+      memcpy (cstr, values[ix], strlen(values[ix])); 
+      if (ix != (numStrings - 1)) {
+        cstr += strlen(values[ix]);
+        memcpy (cstr, STRINGDELIMITER, strlen(STRINGDELIMITER));
+        cstr += (int) strlen(STRINGDELIMITER);
+      }
+    }
+    if (!sX(ReadADR64(CDF->fp,CDF->CURattrOffset64,
+		      ADR_RECORD,&ADR,
+		      ADR_NULL),&pStatus)) {
+      AbortAccess64 (CDF, UPDATE, noDELETE);
+      return pStatus;
+    }
+    if (!WriteAccess64(CDF,FALSE,&pStatus)) return pStatus;
+    eOffset = (!zOp?CDF->CURgrEntryOffset64:CDF->CURzEntryOffset64);
+    if (eOffset != (OFF_T) RESERVED_ENTRYOFFSET64) {
+      /************************************************************************
+      * The entry already exists.
+      ************************************************************************/
+      struct AEDRstruct64 AEDR; int nBytesCur;
+      if (!sX(ReadAEDR64(CDF->fp,eOffset,
+		         AEDR_RECORD,&AEDR,NULL,
+		         AEDR_NULL),&pStatus)) {
+	AbortAccess64 (CDF, UPDATE, noDELETE);
+	return pStatus;
+      }
+      nBytesCur = (int) (CDFelemSize(AEDR.DataType) * AEDR.NumElems);
+      zEntry = (AEDR.RecordType == AzEDR_);
+      if (numElems != nBytesCur) {
+	/********************************************************************
+	* The size of the new entry value is different than the size of the
+	* old entry value.  The AEDR is changing size.
+	********************************************************************/
+	OFF_T prevOffset, newOffset;
+	if (!sX(FindPrevEntry64(CDF,CDF->CURattrOffset64,eOffset,
+			        zEntry,&prevOffset),&pStatus)) {
+	  AbortAccess64 (CDF, UPDATE, noDELETE);
+	  return pStatus;
+	}
+	if (!sX(ResizeIR64(CDF,eOffset,
+			   AEDR_BASE_SIZE64+numElems,
+			   &newOffset,TRUE,NULL),&pStatus)) {
+	  AbortAccess64 (CDF, UPDATE, noDELETE);
+	  return pStatus;
+	}
+	AEDR.RecordSize = AEDR_BASE_SIZE64 + numElems;
+	AEDR.DataType = dataType;
+	AEDR.NumElems = numElems;
+        AEDR.NumStrings = numStrings;
+	if (!sX(WriteAEDR64(CDF,CDF->fp,newOffset,
+			    AEDR_RECORD,&AEDR,tmpStr,
+			    AEDR_NULL),&pStatus)) {
+	  AbortAccess64 (CDF, UPDATE, noDELETE);
+	  return pStatus;
+	}
+	if (!zOp) 
+	    CDF->CURgrEntryOffset64 = newOffset;
+	else
+	    CDF->CURzEntryOffset64 = newOffset;
+	if (prevOffset == 0) {
+	  if (!sX(WriteADR64(CDF->fp,CDF->CURattrOffset64,
+			     BOO(zEntry,ADR_AzEDRHEAD,ADR_AgrEDRHEAD),&newOffset,
+			     ADR_NULL),&pStatus)) {
+	    AbortAccess64 (CDF, UPDATE, noDELETE);
+	    return pStatus;
+	  }
+	}
+	else {
+	  if (!sX(WriteAEDR64(CDF,CDF->fp,prevOffset,
+			      AEDR_AEDRNEXT,&newOffset,
+			      AEDR_NULL),&pStatus)) {
+	    AbortAccess64 (CDF, UPDATE, noDELETE);
+	    return pStatus;
+	  }
+	}
+      }
+      else {
+	/********************************************************************
+	* The AEDR is not changing size.
+	********************************************************************/
+	AEDR.DataType = dataType;
+	AEDR.NumElems = numElems;
+        AEDR.NumStrings = numStrings;
+	if (!sX(WriteAEDR64(CDF,CDF->fp,eOffset,
+			    AEDR_RECORD,&AEDR,tmpStr,
+			    AEDR_NULL),&pStatus)) {
+	  AbortAccess64 (CDF, UPDATE, noDELETE);
+	  return pStatus;
+	}
+      }
+    }
+    else {
+      /************************************************************************
+      * The entry does not exist.
+      ************************************************************************/
+      struct AEDRstruct64 AEDR;
+      OFF_T lastOffset;
+      zEntry = BOO(!zOp,FALSE, BOO(zModeON(CDF),
+		   BOO(CDF->CURzEntryNum < CDF->NrVars,FALSE,TRUE),TRUE));
+      entryN = BOO(!zOp,CDF->CURgrEntryNum,
+		   BOO(zModeON(CDF), BOO(CDF->CURzEntryNum < CDF->NrVars,
+			                 CDF->CURzEntryNum,CDF->CURzEntryNum -
+                                                           CDF->NrVars),
+		                         CDF->CURzEntryNum));
+      AEDR.RecordSize = AEDR_BASE_SIZE64 + numElems;
+      AEDR.RecordType = BOO(zEntry,AzEDR_,AgrEDR_);
+      AEDR.AEDRnext = (OFF_T) 0;
+      AEDR.AttrNum = ADR.Num;
+      AEDR.DataType = dataType;
+      AEDR.Num = entryN;
+      AEDR.NumElems = numElems;
+      AEDR.NumStrings = numStrings;
+      AEDR.rfuB = 0;
+      AEDR.rfuC = 0;
+      AEDR.rfuD = -1;
+      AEDR.rfuE = -1;
+      if (!sX(AllocateIR64(CDF,AEDR.RecordSize,&eOffset),&pStatus)) {
+	AbortAccess64 (CDF, UPDATE, noDELETE);
+	return pStatus;
+      }
+      if (!sX(WriteAEDR64(CDF,CDF->fp,eOffset,
+			  AEDR_RECORD,&AEDR,tmpStr,
+			  AEDR_NULL),&pStatus)) {
+	AbortAccess64 (CDF, UPDATE, noDELETE);
+	return pStatus;
+      }
+      if (!zOp) 
+	  CDF->CURgrEntryOffset64 = eOffset;
+      else
+	  CDF->CURzEntryOffset64 = eOffset;
+      if (!sX(FindLastEntry64(CDF,CDF->CURattrOffset64,
+			      zEntry,&lastOffset),&pStatus)) {
+	AbortAccess64 (CDF, UPDATE, noDELETE);
+	return pStatus;
+      }
+      if (lastOffset == (OFF_T) 0) {
+	/********************************************************************
+	* This is the first entry (of this type).  The ADR will point to
+	* this entry.
+	********************************************************************/
+	if (zEntry) {
+	  ADR.NzEntries = 1;
+	  ADR.MAXzEntry = entryN;
+	  ADR.AzEDRhead = eOffset;
+	}
+	else {
+	  ADR.NgrEntries = 1;
+	  ADR.MAXgrEntry = entryN;
+	  ADR.AgrEDRhead = eOffset;
+	}
+	if (!sX(WriteADR64(CDF->fp,CDF->CURattrOffset64,
+			   ADR_RECORD,&ADR,
+			   ADR_NULL),&pStatus)) {
+	  AbortAccess64 (CDF, UPDATE, noDELETE);
+	  return pStatus;
+	}
+      }
+      else {
+	/********************************************************************
+	* Entries already exist (of this type).  The currently last entry
+	* will point to this entry.
+	********************************************************************/
+	if (zEntry) {
+	  ADR.NzEntries++;
+	  ADR.MAXzEntry = MAXIMUM(ADR.MAXzEntry,entryN);
+	}
+	else {
+	  ADR.NgrEntries++;
+	  ADR.MAXgrEntry = MAXIMUM(ADR.MAXgrEntry,entryN);
+	}
+	if (!sX(WriteADR64(CDF->fp,CDF->CURattrOffset64,
+			   ADR_RECORD,&ADR,
+			   ADR_NULL),&pStatus)) {
+	  AbortAccess64 (CDF, UPDATE, noDELETE);
+	  return pStatus;
+	}
+	if (!sX(WriteAEDR64(CDF,CDF->fp,lastOffset,
+			    AEDR_AEDRNEXT,&eOffset,
+			    AEDR_NULL),&pStatus)) {
+	  AbortAccess64 (CDF, UPDATE, noDELETE);
+	  return pStatus;
+	}
+      }
+    }
+    free (tmpStr);
+    tmpStr = NULL;
+    break;
+  }
 }
 return pStatus;
 }
