@@ -29,9 +29,9 @@
 *                               eliminate the potential buffer overflow.
 *   V3.3  28-Jul-08, M Liu      Modified to remove checks for wasted space as 
 *                               it is handled by cdfread.c for V2 CDF.
-*   V3.3a 15-Sep-08, M Liu      Modified ReadAEDRList64 to pass in the number of
-*                               entries to set up the list, not just the last
-*                               entry number. 
+*   V3.3a 15-Sep-08, M Liu      Modified ReadAEDRList64 to pass in the number
+*                               of entries to set up the list, not just the
+*                               last entry number. 
 *   V3.4  12-Aug-10, M Liu      Replaced strcpy by strcpyX in ReadVDR. 
 *
 ******************************************************************************/
@@ -242,8 +242,12 @@ va_dcl
        case CDR_GDROFFSET: {
 	 OFF_T *buffer = va_arg (ap, OFF_T *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case CDR_RECORDSIZE: tOffset += (OFF_T) CDR_RECORDSIZE_OFFSET64; break;
-	   case CDR_GDROFFSET: tOffset += (OFF_T) CDR_GDROFFSET_OFFSET64; break;
+	   case CDR_RECORDSIZE:
+	     tOffset += (OFF_T) CDR_RECORDSIZE_OFFSET64;
+	     break;
+	   case CDR_GDROFFSET:
+	     tOffset += (OFF_T) CDR_GDROFFSET_OFFSET64;
+	     break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
          if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
@@ -254,12 +258,16 @@ va_dcl
 	 Int32 *buffer = va_arg (ap, Int32 *);
 	 OFF_T tOffset = offset;
 	 switch (field) {
-	   case CDR_RECORDTYPE: tOffset += (OFF_T) CDR_RECORDTYPE_OFFSET64; break;
+	   case CDR_RECORDTYPE:
+	     tOffset += (OFF_T) CDR_RECORDTYPE_OFFSET64;
+	     break;
 	   case CDR_VERSION: tOffset += (OFF_T) CDR_VERSION_OFFSET64; break;
 	   case CDR_RELEASE: tOffset += (OFF_T) CDR_RELEASE_OFFSET64; break;
 	   case CDR_ENCODING: tOffset += (OFF_T) CDR_ENCODING_OFFSET64; break;
 	   case CDR_FLAGS: tOffset += (OFF_T) CDR_FLAGS_OFFSET64; break;
-	   case CDR_INCREMENT: tOffset += (OFF_T) CDR_INCREMENT_OFFSET64; break;
+	   case CDR_INCREMENT:
+	     tOffset += (OFF_T) CDR_INCREMENT_OFFSET64;
+	     break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
@@ -307,7 +315,8 @@ va_dcl
   ***************************************************************************/
   if (read_only_mode == READONLYon && fp->GDR64 == NULL)
   {
-      fp->GDR64 = cdf_AllocateMemory((size_t)sizeof(struct GDRstruct64), NULL);
+      fp->GDR64 = cdf_AllocateMemory((size_t)sizeof(struct GDRstruct64),
+                                     NULL);
       if (fp->GDR64 == NULL) return CRE;
       if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
       if (!Read64_64(fp,&(fp->GDR64->RecordSize))) return CRE;
@@ -656,11 +665,11 @@ va_dcl
   {
       return NO_ATTR_SELECTED;
   };
-  /***************************************************************************
+  /****************************************************************************
   * For whatever ADR data is selected, if READONLYon, read the data from memory
   * using CurADRIndex to select the correct ADR from the ADRList. Otherwise,
   * read the data from the file/cache using the file offset.
-  ***************************************************************************/
+  ****************************************************************************/
   for (;;) {
      int field = va_arg (ap, int);
      switch (field) {
@@ -891,7 +900,7 @@ va_dcl
 #endif
   pStatus = CDFlib(CONFIRM_, CDF_READONLY_MODE_, &read_only_mode, NULL_);
   if (pStatus != CDF_OK) return pStatus;
-  /***************************************************************************
+  /****************************************************************************
   * If READONLYon and either an attribute or an entry have not been selected,
   * return the appropriate status. If they have been selected but there is no
   * entry for the selected attribute, return BAD_ENTRY_NUM.  Note that for each
@@ -900,7 +909,7 @@ va_dcl
   * attribute, the entry list has a NULL pointer for that entry. Note also that
   * the reading of ADRs and AEDRs into memory is triggered by the 1st time an
   * ADR (or AEDR) is selected.
-  ***************************************************************************/
+  ***********************************************************************.****/
   if (read_only_mode == READONLYon)
   {
       if (fp->CurADRIndex == RESERVED_ENTRYNUM)
@@ -913,11 +922,11 @@ va_dcl
       }
       else if (fp->CURzEntrySel)
       {
-          if (fp->ADRList64[fp->CurADRIndex]->zAEDRList64[fp->CurAEDRIndex] 
-              != NULL)
+          if (fp->ADRList64[fp->CurADRIndex]->zAEDRList64[fp->CurAEDRIndex] != 
+              NULL)
           {
               CurAEDR =
-                  fp->ADRList64[fp->CurADRIndex]->zAEDRList64[fp->CurAEDRIndex];
+                fp->ADRList64[fp->CurADRIndex]->zAEDRList64[fp->CurAEDRIndex];
           }
           else
           {
@@ -930,7 +939,7 @@ va_dcl
               NULL)
           {
               CurAEDR =
-                 fp->ADRList64[fp->CurADRIndex]->grAEDRList64[fp->CurAEDRIndex];
+                fp->ADRList64[fp->CurADRIndex]->grAEDRList64[fp->CurAEDRIndex];
           }
           else
           {
@@ -939,9 +948,9 @@ va_dcl
       };
   };
   /***************************************************************************
-  * For whatever AEDR data is selected, if READONLYon, read the data from memory
-  * using CurADRIndex and CurAEDRIndex to select the correct AEDR from the
-  * AEDRList. Otherwise, read the data from the file/cache using the file
+  * For whatever AEDR data is selected, if READONLYon, read the data from
+  * memory using CurADRIndex and CurAEDRIndex to select the correct AEDR from
+  * the AEDRList. Otherwise, read the data from the file/cache using the file
   * offset.
   ***************************************************************************/
   for (;;) {
@@ -1671,7 +1680,9 @@ va_dcl
 	   case CCR_RECORDSIZE:
              tOffset += (OFF_T) CCR_RECORDSIZE_OFFSET64;
              break;
-	   case CCR_CPROFFSET: tOffset += (OFF_T) CCR_CPROFFSET_OFFSET64; break;
+	   case CCR_CPROFFSET:
+	     tOffset += (OFF_T) CCR_CPROFFSET_OFFSET64;
+	     break;
 	   case CCR_USIZE: tOffset += (OFF_T) CCR_USIZE_OFFSET64; break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
@@ -1916,9 +1927,9 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
   Int32 i;
   OFF_T temp;
 
-  /**************************************************************************
+  /***************************************************************************
   * Allocate memory for the list of ADRs 
-  ***************************************************************************/
+  ****************************************************************************/
   if (fp->GDR64->NumAttr > 0)
   fp->ADRList64 = cdf_AllocateMemory((size_t)fp->GDR64->NumAttr * 
                                      sizeof(struct ADRstruct64**), NULL);
@@ -1986,9 +1997,9 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
 /******************************************************************************
 * ReadAEDRList64.
 * Reads the set of entrys (zENTRYs or grENTRYs) associated with an attribute
-* into a list indexed by the entry number. If there is no entry for a particular
-* index (i.e., there is no entry for the associated variable/attribute
-* pair), the list entry is NULL.
+* into a list indexed by the entry number. If there is no entry for a
+* particular index (i.e., there is no entry for the associated
+* variable/attribute pair), the list entry is NULL.
 ******************************************************************************/
 STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp, 
                                        struct AEDRstructExt64 ***AEDRList, 
