@@ -27,8 +27,8 @@
 *                               variable for GET/PUT/DELETE/CLOSE operation.
 *   V3.2  20-Jun-07, D Berger   Added clearing of READONLY mode metadata state
 *                               info when READONLYon selected.
-*   V3.2a 29-AUG-07, D Berger   Removed clearing of READONLY mode metadata state
-*                               info when zMODE selected.
+*   V3.2a 29-AUG-07, D Berger   Removed clearing of READONLY mode metadata
+*                               state info when zMODE selected.
 *
 ******************************************************************************/
 
@@ -220,7 +220,8 @@ switch (Va->item) {
     if (scratchDir == NULL) return BAD_SCRATCH_DIR;
     length = strlen (scratchDir);
     if (length > DU_MAX_DIR_LEN) return BAD_SCRATCH_DIR;
-    CDF->scratchDir = (char *) cdf_AllocateMemory ((size_t) (length + 1), NULL);
+    CDF->scratchDir = (char *) cdf_AllocateMemory ((size_t) (length + 1),
+                                                   NULL);
     if (CDF->scratchDir == NULL) {
       AbortAccess (CDF, UPDATE, noDELETE);
       return BAD_MALLOC;
