@@ -28,8 +28,8 @@
 *   V2.1  29-Jun-04, M Liu      Added LFS (Large File Support > 2G).
 *   V3.2  20-Jun-07, D Berger   Added clearing of READONLY mode metadata state
 *                               info when READONLYon selected.
-*   V3.2a 29-Aug-07, D Berger   Removed clearing of READONLY mode metadata state
-*                               info when zMODE selected.
+*   V3.2a 29-Aug-07, D Berger   Removed clearing of READONLY mode metadata
+*                               state info when zMODE selected.
 *
 ******************************************************************************/
 
@@ -223,7 +223,8 @@ switch (Va->item) {
     if (scratchDir == NULL) return BAD_SCRATCH_DIR;
     length = strlen (scratchDir);
     if (length > DU_MAX_DIR_LEN) return BAD_SCRATCH_DIR;
-    CDF->scratchDir = (char *) cdf_AllocateMemory ((size_t) (length + 1), NULL);
+    CDF->scratchDir = (char *) cdf_AllocateMemory ((size_t) (length + 1),
+                                                   NULL);
     if (CDF->scratchDir == NULL) {
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return BAD_MALLOC;
@@ -772,7 +773,8 @@ switch (Va->item) {
   case ATTR_:
   case ATTR_NAME_: {
     Logical nameOp = (Va->item == ATTR_NAME_);
-    long attrNum; char *attrName; struct CDFstruct *CDF; OFF_T offset;
+    long attrNum = -1L; char *attrName = NULL; struct CDFstruct *CDF;
+    OFF_T offset;
     if (nameOp)
       attrName = va_arg (Va->ap, char *);
     else {
