@@ -40,11 +40,10 @@ char *copyRight;
   strcpyX (copyRight,
 "\012\
 Common Data Format (CDF)\012\
-(C) Copyright 1990-2015 NASA/GSFC\012\
+https://cdf.gsfc.nasa.gov\012\
 Space Physics Data Facility\012\
 NASA/Goddard Space Flight Center\012\
-Greenbelt, Maryland 20771 USA\012\
-(Internet -- GSFC-CDF-SUPPORT@LISTS.NASA.GOV)\012", CDF_COPYRIGHT_LEN);
+Greenbelt, Maryland 20771 USA\012", CDF_COPYRIGHT_LEN);
   return;
 }
 
@@ -571,7 +570,8 @@ break;
 
 case NOT_A_CDF_OR_NOT_SUPPORTED:
 strcpyX (textPtr,
-"NOT_A_CDF_OR_NOT_SUPPORTED: Named CDF is corrupted or not supported by the current library version.",
+"NOT_A_CDF_OR_NOT_SUPPORTED: Named CDF is corrupted or not supported by "
+"the current library version.",
 CDF_STATUSTEXT_LEN);
 break;
 
@@ -745,13 +745,15 @@ break;
 
 case TT2000_TIME_ERROR:
 strcpyX (textPtr,
-"TT2000_TIME_ERROR: Error handling the date/time for TT2000 or a TT2000 epoch.",
+"TT2000_TIME_ERROR: Error handling the date/time for TT2000 or a TT2000 "
+"epoch.",
 CDF_STATUSTEXT_LEN);
 break;
 
 case UNABLE_TO_PROCESS_CDF:
 strcpyX (textPtr,
-"UNABLE_TO_PROCESS_CDF: One of data fields is invalid... Upgrade the library might fix the problem.",
+"UNABLE_TO_PROCESS_CDF: One of data fields is invalid... Upgrade the library "
+"might fix the problem.",
 CDF_STATUSTEXT_LEN);
 break;
 
@@ -769,31 +771,85 @@ break;
 
 case ILLEGAL_EPOCH_FIELD:
 strcpyX (textPtr,
-"ILLEGAL_EPOCH_FIELD: One or more of the date/time fields is out of valid range.",
+"ILLEGAL_EPOCH_FIELD: One or more of the date/time fields is out of valid "
+"range.",
 CDF_STATUSTEXT_LEN);
 break;
 
 case CANNOT_INSERT_RECORDS:
 strcpyX (textPtr,
-"CANNOT_INSERT_RECORDS: Cannot insert records to a variable with sparserecords.",
+"CANNOT_INSERT_RECORDS: Cannot insert records to a variable with "
+"sparserecords.",
 CDF_STATUSTEXT_LEN);
 break;
 
 case TT2000_CDF_MAYNEEDUPDATE:
 strcpyX (textPtr,
-"TT2000_CDF_MAYNEEDUPDATE: CDF version or its file-based template may need to upgrade to handle TT2000 data properly (even its value may be valid).",
+"TT2000_CDF_MAYNEEDUPDATE: CDF version or its file-based template may need to "
+"upgrade to handle TT2000 data properly (even its value may be valid).",
 CDF_STATUSTEXT_LEN);
 break;
 
 case TT2000_USED_OUTDATED_TABLE:
 strcpyX (textPtr,
-"TT2000_USED_OUTDATED_TABLE: A TT2000 data is either invalid (made with an oudated leap second table) or trying to use an outdated leap second table.",
+"TT2000_USED_OUTDATED_TABLE: A TT2000 data is either invalid (made with an "
+"oudated leap second table) or trying to use an outdated leap second table.",
 CDF_STATUSTEXT_LEN);
 break;
 
 case BADDATE_LEAPSECOND_UPDATED:
 strcpyX (textPtr,
-"BADDATE_LEAPSECOND_UPDATED: The last leap second updated date is not valid (not in the leap second table).",
+"BADDATE_LEAPSECOND_UPDATED: The last leap second updated date is not valid "
+"(not in the leap second table).",
+CDF_STATUSTEXT_LEN);
+break;
+
+case FUNCTION_NOT_SUPPORTED:
+strcpyX (textPtr,
+"FUNCTION_NOT_SUPPORTED: This function is not supported. Likely, it is trying "
+"to access an rVariable.",
+CDF_STATUSTEXT_LEN);
+break;
+
+case BLOCKINGFACTOR_TOO_SMALL:
+strcpyX (textPtr,
+"BLOCKINGFACTOR_TOO_SMALL: The blocking factor set for the compressed "
+"variable is smaller than the default. It is changed but may make data access "
+"ineffective.",
+CDF_STATUSTEXT_LEN);
+break;
+
+case BLOCKINGFACTOR_TOO_SMALL2:
+strcpyX (textPtr,
+"BLOCKINGFACTOR_TOO_SMALL2: The variable's blocking factor is smaller than "
+"the default if it is compressed. The compression is set but may make data "
+"access ineffective.",
+CDF_STATUSTEXT_LEN);
+break;
+
+case TRY_TO_READ_NONSTRING_DATA:
+strcpyX (textPtr,
+"TRY_TO_READ_NONSTRING_DATA: Wrong function as the attribute entry data is "
+"non-string.",
+CDF_STATUSTEXT_LEN);
+break;
+
+case BAD_NUM_STRINGS:
+strcpyX (textPtr,
+"BAD_NUM_STRINGS: Bad number of strings (at least 1 is required).",
+CDF_STATUSTEXT_LEN);
+break;
+
+case STRING_NOT_UTF8_ENCODING:
+strcpyX (textPtr,
+"STRING_NOT_UTF8_ENCODING: String not in UTF8 encoding form.",
+CDF_STATUSTEXT_LEN);
+break;
+
+case CANNOT_CONVERT_WIDECHAR:
+strcpyX (textPtr,
+"CANNOT_CONVERT_WIDECHAR: Can not convert between wide-character string and "
+"multi-byte character string. Locale might not be properly set.",
 CDF_STATUSTEXT_LEN);
 break;
 
