@@ -3,7 +3,7 @@
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
-/****************************************************************************** 
+/******************************************************************************
 *
 *  SPDF/CDF                       CDF_TIME_TT2000 utility routines for C.
 *
@@ -14,7 +14,9 @@
 *   V1.0  15-Mar-11, M Liu      Initial version (for CDF V3.3.2)
 *   V2.0  15-Feb-12, M Liu      Initial version (for CDF V3.4.0)
 *   V2.1  10-Sep-18, M Liu      Added toEncodeTT2000.
-*
+*   V3.8  10-Jul-20, M Liu      Modified the breakdown code to typecast the
+*                               day_AD value first. Added handling of negative
+*                               leap second.
 ******************************************************************************/
 
 #include "cdflib.h"
@@ -36,13 +38,25 @@
 #define HOURinNanoSecs          3600000000000LL
 #define MINUTEinNanoSecs        60000000000LL
 #define T12hinNanoSecs          43200000000000LL
-/* Julian days for 1707-09-22 and 2292-04-11, the valid TT2000 range. */
+/* Julian days for 1707-09-22T12:12:10.961224192 and
+ * 2292-04-11T11:46:07.670775807, the valid TT2000 range. */
+/* 1707-09-22T12:12:10.961224192 reserved as FILLVAL */
+/*                               (encoded as 9999-12-31T23:59:59.999999999) */
+/* 1707-09-22T12:12:10.961224193 reserved as PADVAL */
+/*                               (encoded as 0000-01-01T00:00:00.000000000) */
+/* 1707-09-22T12:12:10.961224195 reserved as ILLEGAL_VAL */
+/*                               (encoded as 9999-12-31T23:59:59.999999999) */
 #define JDY17070922             2344793
+#define JDY17070922subdayns     43930961224192LL
 #define JDY22920411             2558297
+#define JDY22920411subdayns     42367670775807LL
 
 /* Number of Delta(dAT) expressions before leap seconds were introduced */
 #define NERA1 14
 
+/* The following session needs to be modified when a leap second is added   */
+/* ======================================================================   */
+/* A positive second is added for 2017-01-01                       */
 #define LASTLEAPSECONDDAY	20170101
 /* Dates, Delta(AT)s and drift rates */
 static double  LTS [][6]= {
@@ -91,14 +105,16 @@ static double  LTS [][6]= {
       { 2017,  1,   1, 37.0,             0.0, 0.0       }
      };
 
-/* Number of Delta(AT) in static table */
-static const int NDAT = sizeof (LTS) / sizeof (LTS[0]);
-static double **LTD = NULL;
-static long long *NST = NULL;
-/* Pre-computed times from CDF_TT2000_from_UTC_parts for days in LTS table */
+/* Pre-computed times from CDF_TT2000_from_UTC_parts for days in LTS table  */
+/* To add a new leap second entry: Use the old table to generate the        */
+/* nanoseconds for the new date and add/substract one second (1000000000LL) */
+/* to it, depending on positive/negative leap second.                       */
+/* Exp. positive leap second...                                             */
+/*      23h 59m 58s => 23h 59m 59s => 23h 59m 60s => 00h 00m 00s            */
+/* Exp. negative leap second...                                             */
+/*      23h 59m 57s => 23h 59m 58s => 00h 00m 00s => 00h 00m 01s            */
 static long long NST2 [] = {
-         0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL,
-         0LL, 0LL, 0LL, 0LL,
+         0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL, 0LL,
          -883655957816000000LL, -867931156816000000LL, -852033555816000000LL,
          -820497554816000000LL, -788961553816000000LL, -757425552816000000LL,
          -725803151816000000LL, -694267150816000000LL, -662731149816000000LL,
@@ -108,8 +124,17 @@ static long long NST2 [] = {
          -205243139816000000LL, -173707138816000000LL, -126273537816000000LL,
           -79012736816000000LL,  -31579135816000000LL,  189345665184000000LL,
           284040066184000000LL,  394372867184000000LL,  488980868184000000LL,
-          536500869184000000LL};
+          536500869184000000LL
+     };
+/* ====================================================================== */
 
+/* Number of Delta(AT) in static table */
+static const int NDAT = sizeof (LTS) / sizeof (LTS[0]);
+static double **LTD = NULL;
+static long long *NST = NULL;
+static int *NSTb = NULL;
+
+static int lastLeapSecondDay;
 static int entryCnt;
 static char *leapTableEnv = NULL;
 
@@ -184,13 +209,14 @@ static int MonthNumber (char *month)
 static double JulianDay12h (long y, long m, long d)
 {
   if (m == 0) m = 1;
-  return (double) (367*y-7*(y+(m+9)/12)/4-3*((y+(m-9)/7)/100+1)/4+275*m/9+d+1721029);
+  return
+   (double) (367*y-7*(y+(m+9)/12)/4-3*((y+(m-9)/7)/100+1)/4+275*m/9+d+1721029);
 }
 
 static void DatefromJulianDay (double julday, long *y, long *m, long *d)
 {
   long i, j, k, l, n;
-  l=(long) (julday+68569);
+  l=68569 + (long) julday;
   n=4*l/146097;
   l=l-(146097*n+3)/4;
   i=4000*(l+1)/1461001;
@@ -246,11 +272,11 @@ void EPOCHbreakdownTT2000 (double epoch, long *year, long *month, long *day,
   long jd,i,j,k,l,n;
   double second_AD, minute_AD, hour_AD, day_AD;
   second_AD = epoch;
-  minute_AD = second_AD / 60.0;
-  hour_AD = minute_AD / 60.0;
-  day_AD = hour_AD / 24.0;
+  minute_AD = second_AD / 60;
+  hour_AD = minute_AD / 60;
+  day_AD = hour_AD / 24;
 
-  jd = (long) (1721060 + day_AD);
+  jd = 1721060 + (long) day_AD;
   l=jd+68569;
   n=4*l/146097;
   l=l-(146097*n+3)/4;
@@ -347,21 +373,36 @@ static void LoadLeapSecondsTable ()
 static void LoadLeapNanoSecondsTable () 
 {
   int ix;
+  double diffLeap;
   if (LTD == NULL) LoadLeapSecondsTable ();
   NST = (long long *) cdf_AllocateMemory (entryCnt * sizeof (long long), NULL);
-  if (fromFile == 0)
+  NSTb = (int *) cdf_AllocateMemory (entryCnt * sizeof (int), NULL);
+  if (fromFile == 0) {
     memcpy (NST, NST2, entryCnt * sizeof (long long));
-  else {
-    if (LTD[entryCnt-1][0] == LTS[entryCnt-1][0]) 
+    lastLeapSecondDay = LASTLEAPSECONDDAY;
+  } else {
+    if (LTD[entryCnt-1][0] == LTS[entryCnt-1][0]) {
       memcpy (NST, NST2, entryCnt * sizeof (long long));
-    else {
+      lastLeapSecondDay = LASTLEAPSECONDDAY;
+    } else {
       for (ix = NERA1; ix < entryCnt; ++ix) {
          NST[ix] = CDF_TT2000_from_UTC_parts(LTD[ix][0], LTD[ix][1],
                                              LTD[ix][2], 0.0, 0.0, 0.0,
                                              0.0, 0.0, 0.0);
+         if (ix == (entryCnt - 1))
+           lastLeapSecondDay = (int) LTD[ix][0] * 10000 + 
+                               (int) LTD[ix][1] * 100 + 
+                               (int) LTD[ix][2];
       }
     }
   }
+  for (ix = 0; ix < entryCnt; ++ix)
+    NSTb[ix] = 0;
+  for (ix = entryCnt-1; ix > 0; --ix) {
+    diffLeap = LTD[ix][3] - LTD[ix-1][3];
+    if (diffLeap == 1.0) NSTb[ix] = 1;
+    else if (diffLeap == -1.0) NSTb[ix] = -1;
+  }
 }
 
 static double LeapSecondsfromYMD (long iy, long im, long id)
@@ -401,9 +442,9 @@ static double LeapSecondsfromJ2000 (long long nanosecs, int *leapSecond)
     if (nanosecs >= NST[i]) {
       j = i;
       if (i < (entryCnt - 1)) {
-        /* Check for time following on leap second (second = 60). */
-        if ((nanosecs + 1000000000L) >= NST[i+1]) {
-          *leapSecond = 1;
+        /* Check for time following on the leap second. */
+        if ((nanosecs + (long long) (NSTb[i+1]*1000000000L)) >= NST[i+1]) {
+          *leapSecond = NSTb[i+1]; 
         }
       }
       break;
@@ -463,8 +504,10 @@ VISIBLE_PREFIX void CDFClearLeapSecondsTable ()
        cdf_FreeMemory (LTD[ix], NULL);
     cdf_FreeMemory (LTD, NULL);
     if (NST != NULL) cdf_FreeMemory (NST, NULL);
+    if (NSTb != NULL) cdf_FreeMemory (NSTb, NULL);
     LTD = NULL;
     NST = NULL;
+    NSTb = NULL;
     tableChecked  = 0;
   }
   if (openCDF64s == 0 && leapTableEnv != NULL) {
@@ -617,14 +660,14 @@ va_dcl
   if (dat0 > 0.0) { /* Post-1972.... */
     secSinceJ2000 -= (long long) dat0;
     epoch = (double) J2000Since0AD12hSec + secSinceJ2000;
-    if (leapSec == 0) 
+    if (leapSec == 0 || leapSec == -1) 
       EPOCHbreakdownTT2000 (epoch, &ye1, &mo1, &da1, &ho1, &mi1, &se1);
-    else {
-      /* second is at 60.... bearkdown function can't handle 60 so make it
+    else { /* positive leap second */
+      /* second is at 60.... breakdown function can't handle 60 so make it
          59 first and then add 1 second back. */
-      epoch -= 1.0;
+      epoch -= leapSec;
       EPOCHbreakdownTT2000 (epoch, &ye1, &mo1, &da1, &ho1, &mi1, &se1);
-      se1 += 1;
+      se1 += leapSec;
     }
   } else { /* Pre-1972.... */
     long long tmpNanosecs;
@@ -814,6 +857,7 @@ VISIBLE_PREFIX void breakdownTT2000withBasedLeapDay (long long tt2000,
         breakdownTT2000 (tt2000, &yyy, &mmm, &ddd, &hhh, &mmn, &sss, &mms,
                          &mus, &mns);
       free (tmpTT2000s);
+      tmpTT2000s = NULL;
     }
   }
   *yy = (long) yyy;
@@ -874,6 +918,7 @@ VISIBLE_PREFIX void encodeTT2000withBasedLeapDay (long long tt2000,
     if (found == 0)
       CDF_TT2000_to_UTC_string (tt2000, string, 3);
     free (tmpTT2000s);
+    tmpTT2000s = NULL;
   }
   return;
 }
@@ -923,7 +968,7 @@ va_dcl
   long lyl, lml, ldl, lhl, lnl, lsl, lll, lul, lal;
   long xy, xm, xd;
   int  lyear;
-
+  double jday12h = 0.0;
 #if defined(STDARG)
   va_start (ap, dd);
 #else
@@ -1069,8 +1114,8 @@ va_dcl
     ls += as;
     ll += al; 
     lu += au;
-    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
+    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
   } 
   if (lu >= 1000.0) {
     double ad, ah, am, as, al;
@@ -1089,8 +1134,8 @@ va_dcl
     ln += am;
     ls += as;
     ll += al;
-    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
+    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
   }
   if (ll >= 1000.0) {
     double ad, ah, am, as;
@@ -1106,8 +1151,8 @@ va_dcl
     lh += ah;
     ln += am;
     ls += as;
-    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
+    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
   }
   if (ls >= 60.0) {
     tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
@@ -1125,8 +1170,8 @@ va_dcl
       ld += ad;
       lh += ah;
       ln += am;
-      tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
-      DatefromJulianDay (tmp, &lyl, &lml, &ldl);
+      jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
+      DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
     }
   }
   if (ln >= 60.0) {
@@ -1137,16 +1182,16 @@ va_dcl
     ln = ln - ah * 60;
     ld += ad;
     lh += ah;
-    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
+    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
   }
   if (lh >= 24.0) {
     double ad;
     ad = floor(lh / 24.0); 
     lh = lh - ad * 24.0;
     ld += ad;
-    tmp = JulianDay12h ((long) ly, (long) lm, (long) ld);
-    DatefromJulianDay (tmp, &lyl, &lml, &ldl);
+    jday12h = JulianDay12h ((long) ly, (long) lm, (long) ld);
+    DatefromJulianDay (jday12h, &lyl, &lml, &ldl);
   }
   if (lyl == -999 && lml == -999) {
     lyl = (long) ly;
@@ -1168,6 +1213,16 @@ va_dcl
     return DEFAULT_TT2000_PADVALUE;
   if (!YearWithin(lyl) && !ValidateYMD(lyl,lml,ldl))
     return ILLEGAL_TT2000_VALUE;
+  if (jday12h == 0.0)  jday12h = JulianDay12h (lyl, lml, ldl);
+  if (jday12h == JDY22920411) {
+    long long subday = (long long) (3600*lhl+60*lnl+lsl)*1000000000LL+
+                       lll*1000000LL+lul*1000LL+lal;
+    if (subday > JDY22920411subdayns) return ILLEGAL_TT2000_VALUE;
+  } else if (jday12h == JDY17070922) {
+    long long subday = (long long) (3600*lhl+60*lnl+lsl)*1000000000LL+
+                       lll*1000000LL+lul*1000LL+lal;
+    if (subday < JDY17070922subdayns) return ILLEGAL_TT2000_VALUE;
+  }
   lyear = (lyl & 3) == 0 && ((lyl % 25) != 0 || (lyl & 15) == 0);
   if ((!lyear && ldl > 365) || (lyear && ldl > 366))
     return ILLEGAL_TT2000_VALUE;
@@ -1350,37 +1405,37 @@ va_dcl
   if (nanoSecSinceJ2000 == FILLED_TT2000_VALUE ||
       nanoSecSinceJ2000 == ILLEGAL_TT2000_VALUE) {
     if (style == 0) {
-      strncpy(string, "31-Dec-9999 23:59:59.999999999", 30);
+      strcpyX (string, "31-Dec-9999 23:59:59.999999999", 30);
       string[30] = '\0';
     } else if (style == 1) {
-      strncpy(string, "99991231.9999999999", 19);
+      strcpyX (string, "99991231.9999999999", 19);
       string[19] = '\0';
     } else if (style == 2) {
-      strncpy(string, "99991231235959", 14);
+      strcpyX (string, "99991231235959", 14);
       string[14] = '\0';
     } else if (style == 3) {
-      strncpy(string, "9999-12-31T23:59:59.999999999", 29);
+      strcpyX (string, "9999-12-31T23:59:59.999999999", 29);
       string[29] = '\0';
     } else {
-      strncpy(string, "9999-12-31T23:59:59.999999999Z", 30);
+      strcpyX (string, "9999-12-31T23:59:59.999999999Z", 30);
       string[30] = '\0';
     }
     return;
   } else if (nanoSecSinceJ2000 == DEFAULT_TT2000_PADVALUE) {
     if (style == 0) {
-      strncpy(string, "01-JAN-0000 00:00:00.000000000", 30);
+      strcpyX (string, "01-JAN-0000 00:00:00.000000000", 30);
       string[30] = '\0';
     } else if (style == 1) {
-      strncpy(string, "00000101.0000000000", 19);
+      strcpyX (string, "00000101.0000000000", 19);
       string[19] = '\0';
     } else if (style == 2) {
-      strncpy(string, "00000101000000", 14);
+      strcpyX (string, "00000101000000", 14);
       string[14] = '\0';
     } else if (style == 3) {
-      strncpy(string, "0000-01-01T00:00:00.000000000", 29);
+      strcpyX (string, "0000-01-01T00:00:00.000000000", 29);
       string[29] = '\0';
     } else {
-      strncpy(string, "0000-01-01T00:00:00.000000000Z", 30);
+      strcpyX (string, "0000-01-01T00:00:00.000000000Z", 30);
       string[30] = '\0';
     }
     return;
@@ -1497,6 +1552,8 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
           &lh, &ln, &ls, &tmp) < 8) {
          free (newstr);
          free (tmpPtr);
+         newstr = NULL;
+         tmpPtr = NULL;
          return ILLEGAL_TT2000_VALUE;
       }
     } else {
@@ -1504,6 +1561,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
           &ld, &(moString[0]), &(moString[1]), &(moString[2]), &ly,
           &lh, &ln, &ls, &tmp) != 9) {
         free (tmpPtr);
+        tmpPtr = NULL;
         return ILLEGAL_TT2000_VALUE;
       }
     }
@@ -1512,10 +1570,12 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     if (ly == 9999 && lm == 12 && ld == 31 && lh == 23 && ln == 59 &&
         ls == 59 && (tmp == 999999999 || tmp == 999 || tmp == 999999)) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && lh == 0 && ln == 0 &&
                ls == 0 && tmp == 0) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
     if (tmp == 0) {
@@ -1535,9 +1595,13 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
         la = (long) (tmp - lu * 1000);
       }
     }
-    if (newstr != NULL) free (newstr);
+    if (newstr != NULL) {
+      free (newstr);
+      newstr = NULL;
+    }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) return ILLEGAL_TT2000_VALUE;
     free (tmpPtr);
+    tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
                                       (double) ll, (double) lu, (double) la);
@@ -1546,6 +1610,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     if (sscanf(tmpPtr,"%4ld%2ld%2ld.%lld",
         &ly, &lm, &ld, &tmp) != 4) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
     if (tmp == 0) 
@@ -1557,13 +1622,16 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     }
     if (ly == 9999 && lm == 12 && ld == 31 && tmp == 9999999999LL) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && tmp == 0) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
     fraction *= 24.0;
@@ -1578,6 +1646,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     lu = (long) floor(fraction);
     la = (long) ((fraction - lu) * 1000.0);
     free (tmpPtr);
+    tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
                                       (double) ll, (double) lu, (double) la);
@@ -1585,22 +1654,27 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     if (sscanf(tmpPtr,"%4ld%2ld%2ld%2ld%2ld%2ld",
         &ly, &lm, &ld, &lh, &ln, &ls) != 6) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
     if (ly == 9999 && lm == 12 && ld == 31 && lh == 23 && ln == 59 &&
         ls == 59) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && lh == 0 && ln == 0 &&
                ls == 0) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
     free (tmpPtr);
+    tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
                                       0.0, 0.0, 0.0);
@@ -1615,12 +1689,14 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
         if (sscanf(tmpPtr,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld",
             &ly, &lm, &ld, &ac, &lh, &ln, &ls) != 7) {
           free (tmpPtr);
+          tmpPtr = NULL;
           return ILLEGAL_TT2000_VALUE;
         }
       } else {
         if (sscanf(tmpPtr,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ldZ",
             &ly, &lm, &ld, &ac, &lh, &ln, &ls) != 7) {
           free (tmpPtr);
+          tmpPtr = NULL;
           return ILLEGAL_TT2000_VALUE;
         }
       }
@@ -1628,6 +1704,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
       if (sscanf(tmpPtr,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld.",
           &ly, &lm, &ld, &ac, &lh, &ln, &ls) != 7) {
         free (tmpPtr);
+        tmpPtr = NULL;
         return ILLEGAL_TT2000_VALUE;
       }
       if (tmpPtr[len-1] != 'Z') { 
@@ -1642,10 +1719,12 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     if (ly == 9999 && lm == 12 && ld == 31 && lh == 23 && ln == 59 &&
         ls == 59 && (tmp == 999999999 || tmp == 999 || tmp == 999999)) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return FILLED_TT2000_VALUE;
     } else if (ly == 0 && lm == 1 && ld == 1 && lh == 0 && ln == 0 &&
                ls == 0 && tmp == 0) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return DEFAULT_TT2000_PADVALUE;
     }
     if (tmp == 0) {
@@ -1658,14 +1737,17 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
     }
     if (!YearWithin(ly) && !ValidateYMD(ly,lm,ld)) {
       free (tmpPtr);
+      tmpPtr = NULL;
       return ILLEGAL_TT2000_VALUE;
     }
     free (tmpPtr);
+    tmpPtr = NULL;
     return CDF_TT2000_from_UTC_parts ((double) ly, (double) lm, (double) ld,
                                       (double) lh, (double) ln, (double) ls,
                                       (double) ll, (double) lu, (double) la);
   } else {
     free (tmpPtr);
+    tmpPtr = NULL;
     return ILLEGAL_TT2000_VALUE;
   }
 }
@@ -1708,7 +1790,7 @@ VISIBLE_PREFIX int ValidateTT2000 (int yyyymmdd,
                                    int leapSecondLastUpdated)
 {
   int i, last, lastDate;
-  if (yyyymmdd < LASTLEAPSECONDDAY) return 1;
+  if (yyyymmdd < lastLeapSecondDay) return 1;
   if (LTD == NULL) LoadLeapSecondsTable ();
   else RecheckLeapSecondsTableEnvVar();
   last = entryCnt - 1;
@@ -1822,11 +1904,11 @@ static void FromUTCISO8601string (char *string, long *ly, long *lm, long *ld,
 /******************************************************************************
  * LastLeapSecondDayInStaticTable.
  * Returns the last leap second day added in the static leap second table.
- ******************************************************************************/
+ *****************************************************************************/
 
 int LastLeapSecondDayInStaticTable ()
 {
-  return (int) LASTLEAPSECONDDAY;
+  return (int) lastLeapSecondDay;
 }
 
 /******************************************************************************
@@ -1834,7 +1916,7 @@ int LastLeapSecondDayInStaticTable ()
  * Converts an array of CDF's TT2000 times (nanoseconds from 
  * 2000-01-01 12:00:00.000) in 64-bit integer to unix times (seconds from 
  * 1970-01-01 00:00:00 UTC) in double.
- ******************************************************************************/
+ *****************************************************************************/
 
 VISIBLE_PREFIX void TT2000toUnixTime (epoch, unixTime, numTimes)
 long long *epoch;
@@ -1857,7 +1939,7 @@ int    numTimes;
  * Converts an array of unix times (seconds from 1970-01-01 00:00:00 UTC) in
  * double to CDF's TT2000 times (nanoseconds from 2000-01-01 12:00:00.000) in 
  * 64-bit long.
- ******************************************************************************/
+ *****************************************************************************/
 
 VISIBLE_PREFIX void UnixTimetoTT2000 (unixTime, epoch, numTimes)
 double *unixTime;
