@@ -530,6 +530,9 @@ vFILE *vFp;
   * actually the scratch directory to be used.
   ****************************************************************************/
   if (vFp->fp == NULL) {
+#if __XSI_VISIBLE >= 4
+int ix;
+#endif
     long i; char *tmpPath; size_t pathLength;
     pathLength = strlen(vFp->path) + 1 + 8 + 1 + EXT_LEN;
     if (pathLength < DU_MAX_DIR_LEN) pathLength = DU_MAX_DIR_LEN;
@@ -538,7 +541,7 @@ vFILE *vFp;
     if (vFp->path != NULL && strlen(vFp->path) != 0) { 
       strcpyX (tmpPath, vFp->path, 0);
       AppendToDir (tmpPath, "");
-#     if defined(unix) || defined(vms)
+#     if defined(unix) || defined(vms) || defined(__CYGWIN__)
         strcatX (tmpPath, TmpFileTemplate, 0);
         fileid = mkstemp(tmpPath);
         if (fileid != -1) fp = fdopen(fileid, "w+");
@@ -547,7 +550,8 @@ vFILE *vFp;
             strcpyX (tmpPath, vFp->path, 0);
             AppendToDir (tmpPath, "");
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) {
               fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
               if (fp != NULL) break;
@@ -564,8 +568,10 @@ vFILE *vFp;
             if (err == EEXIST) {
               int i1, i2;
               for (i = 1; i <= MAX_TMP; i++) {
-                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
-                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
                 strcpyX (tmpPath, vFp->path, 0);
                 AppendToDir (tmpPath, "");
                 snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
@@ -580,10 +586,11 @@ vFILE *vFp;
           }
 #       else
           for (i = 1; i <= MAX_TMP; i++) {
-            strcpy (tmpPath, vFp->path);
+            strcpyX (tmpPath, vFp->path, (size_t)pathLength);
             AppendToDir (tmpPath, "");
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
             if (fp != NULL) break;
           }
@@ -591,21 +598,21 @@ vFILE *vFp;
 #     endif
     } else {
       char *tmpFolder = NULL;
-      strcpy (tmpPath, "");
+      strcpyX (tmpPath, "", (size_t)pathLength);
 #     if defined(unix) || defined(vms)
         tmpFolder = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
         if (tmpFolder == NULL) return FALSE;
         writable = access(".", W_OK);
         if (writable == 0) {
-          strcpy (tmpPath, TmpFileTemplate);
-          strcpy (tmpFolder, "");
+          strcpyX (tmpPath, TmpFileTemplate, (size_t)pathLength);
+          strcpyX (tmpFolder, "", (size_t)pathLength);
         } else {
 #         if defined(unix)
-            strcpy (tmpPath, "/tmp/");
-            strcpy (tmpFolder, tmpPath);
+            strcpyX (tmpPath, "/tmp/", (size_t)pathLength);
+            strcpyX (tmpFolder, tmpPath, (size_t)pathLength);
 #         else
-            strcpy (tmpPath, "SYS$SCRATCH:");
-            strcpy (tmpFolder, tmpPath);
+            strcpyX (tmpPath, "SYS$SCRATCH:", (size_t)pathLength);
+            strcpyX (tmpFolder, tmpPath, (size_t)pathLength);
 #         endif
           strcatX (tmpPath, TmpFileTemplate, 0);
         }
@@ -613,9 +620,10 @@ vFILE *vFp;
         if (fileid != -1) fp = fdopen(fileid, "w+");
         else {
           for (i = 1; i <= MAX_TMP; i++) {
-            strcpy (tmpPath, tmpFolder);
+            strcpyX (tmpPath, tmpFolder, (size_t)pathLength);
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) {
               fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
               if (fp != NULL) break;
@@ -633,9 +641,11 @@ vFILE *vFp;
             if (err == EEXIST) {
               int i1, i2;
               for (i = 1; i <= MAX_TMP; i++) {
-                strcpy (tmpPath, "");
-                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
-                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                strcpyX (tmpPath, "", (size_t)pathLength);
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
                 snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
                                          strlen(tmpPath),
                           "TMP%c%c%5.5d.%s", i1, i2, rand(), vFp->scratchExt);
@@ -724,7 +734,8 @@ char *a_mode;           /* Access mode. */
     }
     EOFoffsetInBlock = eof % nCACHE_BUFFER_BYTEs;
     if (EOFoffsetInBlock != 0) {
-      long offsetToLastBlock; char buffer[nCACHE_BUFFER_BYTEs]; size_t numitems; int i;
+      long offsetToLastBlock; char buffer[nCACHE_BUFFER_BYTEs];
+      size_t numitems; int i;
       offsetToLastBlock = nCACHE_BUFFER_BYTEs * (eof / nCACHE_BUFFER_BYTEs);
       if (fseek(fp,offsetToLastBlock,vSEEK_SET) == EOF) {
 	fclose (fp);
@@ -763,7 +774,8 @@ char *a_mode;           /* Access mode. */
   }
   vFp->magic_number = VSTREAM_MAGIC_NUMBER;
   vFp->fp = fp;
-  vFp->path = (char *) cdf_AllocateMemory ((size_t)strlen(file_spec) + 1, NULL);
+  vFp->path = (char *) cdf_AllocateMemory ((size_t)strlen(file_spec) + 1,
+                                           NULL);
   if (vFp->path == NULL) {
     cdf_FreeMemory (vFp, NULL);
     fclose (fp);
