@@ -75,7 +75,8 @@
 #endif
 
 #define LASTphyBLOCKn(vFp) \
-BOO(vFp->phyLength64 == 0,NO_BLOCK,(long) ((vFp->phyLength64-1)/nCACHE_BUFFER_BYTEs))
+BOO(vFp->phyLength64 == 0,NO_BLOCK, \
+                          (long) ((vFp->phyLength64-1)/nCACHE_BUFFER_BYTEs))
 
 #if defined(MICROSOFTC_700) && INCLUDEvMEMORY
 #define CACHEbufferREADfrom(cache) \
@@ -600,7 +601,7 @@ vFILE *vFp;
     if (vFp->path != NULL && strlen(vFp->path) != 0) { 
       strcpyX (tmpPath, vFp->path, 0);
       AppendToDir (tmpPath, "");
-#     if defined(unix) || defined(vms)
+#     if defined(unix) || defined(vms) || defined(__CYGWIN__)
         strcatX (tmpPath, TmpFileTemplate, 0);
         fileid = mkstemp(tmpPath);
         if (fileid != -1) fp = fdopen(fileid, "w+");
@@ -609,7 +610,8 @@ vFILE *vFp;
             strcpyX (tmpPath, vFp->path, 0);
             AppendToDir (tmpPath, "");
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) {
               fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
               if (fp != NULL) break;
@@ -628,8 +630,10 @@ vFILE *vFp;
               int i1, i2;
               for (i = 1; i <= MAX_TMP; i++) {
                 fh = -1;
-                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
-                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
                 strcpyX (tmpPath, vFp->path, 0);
                 AppendToDir (tmpPath, "");
                 snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
@@ -647,7 +651,8 @@ vFILE *vFp;
             strcpyX (tmpPath, vFp->path, (size_t)pathLength);
             AppendToDir (tmpPath, "");
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
             if (fp != NULL) break;
           }
@@ -679,7 +684,8 @@ vFILE *vFp;
           for (i = 1; i <= MAX_TMP; i++) {
             strcpyX (tmpPath, tmpFolder, (size_t)pathLength);
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
-                      "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
+                      "TMP%08ld.%s", (long)(rand()%100000000),
+                      vFp->scratchExt);
             if (!IsReg(tmpPath)) {
               fp = CDFOpenFile (tmpPath, WRITE_PLUS_a_mode);
               if (fp != NULL) break;
@@ -700,8 +706,10 @@ vFILE *vFp;
               for (i = 1; i <= MAX_TMP; i++) {
                 fh = -1;
                 strcpyX (tmpPath, "", (size_t)pathLength);
-                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
-                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
+                i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
+                i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) +
+                     (int) 'A';
                 snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
                                          strlen(tmpPath),
                           "TMP%c%c%5.5d.%s", i1, i2, rand(), vFp->scratchExt);
@@ -1202,7 +1210,8 @@ char *a_mode;           /* Access mode. */
 #else
   vFp->fp = fp;
 #endif
-  vFp->path = (char *) cdf_AllocateMemory ((size_t)strlen(file_spec) + 1, NULL);
+  vFp->path = (char *) cdf_AllocateMemory ((size_t)strlen(file_spec) + 1,
+                                           NULL);
   if (vFp->path == NULL) {
     cdf_FreeMemory (vFp, NULL);
     FCLOSE64 (fp);
