@@ -227,6 +227,8 @@ static char zVarsRecBuffer[zDIM_0_SIZEa][zNUM_ELEMSa] = {
   {'%','%','%','%','%','%','%','%'}
 };
 static char zVarsRecBufferOut[zDIM_0_SIZEa][zNUM_ELEMSa];
+long lastUpdated;
+static long lastUpdatedO = 20170101;
 
 /******************************************************************************
 * Display title.
@@ -313,6 +315,15 @@ status = CDFlib (SELECT_, rVAR_, 0L,
 		 NULL_);
 if (status < CDF_OK) QuitCDF ("2b.04", status);
 
+/******************************************************************************
+* Check leap second last upadted.
+******************************************************************************/
+
+status = CDFlib (GET_, CDF_LEAPSECONDLASTUPDATED_, &lastUpdated,
+                 NULL_);
+if (status < CDF_OK) QuitCDF ("2.7", status);
+if ((int)lastUpdated != lastUpdatedO) QuitCDF("2.8", status);
+
 /******************************************************************************
 * Close CDF.
 ******************************************************************************/
