@@ -39,7 +39,11 @@ void *GetVirtualVarRecords (long, Logical);
 /******************************************************************************
 * Global variables.
 ******************************************************************************/
+#ifdef WIN32
+  static unsigned int oldCodePage = 0;
+#endif
 
+FILE *fp;
 /******************************************************************************
 * Main.
 ******************************************************************************/
@@ -49,10 +53,8 @@ MAIN {
   Logical success = TRUE;
   strcpyX (pgmName, "CDFdump", MAX_PROGRAM_NAME_LEN);
   success = DumpCDF (argc, argv);
-#if defined(DEBUG)
-  if (cdf_FreeMemory(NULL,FatalError) > 0) DisplayWarning ("Abandoned buffers.");
-#else
-  cdf_FreeMemory (NULL, FatalError);
+#ifdef WIN32
+  if (oldCodePage != 0) SetConsoleOutputCP(oldCodePage);
 #endif
   return BOO(success,EXIT_SUCCESS_,EXIT_FAILURE_);
 }
@@ -88,20 +90,20 @@ char tText[256];
 char shortStr1[20], shortStr2[20], *prtFormat = NULL;
 void *value, *working = NULL;
 void *value2 = NULL;
+unsigned char *checkPtr = NULL;
 Logical  toCol2Row = FALSE;
 Byte1 **handles[1], *buffer = NULL;
 char **vars = NULL;
 int  numVars = 0;
 size_t nValueBytes[1];
 size_t offset, nBytes;
-struct HyperStruct hyperX;
+struct HyperStruct hyperSt;
 struct GroupStruct groups;
 Logical Z, pad, ifound;
 int  varNum, i, ii, j, k, ir, imore, iskip, icount = 0, ij, precision;
 long tmpLong[1] = {0};
 Logical qopError = FALSE;
 Logical detect = FALSE;
-FILE *fp;
 QOP *qop;
 Logical virtual = FALSE;
 static char *validQuals[] = {
@@ -111,13 +113,13 @@ static char *validQuals[] = {
 };
 static int optRequired[] = {
   TRUE, TRUE, FALSE, FALSE, TRUE, TRUE,
-  FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE,
+  FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, TRUE,
   0
 };
 int numValidDumps = 6;
 static char *validDumps[] = {
   "all", "data", "nodata", "metadata", "global", "variable" };
-
+char *locale;
 
 /******************************************************************************
 * Parse qualifiers/options/parameters (QOP).
@@ -150,9 +152,15 @@ switch (argC) {
         }
       }
       if (!Z) {
-        DisplayError ("Invalid dump option.");
-        qopError = TRUE;
-        return TRUE;
+        if (strcmpIgCase(dumpOption, "meta") == 1) {
+          dump = 3;
+          Z = TRUE;
+	}
+        if (!Z) {
+          DisplayError ("Invalid dump option.");
+          qopError = TRUE;
+          return TRUE;
+        }
       }
     } else
       MakeNUL(dumpOption);
@@ -223,7 +231,7 @@ switch (argC) {
         vars = (char **) cdf_AllocateMemory ((size_t)sizeof(char *) * numVars,
                                              FatalError);
         for (i = 0; i < numVars; i++) 
-          vars[i] = (char *) cdf_AllocateMemory ((size_t)CDF_VAR_NAME_LEN256+1, 
+          vars[i] = (char *) cdf_AllocateMemory ((size_t)CDF_VAR_NAME_LEN256+1,
                                                  FatalError);
         ParseStringForTokens (',', varsOption, vars);
       }   
@@ -268,7 +276,6 @@ switch (argC) {
       strcpyX (CDFpath, qop->parms[CDFPATHparm], DU_MAX_PATH_LEN);
       ParsePath (CDFpath, dir, CDFname);
     }
-
     if (!NULstring(outputFile)) {
       if (strncmpIgCase(outputFile, "source", 6) != 0) {
         int loc;
@@ -323,7 +330,6 @@ switch (argC) {
   if (status < CDF_OK) return QuitCDF (CDFpath, "1.0", status, CDFpath);
 
   status = CDFlib (SELECT_, CDF_, id,
-/*                          CDF_READONLY_MODE_, READONLYon, */
                    GET_, CDF_VERSION_, &version,
                          CDF_RELEASE_, &release,
                          CDF_INCREMENT_, &increment,
@@ -351,27 +357,34 @@ switch (argC) {
     fprintf (fp, "Version:      %ld.%ld.%ld\n",version,release,
 							  increment);
     fprintf (fp, "%s\n",copyRight);
-/*    if (dump == ALLDUMP) { */
-      fprintf (fp, "Format:       %s\n",FormatToken(format));
-      fprintf (fp, "Encoding:     %s\n",EncodingToken(encoding));
-      fprintf (fp, "Majority:     %s\n",MajorityToken(majority));
-      fprintf (fp, "NumrVars:     %ld\n",numrVars);
-      fprintf (fp, "NumzVars:     %ld\n",numzVars);
-      fprintf (fp, "NumAttrs:     %ld (%ld global, %ld variable)\n",
-  			  numAttrs, numgAttrs, numvAttrs);
-      fprintf (fp, "Compression:  %s\n",CompressionToken(compression,
-                                        compressParms));
-      if (!PriorTo ("3.2.0", (Int32) version, (Int32) release,
-		    (Int32) increment)) 
-        fprintf (fp, "Checksum:     %s\n", ChecksumToken(checksum));
-      if (!PriorTo ("3.5.0", (Int32) version, (Int32) release,
-                    (Int32) increment)) {
-        status = CDFlib (GET_, CDF_LEAPSECONDLASTUPDATED_, &lastUpdated,
-                         NULL_);
-        if (status < CDF_OK) return QuitCDF (CDFpath, "2.1", status, CDFpath);
-        fprintf (fp, "LeapSecondLastUpdated:     %ld\n", lastUpdated);
-      }
+    fprintf (fp, "Format:       %s\n",FormatToken(format));
+    fprintf (fp, "Encoding:     %s\n",EncodingToken(encoding));
+    fprintf (fp, "Majority:     %s\n",MajorityToken(majority));
+    fprintf (fp, "NumrVars:     %ld\n",numrVars);
+    fprintf (fp, "NumzVars:     %ld\n",numzVars);
+    fprintf (fp, "NumAttrs:     %ld (%ld global, %ld variable)\n",
+  		 numAttrs, numgAttrs, numvAttrs);
+    fprintf (fp, "Compression:  %s\n",CompressionToken(compression,
+                                      compressParms));
+    if (!PriorTo ("3.2.0", (Int32) version, (Int32) release,
+		  (Int32) increment)) 
+      fprintf (fp, "Checksum:     %s\n", ChecksumToken(checksum));
+    if (!PriorTo ("3.5.0", (Int32) version, (Int32) release,
+                  (Int32) increment)) {
+      status = CDFlib (GET_, CDF_LEAPSECONDLASTUPDATED_, &lastUpdated,
+                       NULL_);
+      if (status < CDF_OK) return QuitCDF (CDFpath, "2.1", status, CDFpath);
+      fprintf (fp, "LeapSecondLastUpdated:     %ld\n", lastUpdated);
+    }
   }
+  
+#if !defined(WIN32)
+  setlocale(LC_CTYPE, "en_US.UTF-8");
+#else
+  setlocale(LC_CTYPE, ".UTF8");
+  oldCodePage = GetConsoleOutputCP();
+  SetConsoleOutputCP(65001); 
+#endif
 
   /**********************************************/
   /* Print out the Global Attribute information */
@@ -417,6 +430,7 @@ switch (argC) {
               j++;
               continue;
             } else {
+              if (STRINGdataType(dataTypeX)) checkPtr = NULL;
               if (STRINGdataType(dataTypeX)) imore = 1;
               else imore = 0;
               nBytes = (size_t) (CDFelemSize(dataTypeX) * (numElemsX + imore));
@@ -425,7 +439,18 @@ switch (argC) {
                                NULL_);
               if (status < CDF_OK)
                 return QuitCDF (CDFpath, "5.0", status, attrName);
+              if (STRINGdataType(dataTypeX)) {
+		int cnt;
+		*((char *)value+numElemsX) = '\0';
+		checkPtr = UTF8Check ((unsigned char *)value, (int)numElemsX,
+			              &cnt);
+	      }
 	      if (detect) {
+		if (STRINGdataType(dataTypeX)) {
+	          if (checkPtr != NULL) 
+	            printf("** Attr:%s entry:%d failed UTF-8 check...\n",
+                           attrName, j);
+	        }
 		++k; ++j;
                 cdf_FreeMemory (value, FatalError);
 		continue;
@@ -433,7 +458,6 @@ switch (argC) {
               fprintf (fp, "\t%d (CDF_%s/%ld): \t",
                        j,DataTypeToken(dataTypeX),numElemsX);
               if (STRINGdataType(dataTypeX)) {
-                ((char *)value)[numElemsX] = '\0';
                 fprintf (fp, "\"%s\"\n", (char *)value);
               } else {
                 int ix, style;
@@ -858,6 +882,14 @@ switch (argC) {
                            NULL_);
           if (status < CDF_OK)
             return QuitCDF (CDFpath, "15.0", status, attrName);
+          if (STRINGdataType(dataTypeX)) *((char *)value+numElemsX) = '\0';
+	  if (STRINGdataType(dataTypeX)) {
+	    int cnt;
+	    checkPtr = UTF8Check ((unsigned char *)value, (int)numElemsX, &cnt);
+	    if (checkPtr != NULL) 
+	      printf("** Attr:%s entry:%d failed UTF-8 check...\n", attrName,
+                     ii);
+	  }
           fprintf (fp, "     %s", attrName);
           ir = (int) strlen(attrName);
           if (ir < 16) Ncharacters (fp, (16-ir), ' ');
@@ -872,18 +904,41 @@ switch (argC) {
               return QuitCDF (CDFpath, "15.1", status, attrName);
             if (numStrings < 2) {
               ((char *)value)[numElemsX] = '\0';
-              fprintf (fp, "\"%s\"\n", (char *)value);
+              if (checkPtr == NULL)
+                fprintf (fp, "\"%s\"\n", (char *)value);
+              else {
+                char *badStr = malloc((int)numElemsX + 1);
+                memset (badStr, '.', (size_t)numElemsX);
+                badStr[(int)numElemsX] = '\0';
+                fprintf (fp, "\"%s\"   (<= non-UTF8)\n", badStr);
+                free (badStr);
+                badStr = NULL;
+              }
             } else {
-              char **strings; int ij;
+              char **strings; int ij, cnt;
               status = CDFlib (GET_, BOO(Z,zENTRY_STRINGSDATA_,
                                            rENTRY_STRINGSDATA_),
                                      &numStrings, &strings,
                                NULL_);
               if (status < CDF_OK)
-                return QuitCDF (CDFpath, "15.2", status, attrName);
+                return QuitCDF (CDFpath, "15.3", status, attrName);
               fprintf (fp, "(strings:%ld)\n", numStrings);
-              for (ij =0; ij < numStrings; ++ij)
-                fprintf(fp, "\t\t\t\t\t\"%s\"\n",strings[ij]);
+              for (ij =0; ij < numStrings; ++ij) {
+                checkPtr = UTF8Check ((unsigned char *)strings[ij],
+			              (int)strlen(strings[ij]), &cnt);
+                if (checkPtr == NULL)
+                  fprintf (fp, "\"%s\"\n", strings[ij]);
+                else {
+                  size_t len = strlen(strings[ij]);
+                  char *badStr;
+                  badStr = malloc(len + 1);
+                  memset (badStr, '.', len);
+                  badStr[(int)len] = '\0';
+                  fprintf (fp, "\"%s\"   (<= non-UTF8)\n", badStr);
+                  free (badStr);
+                  badStr = NULL;
+                }
+              }
               CDF_Free_String (numStrings, strings);
             }
           } else {
@@ -911,10 +966,9 @@ switch (argC) {
                   dataTypeX == CDF_TIME_TT2000)
                 EncodeValue (dataTypeX, value, tText, style,
                              (size_t) sizeof(tText));
-              else {
+              else
                 EncodeValueFormat (dataTypeX, value, tText, prtFormat, -1, 0,
                                    style, (size_t) sizeof(tText));
-              }
               fprintf (fp, "%s\n", tText);
             }
           }
@@ -922,7 +976,11 @@ switch (argC) {
         }
       }
     } 
-
+    if (maxRec == -1) {
+      if (prtFormat != NULL) cdf_FreeMemory (prtFormat, FatalError);
+      if (!detect) fprintf (fp, "\n");
+      continue;
+    }
     if ((dump != METADATADUMP && dump != VARIABLEDUMP && dump != NODATADUMP) ||
         detect) {
       if (!detect) fprintf (fp, "Variable Data:\n");
@@ -974,7 +1032,7 @@ switch (argC) {
           handles[0] = &buffer;
           AllocateBuffers (toRecs, numDims, dimSizes, &groups, 0, 1, handles,
                            nValueBytes, ROWmajor(majority), 1, FatalError);
-          InitHyperParmsFromAnywhere (&hyperX, &groups, numDims, &nHypers, 
+          InitHyperParmsFromAnywhere (&hyperSt, &groups, numDims, &nHypers, 
                                       &nValues, ist);
           if (STRINGdataType(dataType)) imore = 1;
           else imore = 0;
@@ -985,15 +1043,15 @@ switch (argC) {
             value2 = malloc((size_t)nLogValuesPerRec*nValueBytes[0]);
           for (hyperN = 0; hyperN < nHypers; hyperN++) {
             for (j = 0; j < numDims; ++j)
-              if (!dimVarys[j]) hyperX.dimCounts[j] = 1;
-            status = HYPER_READ (id, Z, hyperX, buffer);
+              if (!dimVarys[j]) hyperSt.dimCounts[j] = 1;
+            status = HYPER_READ (id, Z, hyperSt, buffer);
             if (status < CDF_OK)
               return QuitCDF(CDFpath, "16.0", status, varName);
             if (!detect) {
               offset = 0;
               for (k = 0, value = buffer; k < nValues;
                    k += iskip, offset += (size_t) nValueBytes[0]) {
-                i = hyperX.recNumber + k / nLogValuesPerRec; 
+                i = hyperSt.recNumber + k / nLogValuesPerRec; 
                 j = k - k / nLogValuesPerRec * nLogValuesPerRec;
                 if (j == 0) {
                   icount = 0; 
@@ -1092,7 +1150,7 @@ switch (argC) {
                 } else fprintf (fp, ",");
               }
 	    }
-            IncrHyperParms (&hyperX, &groups, numDims, ROWmajor(majority),
+            IncrHyperParms (&hyperSt, &groups, numDims, ROWmajor(majority),
                             &nValues);
           }
         } else {
@@ -1113,7 +1171,8 @@ switch (argC) {
                                    1L,
                                    BOO(Z,zVAR_DIMINDICES_,rVARs_DIMINDICES_), 
                                    dimIndices,
-                                   BOO(Z,zVAR_DIMINTERVALS_,rVARs_DIMINTERVALS_), 
+                                   BOO(Z,zVAR_DIMINTERVALS_,
+					 rVARs_DIMINTERVALS_), 
                                    dimIntervals,
                                    BOO(Z,zVAR_DIMCOUNTS_,rVARs_DIMCOUNTS_), 
                                    dimCounts,
@@ -1126,7 +1185,6 @@ switch (argC) {
                                      (long) k,
                             GET_, BOO(Z,zVAR_HYPERDATA_,rVAR_HYPERDATA_), buffer,
                             NULL_);
-/*          if (status == VIRTUAL_RECORD_DATA) continue; */
             if (status < CDF_OK)
               return QuitCDF(CDFpath, "18.0", status, varName);
 	    if (!detect) {
@@ -1229,7 +1287,10 @@ switch (argC) {
   	  }
         } 
       }
-      if (toCol2Row && value2 != NULL) free (value2);
+      if (toCol2Row && value2 != NULL) {
+        free (value2);
+        value2 = NULL;
+      }
       if (!detect) fprintf (fp, "\n");
       if (buffer != NULL) cdf_FreeMemory (buffer, FatalError);
       if (working != NULL) cdf_FreeMemory (working, FatalError);
@@ -1246,8 +1307,8 @@ switch (argC) {
   if (numVars > 0) {
     for (k = 0; k < numVars; ++k) 
        cdf_FreeMemory (vars[k], FatalError);
+    cdf_FreeMemory (vars, FatalError);
   }
-
   Exit;
 
 }
@@ -1263,19 +1324,20 @@ CDFstatus status;
 char *msg;
 {
   char text[CDF_STATUSTEXT_LEN+1];
-  printf ("Program failed for file: %s at %s...\n", file, where);
+  fprintf (fp, "Program failed for file: %s at %s...\n", file, where);
   if (status < CDF_OK) {
     CDFlib (SELECT_, CDF_STATUS_, status,
             GET_, STATUS_TEXT_, text,
             NULL_);
-    printf ("ERROR> %s ", text);
-    if (msg != NULL) printf ("(%s)\n", msg);
-    else printf("\n");
+    fprintf (fp, "ERROR> %s ", text);
+    if (msg != NULL) fprintf (fp, "(%s)\n", msg);
+    else fprintf(fp, "\n");
   }
   CDFlib (CLOSE_, CDF_,
           NULL_);
-  printf ("\n");
-  return FALSE;
+  fprintf (fp, "\n");
+  if (fp != stdout) fclose(fp);
+  ExitBAD;
 }
 
 /******************************************************************************
@@ -1458,7 +1520,7 @@ long *maxRec;
   char varName1[CDF_VAR_NAME_LEN256+1], varName2[CDF_VAR_NAME_LEN256+1];
   long recVary1, recVary2, dimVarys1[CDF_MAX_DIMS], dimVarys2[CDF_MAX_DIMS];
   long numDims1, numDims2;
-  char units1[10], units2[10];
+  char units1[21], units2[21];
   double scale;
   int  i;
 
