@@ -52,6 +52,10 @@ extern unsigned _stklen = BORLANDC_STACK_SIZE;
 extern unsigned _ovrbuffer = BORLANDC_OVERLAY_SIZE;
 #endif
 
+#ifdef WIN32
+  static unsigned int oldCodePage = 0;
+#endif
+
 /******************************************************************************
 * Global variables local to this source file.
 ******************************************************************************/
@@ -73,10 +77,8 @@ MAIN {
 #else
   success = EditCDFs (argc, argv);
 #endif
-#if defined(DEBUG)
-  if (cdf_FreeMemory(NULL,FatalError) > 0) DisplayWarning ("Abandoned buffers.");
-#else
-  cdf_FreeMemory (NULL, FatalError);
+#ifdef WIN32
+  if (oldCodePage != 0) SetConsoleOutputCP(oldCodePage);
 #endif
   return BOO(success,EXIT_SUCCESS_,EXIT_FAILURE_);
 }
@@ -240,6 +242,13 @@ char *argV[];
        if (qopError) return FALSE;
        break;
    }
+#ifndef WIN32
+   setlocale(LC_CTYPE, "en_US.UTF-8");
+#else
+   setlocale(LC_CTYPE, ".UTF8");
+   oldCodePage = GetConsoleOutputCP();
+   SetConsoleOutputCP(65001);
+#endif
    /***************************************************************************
    * Initialize.
    ***************************************************************************/
@@ -255,10 +264,10 @@ char *argV[];
    setenv ("TERM", "vt100", 1);
 #endif
    InitializeScreen ();
+
    /***************************************************************************
    * Edit CDF(s).
    ***************************************************************************/
-/*   CDFsetValidate (VALIDATEFILEon); */
    if (promptForSpec)
      status = SpecificationPrompt (CDFspec, useFormat, negToPosFp0, zMode,
 				   workingCache, stageCache, compressCache);
@@ -350,8 +359,8 @@ long compressCache;
     ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, INFOkey_EDIT, NUL
   };
   static struct ItemWindowStruct IW = {
-     0, 0, 80, label, 1, header, 0, NULL, 0, NULL, NULL, NULL, 0, 0, NULL,
-     NULL, REFRESHkey_FSI, TRUE, NSkey_FSI, PSkey_FSI
+     0, 0, 80, label, 1, header, 0, NULL, 0, NULL, NULL, NULL, NULL, 0, 0,
+     NULL, NULL, REFRESHkey_FSI, TRUE, NSkey_FSI, PSkey_FSI
   };
   AOSs6 (infoLines, BLANKs78, BLANKs78, BLANKs78,
 	 " ", "Enter any key to continue...", "")
@@ -601,6 +610,7 @@ struct ItemWindowStruct *IW;
        IW->iLineNs[CDFn] = CDFn;
        IW->iCols[CDFn] = 0;
        IW->iLens[CDFn] = (int) MINIMUM(CDFs_NAME_LEN,nameLen);
+       IW->ibLens[CDFn] = (int) MINIMUM(CDFs_NAME_LEN,nameLen);
     }
   }
   else {
@@ -890,7 +900,7 @@ Logical *closed;
      zMODE0key_EDIT, zMODE1key_EDIT, zMODE2key_EDIT, NUL };
    static char label[6+DU_MAX_NAME_LEN+2+1];
    static struct ItemWindowStruct IW = {
-      0, 0, 80, label, 3, hLines, 0, NULL, 0, NULL, NULL, NULL, 4,
+      0, 0, 80, label, 3, hLines, 0, NULL, 0, NULL, NULL, NULL, NULL, 4,
       1, NULL, NULL, REFRESHkey_FSI, FALSE, NUL, NUL
    };
    /***************************************************************************
@@ -910,6 +920,7 @@ Logical *closed;
      IW.iLineNs = iLineNsBrowse;
      IW.iCols = iColsBrowse;
      IW.iLens = iLensBrowse;
+     IW.ibLens = iLensBrowse;
      IW.tLines = tLinesBrowse;
      IW.exitChars = exitCharsBrowse;
    }
@@ -920,6 +931,7 @@ Logical *closed;
      IW.iLineNs = iLineNsEdit;
      IW.iCols = iColsEdit;
      IW.iLens = iLensEdit;
+     IW.ibLens = iLensEdit;
      IW.tLines = tLinesEdit;
      IW.exitChars = exitCharsEdit;
    }
@@ -930,7 +942,6 @@ Logical *closed;
    status = CDFlib (SELECT_, CDF_CACHESIZE_, workingCache,
 			     STAGE_CACHESIZE_, stageCache,
 			     COMPRESS_CACHESIZE_, compressCache,
-/*			     CDF_READONLY_MODE_, readonlyMode, */
 			     CDF_zMODE_, zMode,
 			     CDF_NEGtoPOSfp0_MODE_, negToPosFp0Mode,
 		    NULL_);
@@ -984,8 +995,7 @@ Logical *closed;
 		 ItemWindow (DELETEiw, &IW);
 		 return FALSE;
 	       }
-	     }
-	     else {
+	     } else {
 	       if (!EditAttrsX(TRUE,CDFname,LogicalFALSE)) {
 		 ItemWindow (DELETEiw, &IW);
 		 return FALSE;
@@ -1009,8 +1019,7 @@ Logical *closed;
 		 ItemWindow (DELETEiw, &IW);
 		 return FALSE;
 	       }
-	     }
-	     else {
+	     } else {
 	       if (!EditAttrsX(FALSE,CDFname,useFormat)) {
 		 ItemWindow (DELETEiw, &IW);
 		 return FALSE;
