@@ -70,8 +70,8 @@ Logical useFormat;
    };
    static char label[6+DU_MAX_NAME_LEN+13+1];
    static struct ItemWindowStruct IW = {
-      0, 0, 80, label, 2, header, 0, NULL, 0, NULL, NULL, NULL, 0, 0, NULL,
-      NULL, REFRESHkey_FSI, TRUE, NSkey_FSI, PSkey_FSI
+      0, 0, 80, label, 2, header, 0, NULL, 0, NULL, NULL, NULL, NULL, 0, 0,
+      NULL, NULL, REFRESHkey_FSI, TRUE, NSkey_FSI, PSkey_FSI
    };
    int varJump = BOO(Z,7,6);
    static Logical first = TRUE;
@@ -564,7 +564,8 @@ struct ItemWindowStruct *IW;
       CatNcharacters (IW->iLines[(int)varN], VARNAME_FIELD_BLANKS, (int) ' ');
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
-      IW->iLens[curItem] = strlen(field);
+      IW->iLens[curItem] = (int) strlen(field);
+      IW->ibLens[curItem] = (int) strlen(field);
       curCol += VARNAME_FIELD_LEN + VARNAME_FIELD_BLANKS;
       curItem++;
       /************************************************************************
@@ -585,7 +586,8 @@ struct ItemWindowStruct *IW;
       CatNcharacters (IW->iLines[(int)varN], DATASPEC_FIELD_BLANKS, (int) ' ');
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
-      IW->iLens[curItem] = strlen(field);
+      IW->iLens[curItem] = (int) strlen(field);
+      IW->ibLens[curItem] = (int) strlen(field);
       curCol += DATASPEC_FIELD_LEN + DATASPEC_FIELD_BLANKS;
       curItem++;
       /************************************************************************
@@ -611,7 +613,8 @@ struct ItemWindowStruct *IW;
 			(int) ' ');
 	IW->iLineNs[curItem] = (int) varN;
 	IW->iCols[curItem] = curCol;
-	IW->iLens[curItem] = strlen (field);
+	IW->iLens[curItem] = (int) strlen (field);
+	IW->ibLens[curItem] = (int) strlen (field);
 	curCol += DIMENSIONS_FIELD_LEN + DIMENSIONS_FIELD_BLANKS;
 	curItem++;
       }
@@ -633,7 +636,8 @@ struct ItemWindowStruct *IW;
       CatNcharacters (IW->iLines[(int)varN], VARIANCES_FIELD_BLANKS, (int)' ');
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
-      IW->iLens[curItem] = strlen (field);
+      IW->iLens[curItem] = (int) strlen (field);
+      IW->ibLens[curItem] = (int) strlen (field);
       curCol += VARIANCES_FIELD_LEN + VARIANCES_FIELD_BLANKS;
       curItem++;
       /************************************************************************
@@ -650,7 +654,8 @@ struct ItemWindowStruct *IW;
       CatNcharacters (IW->iLines[(int)varN], 1, (int) ' ');
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
-      IW->iLens[curItem] = strlen(field);
+      IW->iLens[curItem] = (int) strlen(field);
+      IW->ibLens[curItem] = (int) strlen(field);
       curCol += strlen(field) + 1;
       curItem++;
       /************************************************************************
@@ -661,7 +666,8 @@ struct ItemWindowStruct *IW;
       CatNcharacters (IW->iLines[(int)varN], 1, (int) ' ');
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
-      IW->iLens[curItem] = strlen (field);
+      IW->iLens[curItem] = UTF8StrLength (field, (int)strlen(field));
+      IW->ibLens[curItem] = (int) strlen (field);
       curCol += strlen(field) + 1;
       curItem++;
       /************************************************************************
@@ -671,7 +677,8 @@ struct ItemWindowStruct *IW;
       strcatX (IW->iLines[(int)varN], field, 0);
       IW->iLineNs[curItem] = (int) varN;
       IW->iCols[curItem] = curCol;
-      IW->iLens[curItem] = strlen(field);
+      IW->iLens[curItem] = (int) strlen(field);
+      IW->ibLens[curItem] = (int) strlen(field);
       curItem++;
    }
    if (nVars > MANY_VARs) MessageWindow (NULL);
@@ -697,9 +704,10 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
   static Logical first = TRUE;
   static int vvCols[1+CDF_MAX_DIMS+1];
   static int vvLens[1+CDF_MAX_DIMS+1];
+  static int vvbLens[1+CDF_MAX_DIMS+1];
   static int iLineNs[1+CDF_MAX_DIMS+1] = { 0,0,0,0,0,0,0,0,0,0,0,0 };
-  static char *vString;
-  static char vLine[MAX_SCREENLINE_LEN+1];
+  static char *vString;			/* just variable data in string. */
+  static char vLine[MAX_SCREENLINE_LEN+1];	/* data with rec # and index */ 
   static char label[12+CDF_VAR_NAME_LEN256+9+1];
   static char *iLines[] = { vLine };
   static char *header[] = {
@@ -714,8 +722,8 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
     HELPkey_FSI, NEXTVARkey_EDIT, NUL
   };
   static struct ItemWindowStruct IW = {
-    0, 0, 80, label, 1, header, 1, iLines, 0, iLineNs, vvCols, vvLens, 1,
-    3, trailer, exitChars, REFRESHkey_FSI, FALSE, NUL, NUL
+    0, 0, 80, label, 1, header, 1, iLines, 0, iLineNs, vvCols, vvLens, vvbLens,
+    1, 3, trailer, exitChars, REFRESHkey_FSI, FALSE, NUL, NUL
   };
   /***************************************************************************
   * First time...
@@ -974,6 +982,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 		  NULL, 9, 0, 80, 1, NULL, 0, NULL, 1, NULL, NULL,
 		  REFRESHkey_FSI, SOLkey_FSI, EOLkey_FSI, INSERTorOVERkey_FSI
 	       };
+	       int ix;
 	       if (browseOnly) {
 		 EncodeKeyDefinitions (1, trailerBrowse, EXITkey_FSI,
 				       HELPkey_FSI);
@@ -994,10 +1003,10 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
 	       nBytes = (size_t) (PW.maxChars + 1);
 	       PW.value = (char *) cdf_AllocateMemory (nBytes, FatalError);
 	       strcpyX (PW.value, vString, PW.maxChars);
+	       ix = UTF8StrLength (PW.value, (int)nBytes);
 	       PromptWindow (NEWpw, &PW,
 			     (int) BOO(STRINGdataType(dataType),
-				       strlen(PW.value)-1,
-				       strlen(PW.value)), LogicalTRUE);
+				       ix-1, ix), LogicalTRUE);
 	       for (;;) {
 		  if (EnterPW(&PW,VARVALUEhelpID)) {
 		    long nElemsEntered; void *newBinary;
@@ -1011,7 +1020,6 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
                     }      
 		    if (DecodeValues(PW.value,dataType,
 				     &nElemsEntered,&newBinary,style)) {
-/*		      if (nElemsEntered == numElems) { */
 		      if (nElemsEntered <= numElems) {
 			status = CDFlib (PUT_, VAR_DATA(Z), newBinary,
 					 NULL_);
@@ -1186,7 +1194,7 @@ size_t width;
    CDFstatus status; int dimN; Logical virtual;
    static char virtualT[] = " <virtual>";
    int itemN = 0, availCols;
-   int style;
+   int style, n;
    /***************************************************************************
    * Encode record number.
    ***************************************************************************/
@@ -1240,92 +1248,93 @@ size_t width;
      if (!isnan((double)*(float *)binary) && 
          !isinf((double)*(float *)binary) &&
          *(float *)binary <= DEFAULT_FLOAT_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
      } else
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
    } else if (DOUBLEdataType(dataType)) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          *(double *)binary <= DEFAULT_DOUBLE_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
      } else
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
    } else if (dataType == CDF_EPOCH) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          *(double *)binary <= DEFAULT_EPOCH_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
      } else
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
    } else if (dataType == CDF_EPOCH16) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          !isnan(*(((double *)binary)+1)) && !isinf(*(((double *)binary)+1)) &&
          *(double *)binary <= DEFAULT_EPOCH16_PADVALUE &&
          *(((double *)binary)+1) <= DEFAULT_EPOCH16_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
      } else
-       EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
-                           -BOO(virtual,availCols,0), availCols, style,
-                           (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+       n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
+			       -BOO(virtual,availCols,0), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
    } else
-     EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
-		         -BOO(virtual,availCols,-1), availCols, style,
-		         (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
+     n = EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
+			       -BOO(virtual,availCols,-1), availCols, style,
+			       (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
    if (virtual) strcatX (vLine, virtualT, 0);
-   vvLens[itemN] = strlen(&vLine[vvCols[itemN]]);
+   vvLens[itemN] =  UTF8StrLength (&vLine[vvCols[itemN]],
+                                   (int)strlen(&vLine[vvCols[itemN]]));
    *nItems = itemN + 1;
    if (FLOAT4dataType(dataType)) {
      if (!isnan((double)*(float *)binary) &&
          !isinf((double)*(float *)binary) &&
          *(float *)binary <= DEFAULT_FLOAT_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
      } else
-       EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
    } else if (DOUBLEdataType(dataType)) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          *(double *)binary <= DEFAULT_DOUBLE_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
      } else
-       EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
    } else if (dataType == CDF_EPOCH) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          *(double *)binary <= DEFAULT_EPOCH_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
      } else
-       EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
    } else if (dataType == CDF_EPOCH16) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          !isnan(*(((double *)binary)+1)) && !isinf(*(((double *)binary)+1)) &&
          *(double *)binary <= DEFAULT_EPOCH16_PADVALUE &&
          *(((double *)binary)+1) <= DEFAULT_EPOCH16_PADVALUE) {
-       EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
      } else
-       EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
-                           MAX_nonSTRING_VALUE_LEN, style, width);
+       n = EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
+			       MAX_nonSTRING_VALUE_LEN, style, width);
    } else           
-     EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
-		         BOO(STRINGdataType(dataType),
+     n = EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
+			     BOO(STRINGdataType(dataType),
 			     (int)(numElems + 3),MAX_nonSTRING_VALUE_LEN),
-		         style, width);
+			     style, width);
    return TRUE;
 }
 
@@ -1342,7 +1351,8 @@ Logical *changed;        /* Only report changes that affect the caller.
 long nVars;
 {
    CDFstatus status; static Logical first = TRUE;
-   AOSs6 (header, BLANKs78, BLANKs78, BLANKs78, BLANKs78, BLANKs78, BLANKs78)
+   AOSs6 (header, BLANKs78, BLANKs78, BLANKs78, BLANKs78, BLANKs78,
+	  BLANKs78)
    AOSs1 (trailer, "Select: ________   Exit: ________   Help: ________   Next variable: ________")
    static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI,
 			      NEXTVARkey_EDIT, NUL };
@@ -1372,8 +1382,8 @@ long nVars;
    static int iLensEdit[] = { 18,24,19,18,23,20,16 };
    static int iLensEdit2[] = { 18,24,19,18,23,20,21,21 };
    static struct ItemWindowStruct IW = {
-      0, 0, 80, label, 6, header, 3, NULL, 0, NULL, NULL, NULL, 3, 1, trailer,
-      exitChars, REFRESHkey_FSI, FALSE, NUL, NUL
+      0, 0, 80, label, 6, header, 3, NULL, 0, NULL, NULL, NULL, NULL, 3, 1,
+      trailer, exitChars, REFRESHkey_FSI, FALSE, NUL, NUL
    };
    /***************************************************************************
    * First time...
@@ -1389,6 +1399,7 @@ long nVars;
        IW.iLineNs = iLineNsBrowse;
        IW.iCols = iColsBrowse;
        IW.iLens = iLensBrowse;
+       IW.ibLens = iLensBrowse;
      }
      else {
        if (RegularVar(Z, varN)) {
@@ -1397,12 +1408,14 @@ long nVars;
          IW.iLineNs = iLineNsEdit;
          IW.iCols = iColsEdit;
          IW.iLens = iLensEdit;
+         IW.ibLens = iLensEdit;
        } else {
          IW.iLines = itemsEdit2;
          IW.nItems = 8;
          IW.iLineNs = iLineNsEdit2;
          IW.iCols = iColsEdit2;
          IW.iLens = iLensEdit2;
+         IW.ibLens = iLensEdit2;
        }
      }
    /***************************************************************************
@@ -1850,7 +1863,8 @@ Logical center;		/* Center messages displayed? */
     else style = EPOCH3_STYLE;
   }
   strcpyX (IW->hLines[4], " Pad value: ", 0);
-  padBinary = cdf_AllocateMemory ((size_t) (numElems * CDFelemSize(dataType)),
+  padBinary = cdf_AllocateMemory ((size_t) (numElems * CDFelemSize(dataType) +
+                                            (STRINGdataType(dataType)?1:0)),
 				  FatalError);
   status = CDFlib (GET_, VAR_PADVALUE(Z), padBinary,
 		   NULL_);
@@ -1860,9 +1874,12 @@ Logical center;		/* Center messages displayed? */
         maxWidth = (IW->nColsTotal - 2) - strlen(IW->hLines[4]) -
 		    strlen(defaultT);
         if (STRINGdataType(dataType)) {
+          memset ((char *) padBinary, (int)'\0', (size_t) numElems);
+/*
           int ix;
           for (ix = 0; ix < (int) numElems; ++ix)
              *(((char *) padBinary)+ix) = (char) '\0';
+*/
         }
         EncodeValuesFormat (dataType, numElems, padBinary, EofS(IW->hLines[4]),
 			    format, -1, maxWidth, style,
@@ -1874,8 +1891,8 @@ Logical center;		/* Center messages displayed? */
         if (!ReportStatus(status,center)) return FALSE;
         maxWidth = (IW->nColsTotal - 2) - strlen(IW->hLines[4]);
         EncodeValuesFormat (dataType, numElems, padBinary, EofS(IW->hLines[4]),
-			  format, -1, maxWidth, style,
-		          (size_t) sizeof(BLANKs78)-strlen(IW->hLines[4]));
+			    format, -1, maxWidth, style,
+			    (size_t) sizeof(BLANKs78)-strlen(IW->hLines[4]));
         break;
     }
   }
@@ -2087,7 +2104,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
     NULL, 14, 0, 80, 1, NULL, 0, NULL, 1, NULL, NULL, REFRESHkey_FSI,
     SOLkey_FSI, EOLkey_FSI, INSERTorOVERkey_FSI
   };
-  int style;
+  int style, n;
   status = CDFlib (SELECT_, VAR(zVar), varN,
 		   GET_, VAR_DATATYPE(zVar), &dataType,
 			 VAR_NUMELEMS(zVar), &numElems,
@@ -2141,51 +2158,50 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
     if (!isnan((double)*(float *)binary) &&
         !isinf((double)*(float *)binary) &&
         *(float *)binary <= DEFAULT_FLOAT_PADVALUE) {
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
+			      (int) nBytes-1, style, (size_t) nBytes);
     } else
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1,
+			      (int) nBytes-1, style, (size_t) nBytes);
   } else if (DOUBLEdataType(dataType)) {
     if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
         *(double *)binary <= DEFAULT_DOUBLE_PADVALUE) {
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
+			      (int) nBytes-1, style, (size_t) nBytes);
     } else
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1,
+			      (int) nBytes-1, style, (size_t) nBytes);
   } else if (dataType == CDF_EPOCH) {
     if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
         *(double *)binary <= DEFAULT_EPOCH_PADVALUE) {
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
+			      (int) nBytes-1, style, (size_t) nBytes);
     } else
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0,
+			      (int) nBytes-1, style, (size_t) nBytes);
   } else if (dataType == CDF_EPOCH16) {
     if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
         !isnan(*(((double *)binary)+1)) && !isinf(*(((double *)binary)+1)) &&
         *(double *)binary <= DEFAULT_EPOCH16_PADVALUE &&
         *(((double *)binary)+1) <= DEFAULT_EPOCH16_PADVALUE) {
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
+			      (int) nBytes-1, style, (size_t) nBytes);
     } else
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0,
-                          (int) nBytes-1, style, (size_t) nBytes);
+      n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0,
+			      (int) nBytes-1, style, (size_t) nBytes);
   } else
-    EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1, 
-		        (int) nBytes-1, style, (size_t) nBytes);
+    n = EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1, 
+			    (int) nBytes-1, style, (size_t) nBytes);
   cdf_FreeMemory (binary, FatalError);
   if (format != NULL) cdf_FreeMemory (format, FatalError);
   cursorAt = BOO(STRINGdataType(dataType),
-		 strlen(PWt.value) - 1,strlen(PWt.value));
+		 n - 1, n);
   PromptWindow (NEWpw, &PWt, cursorAt, LogicalTRUE);
   for (;;) {
      if (EnterPW(&PWt,PADVALUEhelpID)) {
        long nElemsEntered; void *newBinary;
        if (DecodeValues(PWt.value,dataType,
 			&nElemsEntered,&newBinary,style)) {
-/*	 if (nElemsEntered == numElems) { */
 	 if (nElemsEntered <= numElems) {
 	   status = CDFlib (PUT_, VAR_PADVALUE(zVar), newBinary,
 			    NULL_);
