@@ -197,9 +197,10 @@ int helpId;
   static int iLineNs[] = { 1, 1 };
   static int iCols[] = { 18, 53 };
   static int iLens[] = { 5, 4 };
+  static int ibLens[] = { 5, 4 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    0, 0, 0, label, 0, header, 3, items, 2, iLineNs, iCols, iLens, 3,
+    0, 0, 0, label, 0, header, 3, items, 2, iLineNs, iCols, iLens, ibLens, 3,
     1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   Logical answer = FALSE;
@@ -259,17 +260,19 @@ int helpId;
   static int iLineNs2[] = { 1, 1, 1 };
   static int iCols1[] = { 18, 53 };
   static int iLens1[] = { 5, 4 };
+  static int ibLens1[] = { 5, 4 };
   static int iCols2[] = { 11, 30, 53 };
   static int iLens2[] = { 11, 11, 4 };
+  static int ibLens2[] = { 11, 11, 4 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt;
   static struct ItemWindowStruct IWt1 = {
-    0, 0, 0, label, 0, header, 3, items1, 2, iLineNs1, iCols1, iLens1, 3,
-    1, trailer, exitChars, REFRESHkey_FSI, FALSE
+    0, 0, 0, label, 0, header, 3, items1, 2, iLineNs1, iCols1, iLens1, ibLens1,
+    3, 1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   static struct ItemWindowStruct IWt2 = {
-    0, 0, 0, label, 0, header, 3, items2, 3, iLineNs2, iCols2, iLens2, 3,
-    1, trailer, exitChars, REFRESHkey_FSI, FALSE
+    0, 0, 0, label, 0, header, 3, items2, 3, iLineNs2, iCols2, iLens2, ibLens2,
+    3, 1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   Logical answer = FALSE;
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI,
@@ -351,7 +354,7 @@ struct PromptWindowStruct *PW;
 int helpId;
 {
   for (;;) {
-     PromptWindow (READiw, PW);
+     PromptWindow (READpw, PW);
      switch (PW->key) {
        case EXITkey_FSI:
 	 return FALSE;
@@ -431,10 +434,11 @@ Logical SelectMajority () {
   static int iLineNs[] = { 0, 1 };
   static int iCols[] = { 0, 0 };
   static int iLens[] = { 3, 6 };
+  static int ibLens[] = { 3, 6 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
   status = CDFlib (GET_, CDF_MAJORITY_, &majority,
@@ -477,10 +481,11 @@ Logical SelectFormat () {
   static int iLineNs[] = { 0, 1 };
   static int iCols[] = { 0, 0 };
   static int iLens[] = { 6, 5 };
+  static int ibLens[] = { 6, 5 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
   status = CDFlib (GET_, CDF_FORMAT_, &format,
@@ -527,10 +532,11 @@ Logical SelectEncoding () {
   static int iLineNs[] = { 0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2 };
   static int iCols[] = { 0,10,16,24,30,37,49,61,0,10,16,24,30,37,49,61,0,10,20,30 };
   static int iLens[] = { 4,3,5,3,2,9,9,10,7,3,5,3,4,9,9,10,7,8,8,8 };
+  static int ibLens[] = { 4,3,5,3,2,9,9,10,7,3,5,3,4,9,9,10,7,8,8,8 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 3, items, 20, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 3, items, 20, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   char selectedEncoding[10+1], delim = ' ', *selected = NULL, *tmpStr;
 
@@ -588,10 +594,11 @@ Logical *changed;	/* Assumed initialized to FALSE by caller. */
   static int iLineNs[] = { 0,0,0 };
   static int iCols[] = { 0,16,33 };
   static int iLens[] = { 11,12,13 };
+  static int ibLens[] = { 11,12,13 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    14, 0, 80, NULL, 1, header, 1, items, 3, iLineNs, iCols, iLens, 1, 1,
-    trailer, exitChars, REFRESHkey_FSI, TRUE
+    14, 0, 80, NULL, 1, header, 1, items, 3, iLineNs, iCols, iLens, ibLens, 1,
+    1, trailer, exitChars, REFRESHkey_FSI, TRUE
   };
   static long sRecordsTypes[] = {
     NO_SPARSERECORDS, PAD_SPARSERECORDS, PREV_SPARSERECORDS
@@ -643,10 +650,11 @@ Logical *changed;	/* Assumed initialized to FALSE by caller. */
   static int iLineNs[] = { 0,0,0,0,0 };
   static int iCols[] = { 0,9,19,30,42 };
   static int iLens[] = { 4,5,6,7,7 };
+  static int ibLens[] = { 4,5,6,7,7 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IW = {
     0, 0, 80, NULL, 1, header, 1, items, nCOMPRESSIONs, iLineNs, iCols,
-    iLens, 1, 1, trailer, exitChars, REFRESHkey_FSI, TRUE
+    iLens, ibLens, 1, 1, trailer, exitChars, REFRESHkey_FSI, TRUE
   };
   if (first) {
     EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
@@ -771,10 +779,11 @@ char *label;            /* If NULL, no label. */
   static int iLineNs[] = { DTiwLINEnS };
   static int iCols[] = { DTiwCOLs };
   static int iLens[] = { DTiwLENs };
+  static int ibLens[] = { DTiwLENs };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    4, 1, 78, NULL, 1, header, 3, items, 17, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    4, 1, 78, NULL, 1, header, 3, items, 17, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   static Logical first = TRUE; int itemN;
   char selectedDataType[15+1], delim = ' ', *selected = NULL, *tmpStr;
@@ -816,16 +825,18 @@ long *numElems;
 char *label;
 {
   static char *headerCHAR[] = {
-    "Enter number of elements (characters) for CDF_CHAR data type..."
+    "Enter number of elements (bytes not characters) for CDF_CHAR data type...",
+    "Note: Each UTF-8 encoding character could be a multi-byte character." 
   };
   static char *headerUCHAR[] = {
-    "Enter number of elements (characters) for CDF_UCHAR data type..."
+    "Enter number of elements (bytes not characters) for CDF_UCHAR data type...",
+    "Note: Each UTF-8 encoding character could be a multi-byte character."
   };
   AOSs1 (trailer, "Enter: ________    Exit: ________    Help: ________")
   static char value[MAX_NUMELEMS_LEN+1];
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct PromptWindowStruct PWt = {
-    NULL, 4, 1, 78, 1, NULL, MAX_NUMELEMS_LEN, value, 1, trailer, exitChars,
+    NULL, 4, 1, 78, 2, NULL, MAX_NUMELEMS_LEN, value, 1, trailer, exitChars,
     REFRESHkey_FSI, SOLkey_FSI, EOLkey_FSI, INSERTorOVERkey_FSI
   };
   static Logical first = TRUE; long tNumElems;
@@ -871,10 +882,11 @@ Logical SelectChecksum () {
   static int iLineNs[] = { 0, 1 };
   static int iCols[] = { 0, 0 };
   static int iLens[] = { 4, 3 };
+  static int ibLens[] = { 4, 3 };
   static int exitChars[] = { ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI, NUL };
   static struct ItemWindowStruct IWt = {
-    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, 3, 1,
-    trailer, exitChars, REFRESHkey_FSI, FALSE
+    12, 0, 80, NULL, 1, header, 2, items, 2, iLineNs, iCols, iLens, ibLens, 3,
+    1, trailer, exitChars, REFRESHkey_FSI, FALSE
   };
   EncodeKeyDefinitions (1, trailer, ENTERkey_FSI, EXITkey_FSI, HELPkey_FSI);
   status = CDFlib (GET_, CDF_CHECKSUM_, &checksum,
