@@ -39,14 +39,14 @@ int virtual;
   CDFstatus status;
   long attrN;
   long varyCount;
-  int dimN;
+  int dimN, extra;
   long dimSizes[CDF_MAX_DIMS];
   size_t nValueBytes[1];
   Byte1 **handles[1];
   long nHypers, hyperN;
   long nValues, valueN;
   struct GroupStruct groups;
-  struct HyperStruct hyper;
+  struct HyperStruct hyperSt;
 
   /****************************************************************************
   * Initialize for this variable.
@@ -82,16 +82,18 @@ int virtual;
   AllocateBuffers (Var->varMaxRec + 1, Var->numDims, dimSizes, &groups, 0, 1,
 		   handles, nValueBytes, ROWmajor(majority), MINnHYPERS,
 		   FatalError);
-  Var->min = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+  if (STRINGdataType(Var->dataTypeV)) extra = 1;
+  else extra = 0;
+  Var->min = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 			     FatalError);
-  Var->max = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+  Var->max = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 			     FatalError);
-  Var->last = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+  Var->last = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 			      FatalError);
   if (Var->rangeCheckVar) {
-    Var->minINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+    Var->minINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 				      FatalError);
-    Var->maxINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes,
+    Var->maxINrange = cdf_AllocateMemory ((size_t) Var->nValueBytes+extra,
 				      FatalError);
   }
   /****************************************************************************
@@ -100,20 +102,23 @@ int virtual;
   status = CDFlib (SELECT_, VAR(Var->Z), Var->varN,
 		   NULL_);
   if (!StatusHandlerStats(status)) return FALSE;
-  InitHyperParms (&hyper, &groups, Var->numDims, &nHypers, &nValues);
+  InitHyperParms (&hyperSt, &groups, Var->numDims, &nHypers, &nValues);
   for (hyperN = 0; hyperN < nHypers; hyperN++) {
      status = CDFlib (SELECT_, BOO(Var->Z,zVAR_RECNUMBER_,
-					  rVARs_RECNUMBER_), hyper.recNumber,
+					  rVARs_RECNUMBER_), hyperSt.recNumber,
 			       BOO(Var->Z,zVAR_RECCOUNT_,
-					  rVARs_RECCOUNT_), hyper.recCount,
+					  rVARs_RECCOUNT_), hyperSt.recCount,
 			       BOO(Var->Z, zVAR_RECINTERVAL_,
-					   rVARs_RECINTERVAL_), hyper.recInterval,
+					   rVARs_RECINTERVAL_),
+			      				 hyperSt.recInterval,
 			       BOO(Var->Z,zVAR_DIMINDICES_,
-					  rVARs_DIMINDICES_), hyper.dimIndices,
+					  rVARs_DIMINDICES_),
+			      				 hyperSt.dimIndices,
 			       BOO(Var->Z,zVAR_DIMCOUNTS_,
-					  rVARs_DIMCOUNTS_), hyper.dimCounts,
+					  rVARs_DIMCOUNTS_), hyperSt.dimCounts,
 			       BOO(Var->Z, zVAR_DIMINTERVALS_,
-					   rVARs_DIMINTERVALS_), hyper.dimIntervals,
+					   rVARs_DIMINTERVALS_),
+			      				 hyperSt.dimIntervals,
 		      GET_, BOO(Var->Z,zVAR_HYPERDATA_,
 				       rVAR_HYPERDATA_), Var->buffer,
 		      NULL_);
@@ -128,7 +133,7 @@ int virtual;
 	}
 	if (Var->checkMonotonicVar) Monotonic (Var);
      }
-     IncrHyperParms (&hyper, &groups, Var->numDims, ROWmajor(majority),
+     IncrHyperParms (&hyperSt, &groups, Var->numDims, ROWmajor(majority),
 		     &nValues);
      CHECKforABORTso
   }
@@ -271,7 +276,11 @@ struct VarStructST *Var;
     use = TRUE;
   if (use) {
     ASSIGNx (Var->min, Var->value, Var->dataTypeV, Var->numElemsV);
+    if (STRINGdataType(Var->dataTypeV))
+      *(((char *)Var->min)+(int)Var->numElemsV) = '\0';
     ASSIGNx (Var->max, Var->value, Var->dataTypeV, Var->numElemsV);
+    if (STRINGdataType(Var->dataTypeV))
+      *(((char *)Var->max)+(int)Var->numElemsV) = '\0';
     if (Var->rangeCheckVar) {
       if (LTx(Var->value,Var->validmin,Var->dataTypeV,Var->numElemsV))
         Var->low++;
@@ -282,8 +291,12 @@ struct VarStructST *Var;
 	  Var->oneINrange = TRUE;
 	  ASSIGNx (Var->minINrange, Var->value, Var->dataTypeV,
 		   Var->numElemsV);
+	  if (STRINGdataType(Var->dataTypeV))
+	    *(((char *)Var->minINrange)+(int)Var->numElemsV) = '\0';
 	  ASSIGNx (Var->maxINrange, Var->value, Var->dataTypeV,
 		   Var->numElemsV);
+	  if (STRINGdataType(Var->dataTypeV))
+	    *(((char *)Var->maxINrange)+(int)Var->numElemsV) = '\0';
         }
     }
     Var->minmaxInited = TRUE;
@@ -305,11 +318,15 @@ struct VarStructST *Var;
   else
     use = TRUE;
   if (use) {
-    if (LTx(Var->value,Var->min,Var->dataTypeV,Var->numElemsV))
+    if (LTx(Var->value,Var->min,Var->dataTypeV,Var->numElemsV)) {
       ASSIGNx (Var->min, Var->value, Var->dataTypeV, Var->numElemsV);
-    else {
+      if (STRINGdataType(Var->dataTypeV))
+        *(((char *)Var->min)+(int)Var->numElemsV) = '\0'; 
+    } else {
       if (GTx(Var->value,Var->max,Var->dataTypeV,Var->numElemsV)) {
         ASSIGNx (Var->max, Var->value, Var->dataTypeV, Var->numElemsV);
+        if (STRINGdataType(Var->dataTypeV))
+          *(((char *)Var->max)+(int)Var->numElemsV) = '\0'; 
       }
     }
     if (Var->rangeCheckVar) {
@@ -320,22 +337,31 @@ struct VarStructST *Var;
 	  Var->high++;
         else
 	  if (Var->oneINrange) {
-	    if (LTx(Var->value,Var->minINrange,Var->dataTypeV,Var->numElemsV))
+	    if (LTx(Var->value,Var->minINrange,Var->dataTypeV,Var->numElemsV)) {
 	      ASSIGNx (Var->minINrange, Var->value, Var->dataTypeV,
 		       Var->numElemsV);
-	    else
+              if (STRINGdataType(Var->dataTypeV))
+	        *(((char *)Var->minINrange)+(int)Var->numElemsV) = '\0'; 
+	    } else {
 	      if (GTx(Var->value,Var->maxINrange,
 		      Var->dataTypeV,Var->numElemsV)) {
 	        ASSIGNx (Var->maxINrange, Var->value, Var->dataTypeV,
 		         Var->numElemsV);
+                if (STRINGdataType(Var->dataTypeV))
+	          *(((char *)Var->maxINrange)+(int)Var->numElemsV) = '\0'; 
 	      }
+	    }
 	  }
 	  else {
 	    Var->oneINrange = TRUE;
 	    ASSIGNx (Var->minINrange, Var->value, Var->dataTypeV,
 		     Var->numElemsV);
+            if (STRINGdataType(Var->dataTypeV))
+	      *(((char *)Var->minINrange)+(int)Var->numElemsV) = '\0'; 
 	    ASSIGNx (Var->maxINrange, Var->value, Var->dataTypeV,
 		     Var->numElemsV);
+            if (STRINGdataType(Var->dataTypeV))
+	      *(((char *)Var->maxINrange)+(int)Var->numElemsV) = '\0'; 
 	  }
     }
   }
@@ -361,6 +387,8 @@ struct VarStructST *Var;
   if (use) {
     if (!Var->monoInited) {
       ASSIGNx (Var->last, Var->value, Var->dataTypeV, Var->numElemsV);
+      if (STRINGdataType(Var->dataTypeV))
+        *(((char *)Var->last)+(int)Var->numElemsV) = '\0'; 
       Var->monoState = _Init;
       Var->monoInited = TRUE;
     }
@@ -532,8 +560,12 @@ struct VarStructST *Var;
     status = GetFILLVALEntry (id, Var->Z, VirtualVar.varN,  &dataTypeE,
 			      &numElemsE, &(VirtualVar.fillval));
     if (status != CDF_OK) {
-      if (status == BAD_DATA_TYPE)
-	cdf_FreeMemory (VirtualVar.fillval, FatalError);
+      if (status == BAD_DATA_TYPE) {
+	if (VirtualVar.fillval != NULL) {
+          cdf_FreeMemory (VirtualVar.fillval, FatalError);
+          VirtualVar.fillval = NULL;
+        }
+      }
       VirtualVar.ignoreFillsVar = FALSE;
     } else
       VirtualVar.ignoreFillsVar = TRUE;
