@@ -53,6 +53,9 @@ extern unsigned _stklen = BORLANDC_STACK_SIZE;
 ******************************************************************************/
 
 Logical report[3];
+#ifdef WIN32
+  static unsigned int oldCodePage = 0;
+#endif
 
 /******************************************************************************
 * Main.
@@ -67,10 +70,8 @@ MAIN {
 #else
   success = CalculateStatistics (argc, argv);
 #endif
-#if defined(DEBUG)
-  if (cdf_FreeMemory(NULL,FatalError) > 0) DisplayWarning ("Abandoned buffers.");
-#else
-  cdf_FreeMemory (NULL, FatalError);
+#ifdef WIN32
+  if (oldCodePage != 0) SetConsoleOutputCP(oldCodePage);
 #endif
   return BOO(success,EXIT_SUCCESS_,EXIT_FAILURE_);
 }
@@ -108,7 +109,6 @@ char *argV[];
   };
   static char *reportTokens[] = { "errors", "warnings", "informationals" };
 
-/*  CDFsetValidate (VALIDATEFILEon); */
   /****************************************************************************
   * Get qualifiers/options/parameters.
   ****************************************************************************/
@@ -258,6 +258,15 @@ char *argV[];
       if (qopError) return FALSE;
       break;
   }
+
+#if !defined(WIN32)
+  setlocale(LC_CTYPE, "en_US.UTF-8");
+#else
+  setlocale(LC_CTYPE, ".UTF8");
+  oldCodePage = GetConsoleOutputCP();
+  SetConsoleOutputCP(65001);
+#endif
+
   /****************************************************************************
   * Open output file (if specified).
   ****************************************************************************/
@@ -298,7 +307,6 @@ char *argV[];
   * Open/inquire CDF.
   ****************************************************************************/
   status = CDFlib (OPEN_, CDF_, CDFpath, &id,
-/*		   SELECT_, CDF_READONLY_MODE_, READONLYon, */
 		   SELECT_, CDF_zMODE_, zMode,
 			    CDF_NEGtoPOSfp0_MODE_, BOO(negToPosFp0,
 						       NEGtoPOSfp0on,
@@ -524,11 +532,12 @@ struct VarStructST *Var;
 			   BOO(Var->Z,zENTRY_NUMELEMS_,
 				      rENTRY_NUMELEMS_), &numElemsE,
 		     NULL_);
-    if (status == NO_SUCH_ENTRY)
+    if (status == NO_SUCH_ENTRY) {
       Var->rangeCheckVar = FALSE;
-    else {
+    } else {
       if (!StatusHandlerStats(status)) return FALSE;
-      temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE),
+      temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE +
+                                           (STRINGdataType(dataTypeE)?1:0)),
 			         FatalError);
       status = CDFlib (GET_, BOO(Var->Z,zENTRY_DATA_,rENTRY_DATA_), temp,
 		       NULL_);
@@ -536,8 +545,11 @@ struct VarStructST *Var;
 	cdf_FreeMemory (temp, FatalError);
 	return FALSE;
       }
-      Var->validmin = cdf_AllocateMemory ((size_t) (CDFelemSize(Var->dataTypeV) *
-						    Var->numElemsV),
+      if (STRINGdataType(dataTypeE)) *((char *)temp+numElemsE) = '\0';
+      Var->validmin = cdf_AllocateMemory ((size_t) (
+                                              CDFelemSize(Var->dataTypeV) *
+					      Var->numElemsV +
+					      (STRINGdataType(Var->dataTypeV)?1:0)),
 					  FatalError);
       ConvertDataType (dataTypeE, numElemsE, temp, Var->dataTypeV,
 		       Var->numElemsV, Var->validmin);
@@ -556,7 +568,8 @@ struct VarStructST *Var;
       }
       else {
 	if (!StatusHandlerStats(status)) return FALSE;
-	temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE),
+	temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE
+                                             + (STRINGdataType(dataTypeE)?1:0)),
 				   FatalError);
 	status = CDFlib (GET_, BOO(Var->Z,zENTRY_DATA_,rENTRY_DATA_), temp,
 			 NULL_);
@@ -564,8 +577,11 @@ struct VarStructST *Var;
 	  cdf_FreeMemory (temp, FatalError);
 	  return FALSE;
 	}
-	Var->validmax = cdf_AllocateMemory ((size_t) (CDFelemSize(Var->dataTypeV) *
-						      Var->numElemsV),
+        if (STRINGdataType(dataTypeE)) *((char *)temp+numElemsE) = '\0';
+	Var->validmax = cdf_AllocateMemory ((size_t)
+						(CDFelemSize(Var->dataTypeV) *
+						 Var->numElemsV +
+                                                 (STRINGdataType(Var->dataTypeV)?1:0)),
 					    FatalError);
 	ConvertDataType (dataTypeE, numElemsE, temp, Var->dataTypeV,
 			 Var->numElemsV, Var->validmax);
@@ -584,8 +600,10 @@ struct VarStructST *Var;
 			      &(Var->fillval));
     if (status != CDF_OK) {
       if (status == BAD_DATA_TYPE) {
-        cdf_FreeMemory (Var->fillval, FatalError);
-        Var->fillval = NULL;
+        if (Var->fillval != NULL) {
+          cdf_FreeMemory (Var->fillval, FatalError);
+          Var->fillval = NULL;
+        }
       }
       Var->ignoreFillsVar = FALSE;
     } else
@@ -912,7 +930,8 @@ char **argV[];
       case HELPin: {
         int n;
         *argC = 1;
-        *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *), FatalError);
+        *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
+					      FatalError);
 	n = 0;
 	MAKEstrARGv (argV, n, pgmName)
 	CloseDialog (dialogP);
