@@ -93,6 +93,7 @@ long zMode;
 long workingCache, stageCache, compressCache;
 int lineLen, lineIdx, lineIds;
 static char creCDF[] = "creating the CDF";
+static char readG[] = "reading a gAttribute";
 static char creG[] = "creating a gAttribute";
 static char creV[] = "creating a vAttribute";
 static char creZ[] = "creating a zVariable";
@@ -118,6 +119,9 @@ static char cmpVAR[] = "compressing the Variable";
 static char spaVAR[] = "setting the record sparseness for the Variable";
 static char blkVAR[] = "setting the blocking factor for the Variable";
 static char padVAR[] = "setting the pad value for the Variable";
+#ifdef WIN32
+  static unsigned int oldCodePage = 0;
+#endif
 
 /******************************************************************************
 * Main.
@@ -132,10 +136,8 @@ MAIN {
 #else
   success = CreateSkeletonCDF (argc, argv);
 #endif
-#if defined(DEBUG)
-  if (cdf_FreeMemory(NULL,FatalError) > 0) DisplayWarning ("Abandoned buffers.");
-#else
-  cdf_FreeMemory (NULL, FatalError);
+#ifdef WIN32
+  if (oldCodePage != 0) SetConsoleOutputCP(oldCodePage);
 #endif
   return BOO(success,EXIT_SUCCESS_,EXIT_FAILURE_);
 }
@@ -154,12 +156,14 @@ char *argV[];
   char NRVpathX[DU_MAX_PATH_LEN+1];
   Logical comment;
   int i;
+int inGlobal;
   QOP *qop;
   Logical qopError = FALSE;
   static char *validQuals[] = {
     "cdf", "log", "nolog", "delete", "nodelete", "fillval", "nofillval",
     "report", "neg2posfp0", "noneg2posfp0", "about", "zmode", "statistics",
-    "nostatistics", "cache", "warning", "nowarning", "backward", NULL
+    "nostatistics", "cache", "warning", "nowarning", "backward", 
+    NULL
   };
   static int optRequired[] = {
     TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE,
@@ -210,7 +214,7 @@ char *argV[];
 	  DisplayError ("Invalid \"cdf\" qualifier.");
 	  qopError = TRUE;
 	}
-       } else
+      } else
 	  CDFpath[0] = NUL;
       /************************************************************************
       * Check for `report' qualifier.  If absent, use defaults.
@@ -296,6 +300,13 @@ char *argV[];
   done = FALSE;
   lineN = 0;
   inString = FALSE;
+#if !defined(WIN32)
+  setlocale(LC_CTYPE, "en_US.UTF-8");
+#else
+  setlocale(LC_CTYPE, ".UTF8");
+  oldCodePage = GetConsoleOutputCP();
+  SetConsoleOutputCP(65001);
+#endif
   /****************************************************************************
   * Open skeleton table. Try several combinations for the skeleton table path.
   * If the table file contains the ".skt" or ".SKT" extension, then uses it as
@@ -351,6 +362,7 @@ char *argV[];
   WriteOut (stdout, "Making a cdf from skeleton table: \"");
   WriteOut (stdout, SKTpathX);
   WriteOut (stdout, "\"");
+
   /****************************************************************************
   * Open NRV file (may not exist).
   ****************************************************************************/
@@ -409,6 +421,7 @@ char *argV[];
 	 /*********************************************************************
 	 * Newline - change to a blank.
 	 *********************************************************************/
+	 case Cr:
 	 case Nl:
            if (nextItem != CDFPATHfield) {
 	     if (!CharStream((int)' ')) {
@@ -770,7 +783,7 @@ char *item;
   static long VARYdimVarys[CDF_MAX_DIMS] = {
     VARY, VARY, VARY, VARY, VARY, VARY, VARY, VARY, VARY, VARY
   };
-  long numDims = 0, varNum, dimSizes[CDF_MAX_DIMS];
+  long attrNum, numDims = 0, varNum, dimSizes[CDF_MAX_DIMS];
   long *dimVarysP = NULL;  /* Points to the `dimVarys' array to be used. */
   int dN, dNt;		/* Dimension number. */
   void *padValue;
@@ -1041,6 +1054,7 @@ char *item;
 				      COMPRESS_CACHESIZE_, compressCache,
 			     NULL_);
 	    if (!StatusHandlerS2C(status,creCDF)) return FALSE;
+
 	    NextSearchItem (TOKEN, GATTRmark);
 	  }
       }
@@ -1269,10 +1283,11 @@ char *item;
       long gAttrNum;
       strcpyX (gAttrName, item, CDF_ATTR_NAME_LEN256);
       if (!ISTPname (gAttrName) && warning)
-        WriteOutFP (stdout, "Warning: Attribute name: \"%s\" not ISTP compliant... not recommended\n",
+        WriteOutFP (stdout,
+		    "Warning: Attribute name: \"%s\" not ISTP compliant...\n",
                     gAttrName);
       status = CDFlib (CREATE_, ATTR_, gAttrName, GLOBAL_SCOPE, &gAttrNum,
-		       NULL_);
+                       NULL_);
       if (!StatusHandlerS2C(status,creG)) return FALSE;
       NextSearchItem (TOKEN, PERIODmarkOrGa1stENTRYNUMfield);
       break;
@@ -1323,8 +1338,8 @@ char *item;
       int style, allocated;
       allocated = 0;
       if (!STRINGdataType(eDataType)) {
-        if (TT2000dataType(eDataType)) style = TT2000_3_STYLE;
-        else  style = EPOCH0_STYLE;
+	if (TT2000dataType(eDataType)) style = TT2000_3_STYLE;
+	else  style = EPOCH0_STYLE;
 	if (!DecodeValues(item,eDataType,&eNumElems,&valuesB,style)) {
 	  ParseError ("Illegal entry value(s).");
 	  return FALSE;
@@ -1332,22 +1347,24 @@ char *item;
       }
       else {
 	eNumElems = strlen (item);
-        if (eNumElems != 0) valuesB = item;
-        else {
-          eNumElems = 1L;
-          allocated = 1;
-          valuesB = (void *) malloc (1);
-          *(char *)valuesB = (char) '\0';
-        }
+	if (eNumElems != 0) valuesB = item;
+	else {
+	  eNumElems = 1L;
+	  allocated = 1;
+	  valuesB = (void *) malloc (1);
+	  *(char *)valuesB = (char) '\0';
+	}
       }
       status = CDFlib (SELECT_, gENTRY_, entryNum,
 		       PUT_, gENTRY_DATA_, eDataType, eNumElems, valuesB,
 		       NULL_);
       if (!StatusHandlerS2C(status,wriG)) return FALSE;
       if (allocated == 0) {
-        if (valuesB != item) cdf_FreeMemory (valuesB, FatalError);
-      } else
-        free (valuesB);
+	if (valuesB != item) cdf_FreeMemory (valuesB, FatalError);
+      } else {
+	free (valuesB);
+	valuesB = NULL;
+      }
       NextSearchItem (TOKEN, PERIODmarkOrGaENTRYNUMfield);
       break;
     }
@@ -1556,7 +1573,8 @@ char *item;
 	else {
 	  zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
           if (!ISTPname (varName) && warning)
-            WriteOutFP (stdout, "Warning: Variable name: \"%s\" not ISTP compliant... not recommended\n",
+            WriteOutFP (stdout,
+		 "Warning: Variable name: \"%s\" non-ISTP compliant... not recommended\n",
                         varName);
 	  if (zVar)
 	    status = CDFlib (CREATE_, zVAR_, varName, vDataType, vNumElems,
@@ -1755,8 +1773,7 @@ char *item;
 	  ParseError ("Illegal entry value(s).");
 	  return FALSE;
 	}
-      }
-      else {
+      } else {
 	eNumElems = strlen (item);
         if (eNumElems != 0) eValueB = item;
         else {
@@ -1767,9 +1784,9 @@ char *item;
         }
       }
       zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
+
       status = CDFlib (PUT_, BOO(zVar,zENTRY_DATA_,rENTRY_DATA_), eDataType,
-								  eNumElems,
-								  eValueB,
+					 eNumElems, eValueB,
 		       NULL_);
       if (!StatusHandlerS2C(status,BOO(zVar,wriVZ,wriVR))) return FALSE;
       if (useFillval) {
@@ -1788,8 +1805,10 @@ char *item;
       }
       if (allocated == 0) {
         if (eValueB != item) cdf_FreeMemory (eValueB, FatalError);
-      } else
+      } else {
         free (eValueB);
+        eValueB = NULL;
+      }
       NextSearchItem (TOKEN, VaNAMEfieldOrPERIODmark);
       break;
     }
@@ -2350,7 +2369,8 @@ int base;
 {
   size_t nChars = (size_t) (*size + base);
   if (strlen(*str) == *size) {
-    *str = (char *) cdf_ReallocateMemory (*str, (size_t) (nChars + 1), FatalError);
+    *str = (char *) cdf_ReallocateMemory (*str, (size_t) (nChars + 1),
+					  FatalError);
     *size += base;
   }
   catchrX (*str, chr, nChars);
@@ -2664,7 +2684,7 @@ char **argV[];
 	int n;
 	*argC = 1;
 	*argV = (char **) cdf_AllocateMemory ((size_t) (*argC * sizeof(char *)),
-				  FatalError);
+					      FatalError);
 	n = 0;
 	MAKEstrARGv (argV, n, pgmName)
 	CloseDialog (dialogP);
