@@ -66,6 +66,13 @@
 * Include files.
 ******************************************************************************/
 
+#define NCURSES_WIDECHAR 1
+
+#define _XOPEN_SOURCE_EXTENDED
+
+#include <stdio.h>
+#include <wchar.h>
+#include "cdftools.h"
 #include "windoz.h"
 
 #if defined(win32)
@@ -217,12 +224,20 @@ int rendition;
   return TRUE;
 #endif
 #if defined(CURSESui)
-  int i,j;
-  wattrset (wid->id, RenditionMapping(rendition));
-  for (i = 0; i < num_rows; i++)
-     for (j = 0; j < num_cols; j++)
-	mvwaddch (wid->id, row+i, col+j,
-		  mvwinch(wid->id,row+i,col+j) & A_CHARTEXT);
+  int i,k; size_t iz;
+  char bstring[401]; wchar_t wstring[101];
+  int rend = RenditionMapping(rendition);
+  for (i = 0; i < num_rows; i++) {
+    mvwinnwstr(wid->id, row+i, col, wstring, num_cols);
+    wstring[num_cols] = L'\0';
+#if !defined(WIN32)
+    k = (int) wcstombs (bstring, wstring, 400);
+/*    bstring[k] = (char) '\0'; */
+#else
+    wcstombs_s (&iz, bstring, 400, wstring, 100);
+#endif
+    put_chars (wid, bstring, num_cols, row+i, col, FALSE, rendition);
+  }
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
@@ -261,6 +276,19 @@ int create_pasteboard () {
   return TRUE;
 #endif
 #if defined(CURSESui)
+  char locale[201];
+  int ia;
+  ia = 0;
+  strncpy (locale, setlocale (LC_CTYPE, NULL), 200);
+  if (CDFstrstrIgCase (locale, "utf8") == NULL &&
+      CDFstrstrIgCase (locale, "utf-8") == NULL) {
+#if !defined(WIN32)
+    setlocale (LC_CTYPE, "en_US.UTF-8");
+#else
+    setlocale (LC_CTYPE, ".UTF8");
+#endif
+    ia = 1;
+  }
   initscr ();
   keypad (stdscr, TRUE);
   noecho ();
@@ -270,6 +298,7 @@ int create_pasteboard () {
   batchCount = 0;
   WINDhead = NULL;
   set_cursor_mode (CURSORon);
+  if (ia == 1) setlocale (LC_CTYPE, locale);
   return TRUE;
 #endif
 #if defined(COWui)
@@ -720,20 +749,24 @@ int deleteToEOLkey;		/* Key causing the characters starting at the
 				   cursor to be deleted. */
 int refreshKey;			/* Key causing the screen to be refreshed. */
 {
-  int curLen = (int) strlen(field);
+  int curLen = UTF8StrLength(field, (int)strlen(field));
   int insertMode = FALSE;	/* Initially in insert mode. */
   int firstCol = fieldCol;
   int lastCol = fieldCol + fieldLen - 1;
-  int curChar, colN, key, i;
+  int curChar, colN, i;
+  int len, width;
+  wint_t key;
   /****************************************************************************
   * Write current field contents and position cursor.
   ****************************************************************************/
   if (!put_chars(wid,field,curLen,
 		 fieldRow,fieldCol,FALSE,NORMAL)) return FALSE;
-  for (colN = firstCol + curLen; colN <= lastCol; colN++)
+  width = UTF8TotalWidth(field);
+  for (colN = firstCol + width; colN <= lastCol; colN++)
      if (!put_chars(wid," ",1,fieldRow,colN,FALSE,NORMAL)) return FALSE;
   curChar = 0;
   if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+    return FALSE;
   /****************************************************************************
   * Read keystrokes until return/exit.
   ****************************************************************************/
@@ -757,7 +790,9 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
      if (key == KB_LEFTARROW) {
        if (curChar > 0) {
 	 curChar--;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field, curChar)))
+	   return FALSE;
        }
        else
 	 ring_bell ();
@@ -769,7 +804,9 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
      if (key == KB_RIGHTARROW) {
        if (curChar < curLen && curChar < fieldLen - 1) {
 	 curChar++;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field, curChar)))
+	   return FALSE;
        }
        else
 	 ring_bell ();
@@ -780,16 +817,30 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
      *************************************************************************/
      if (key == KB_DELETE) {
        if (curChar > 0) {
+	 int charLen; int ix, iy, total;
 	 int charsToEnd = curLen - curChar;
-	 memmove (&field[curChar-1], &field[curChar], charsToEnd + 1);
-	 curLen--;
+         iy = (int) strlen(field);
+	 ix = UTF8StrLength (field, iy);
+	 if (ix == iy) 
+	   memmove (&field[curChar-1], &field[curChar], charsToEnd + 1);
+	 else {
+	   char *ptr = UTF8CharAtString (field, curChar);
+	   int len =  UTF8CharAtLength (field, curChar-1);
+	   memmove (ptr-len, ptr, strlen(ptr) + 1);
+	 }
 	 curChar--;
+	 curLen--;
+	 total = UTF8TotalWidth(field);
 	 if (charsToEnd > 0)
-	   if (!put_chars(wid,&field[curChar],charsToEnd,fieldRow,
-			  firstCol+curChar,FALSE,NORMAL)) return FALSE;
+	   if (!put_chars(wid,UTF8CharAtString(field,curChar),charsToEnd,
+			  fieldRow, firstCol+
+				    UTF8FirstCharsWidth(field, curChar),
+			  FALSE,NORMAL)) return FALSE;
 	 if (!put_chars(wid," ",1,fieldRow,
-			firstCol+curLen,FALSE,NORMAL)) return FALSE;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+			firstCol+total,FALSE,NORMAL)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field, curChar)))
+	   return FALSE;
        }
        else
 	 ring_bell ();
@@ -801,7 +852,9 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
      if (key == moveToSOLkey) {
        if (curChar > 0) {
 	 curChar = 0;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field, curChar)))
+	   return FALSE;
        }
        else
 	 ring_bell ();
@@ -813,12 +866,16 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
      if (key == moveToEOLkey) {
        if (curLen < fieldLen && curChar < curLen) {
 	 curChar = curLen;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field,curChar)))
+	   return FALSE;
 	 continue;
        }
        if (curLen == fieldLen && curChar < curLen - 1) {
 	 curChar = curLen - 1;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field,curChar)))
+	   return FALSE;
 	 continue;
        }
        ring_bell ();
@@ -831,15 +888,25 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
        if (curChar > 0) {
 	 int charsToEnd = curLen - curChar;
 	 int charsToStart = curChar + 1;
-	 int colN, i;
-	 memmove (field, &field[curChar], charsToEnd + 1);
+	 int colN, i, ix, iy;
+         iy = (int) strlen(field);
+	 ix = UTF8StrLength (field, iy);
+	 if (ix == iy)
+	   memmove (field, &field[curChar], charsToEnd + 1);
+	 else {
+	   char *ptr = UTF8CharAtString (field, curChar);
+	   memmove (field, ptr, strlen(ptr) + 1);
+	 }
 	 curLen = charsToEnd;
 	 curChar = 0;
 	 if (!put_chars(wid,field,curLen,
 			fieldRow,firstCol,FALSE,NORMAL)) return FALSE;
-	 for (colN = firstCol+curLen, i = 0; i < charsToStart-1; colN++, i++)
+	 width = UTF8TotalWidth(field);
+	 for (colN = firstCol+width, i = 0; i < charsToStart-1; colN++, i++)
 	    if (!put_chars(wid," ",1,fieldRow,colN,FALSE,NORMAL)) return FALSE;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field,curChar)))
+	   return FALSE;
        }
        else
 	 ring_bell ();
@@ -852,11 +919,14 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
        if (curChar < curLen) {
 	 int charsToEnd = curLen - curChar;
 	 int colN, i;
-	 field[curChar] = NUL;
+	 *(UTF8CharAtString(field,curChar)) = NUL;
 	 curLen = curChar;
-	 for (colN = firstCol+curChar, i = 0; i < charsToEnd; colN++, i++)
+	 width = UTF8TotalWidth(field);
+	 for (colN = firstCol+width, i = 0; i < charsToEnd; colN++, i++)
 	    if (!put_chars(wid," ",1,fieldRow,colN,FALSE,NORMAL)) return FALSE;
-	 if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
+	 if (!set_cursor_abs(wid,fieldRow,firstCol+
+					  UTF8FirstCharsWidth(field,curChar)))
+	   return FALSE;
        }
        else
 	 ring_bell ();
@@ -881,31 +951,40 @@ int refreshKey;			/* Key causing the screen to be refreshed. */
      *************************************************************************/
      if (Printable(key)) {
        if (insertMode) {
+	 char *ptr;
 	 if (curLen < fieldLen) {
 	   int charsToEnd = curLen - curChar;
-	   memmove (&field[curChar+1], &field[curChar], charsToEnd + 1);
-	   field[curChar] = key;
+	   len = UTF8CharLength((char *)&key);
+	   ptr = UTF8CharAtString (field, curChar);
+	   memmove (ptr+len, ptr, strlen(ptr) + 1);
+	   memmove (ptr, (char *)&key, (size_t) len);
 	   curLen++;
-	   if (!put_chars(wid,&field[curChar],charsToEnd+1,fieldRow,
-			  firstCol+curChar,FALSE,NORMAL)) return FALSE;
+	   if (!put_chars(wid,ptr,charsToEnd+1,
+			  fieldRow, firstCol+curChar,FALSE,NORMAL))
+	     return FALSE;
 	   if (curChar < fieldLen - 1) curChar++;
 	 }
 	 else
 	   ring_bell ();
-       }
-       else {
-	 field[curChar] = key;
+       } else {
+	 char *ptr, *ptr2;
+	 len = UTF8CharLength((char *)&key);
+	 ptr = UTF8CharAtString (field, curChar);
+	 ptr2 = UTF8CharAtString (field, curChar+1);
+	 memmove (ptr+len, ptr2, strlen(ptr2) + 1);
+	 memmove (ptr, (char *)&key, (size_t) len);
 	 if (curChar == curLen) {
 	   curLen++;
-	   field[curLen] = NUL;
+	   *(UTF8CharAtString(field,curLen)) = NUL;
 	 }
-	 if (!put_chars(wid,&field[curChar],1,fieldRow,
+	 if (!put_chars(wid,UTF8CharAtString(field,curChar),1,fieldRow,
 			firstCol+curChar,FALSE,NORMAL)) return FALSE;
 	 if (curChar < fieldLen - 1) curChar++;
        }
-       if (!set_cursor_abs(wid,fieldRow,firstCol+curChar)) return FALSE;
-     }
-     else
+       if (!set_cursor_abs(wid,fieldRow,firstCol+
+					UTF8FirstCharsWidth(field,curChar)))
+	 return FALSE;
+     } else
        ring_bell ();
   }
 }
@@ -956,7 +1035,7 @@ int rendition;
   if (len > nCols - 2) return FALSE;
   wattrset (wid->id, RenditionMapping(rendition));
   startCol = (nCols - len) / 2;
-  for (i = 0; i < len; i++) mvwaddch (wid->id, 0, startCol + i, label[i]);
+  mvwaddstr (wid->id, 0, startCol, label);
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
@@ -1027,7 +1106,7 @@ int col;
 int put_chars (wid, string, len, row, col, eraseMode, rendition)
 WINDOWid wid;
 char *string;
-int len;
+int len;			/* The number of characters - not bytes */
 int row;
 int col;
 int eraseMode;
@@ -1054,14 +1133,41 @@ int rendition;
   return TRUE;
 #endif
 #if defined(CURSESui)
-  int nRows, nCols, colN, i;
+  /* **** Linux   ****/
+  int nRows, nCols, colN, rend, code; size_t it;
+  int i, j, ix, iy, iz, charLen; wchar_t wch[2], blankw = L' ', *wchars;
+  cchar_t onecc;
+  iy = (int) strlen(string);
+  ix = UTF8StrLength(string, iy);
+  wchars = (wchar_t *) malloc(sizeof(wchar_t) * (ix + 1));
+#if !defined(WIN32)
+  iz = (int) mbstowcs (wchars, string, ix);
+  wchars[iz] = L'\0';
+#else
+  mbstowcs_s (&it, wchars, (size_t)ix, string, (size_t)iy);
+#endif
   WindowSize (wid->id, &nRows, &nCols);
+  rend = RenditionMapping(rendition);
   if (eraseMode == ERASE) {
-    wattrset (wid->id, RenditionMapping(NORMAL));
-    for (colN = 1; colN <= nCols - 2; colN++) mvwaddch (wid->id,row,colN,' ');
+    wch[0] = blankw;
+    wch[1] = 0;
+    for (colN = 1; colN <= (nCols - 2); colN++) {
+      setcchar (&onecc, wch, (chtype) RenditionMapping(NORMAL), 0, (void *)0);
+      code = mvwadd_wch (wid->id,row,colN,&onecc);
+    }
   }
-  wattrset (wid->id, RenditionMapping(rendition));
-  for (i = 0; i < len; i++) mvwaddch (wid->id, row, col + i, string[i]);
+  for (i = 0, j = 0; i < len; ++i) {
+    wch[0] = wchars[i];
+    wch[1] = 0;
+    setcchar (&onecc, wch, (chtype) rend, 0, (void *)0);
+    code = mvwadd_wch (wid->id, row, col + j, &onecc);
+/*
+    j += GetWideCharWidth (wch[0]);
+*/
+    j += UTF8WCharWidth (wch[0]);
+  }
+  free (wchars);
+  wchars = NULL;
   if (!RefreshWINDs(UPDATE_)) return FALSE;
   return TRUE;
 #endif
@@ -1169,7 +1275,11 @@ int read_input (
 #if defined(CURSESui)
 WINDOWid wid;
 #endif
+#if defined(WIN32)
 int *tcode;		/* Out: key entered. */
+#else
+wint_t *tcode;		/* Out: key entered (wide character). */
+#endif
 int mode;		/* Case conversion mode. */
 Logical block;		/* Block until key available? */
 {
@@ -1188,7 +1298,6 @@ Logical block;		/* Block until key available? */
   if (ABORTkey(*tcode)) {
     set_cursor_mode (CURSORon);
     delete_pasteboard (ERASE);
-    cdf_FreeMemory (NULL, FatalError);
     Exit;
   }
   switch (mode) {
@@ -1202,6 +1311,7 @@ Logical block;		/* Block until key available? */
   * Curses.
   ****************************************************************************/
 #if defined(CURSESui)
+  int ret;
   if (!block) {
 #if defined(unix) && !defined(__MINGW32__)
     fd_set rset;
@@ -1218,11 +1328,14 @@ Logical block;		/* Block until key available? */
     if (!kbhit()) return FALSE;
 #endif
   }
-  *tcode = wgetch (wid->id);
+#if defined(WIN32)
+  *tcode = wgetch (wid->id); 
+#else
+  ret = wget_wch (wid->id, tcode);
+#endif
   if (ABORTkey(*tcode)) {
     set_cursor_mode (CURSORon);
     delete_pasteboard (ERASE);
-    cdf_FreeMemory (NULL, FatalError);
     Exit;
   }
   switch (*tcode) {
@@ -1389,7 +1502,6 @@ Logical block;		/* Block until key available? */
 	 *tcode = (int) (event.message & charCodeMask);
 	 if (ABORTkeyMAC(event)) {
 	   delete_pasteboard (ERASE);
-	   cdf_FreeMemory (NULL, FatalError);
 	   Exit;
 	 }
 	 /*******************************************************************
@@ -1558,6 +1670,7 @@ int col;
   return TRUE;
 #endif
 #if defined(CURSESui)
+int ir, ic;
   wmove (wid->id, row, col);
   wrefresh (wid->id);
   return TRUE;
@@ -1696,7 +1809,7 @@ int zzzzz (seconds)
 double seconds;
 {
 #if defined(SMGui)					/* ie. VMS */
-#if defined(alphavmsI)
+#if defined(alphavmsI) || defined(ia64vmsI)
   time_t start_time, current_time;
   time (&start_time);
   time (&current_time);
@@ -1879,25 +1992,23 @@ static Logical DeleteWINDs () {
 static Logical RefreshWINDs (level)
 int level;
 {
-/*  if (batchCount < 1) { */
-    WINDOWid tW;
-    switch (level) {
-      case HARD_:
-      case SOFT_:
-      case UPDATE_:
+  WINDOWid tW;
+  switch (level) {
+    case HARD_:
+    case SOFT_:
+    case UPDATE_:
 	/* Do nothing if CURSES. */
-	break;
+      break;
+  }
+  tW = WINDhead;
+  while (tW != NULL) {
+    if (tW->pasted) {
+      touchwin (tW->id);
+      wnoutrefresh (tW->id);
     }
-    tW = WINDhead;
-    while (tW != NULL) {
-      if (tW->pasted) {
-	touchwin (tW->id);
-	wnoutrefresh (tW->id);
-      }
-      tW = tW->next;
-    }
-    doupdate ();
-/*  } */
+    tW = tW->next;
+  }
+  doupdate ();
   return TRUE;
 }
 #endif
@@ -2326,11 +2437,20 @@ LocalId id;
   werase (id);
 #else
   int nRows, nCols, rowN, colN;
+  int iz;
+  wchar_t star = L'*', blank = L' ', wch[2];
+  cchar_t cc1, cc2;
+  wch[0] = star;
+  wch[1] = 0;
+  setcchar (&cc1, wch, (chtype) RenditionMapping(NORMAL), 0, 0);
+  wch[0] = blank;
+  wch[1] = 0;
+  setcchar (&cc2, wch, (chtype) RenditionMapping(NORMAL), 0, 0);
   WindowSize (id, &nRows, &nCols);
   for (rowN = 0; rowN < nRows; rowN++) {
      for (colN = 0; colN < nCols; colN++) {
-	mvwaddch (id, rowN, colN, '*');
-	mvwaddch (id, rowN, colN, ' ');
+	mvwadd_wch (id, rowN, colN, &cc1);
+	mvwadd_wch (id, rowN, colN, &cc2);
      }
   }
 #endif
